@@ -5,7 +5,7 @@
  * Unit test for motd
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -102,7 +102,7 @@ main(int argc, char** argv)
   // export mdtx environment
   if (!setEnv(programName, &env)) goto optError;
 
-  /************************************************************************/
+  /**********************************************************************/
   if (!(coll = mdtxGetCollection("coll1"))) goto error;
   
   // add a demand for logo.xmp
@@ -140,23 +140,24 @@ main(int argc, char** argv)
   string = 0;
   if (!addCacheEntry(coll, record)) goto error;
   record = 0;
- 
-  // test 1
-  logMain(LOG_INFO, "** Test 1");
-  if (!updateMotd()) goto error;
 
-  // test 2: test alphabetic order on supports
-  logMain(LOG_INFO, "** Test 2");
+  // test 1: test alphabetic order on supports
+  logMain(LOG_INFO, "** Test 1");
   sprintf(path, "%s/logoP1.iso", inputRep);
   if (!mdtxAddSupport("AAA", path)) goto error;
   if (!mdtxAddSupport("ZZZ", path)) goto error;
   if (!mdtxShareSupport("AAA", "coll1")) goto error; // set wrong order
   if (!mdtxShareSupport("ZZZ", "coll1")) goto error;
   if (!scoreLocalImages(coll)) goto error; // <- this perturb first test!
-  if (!updateMotd()) goto error; 
+  if (!updateMotd()) goto error;
+  
+  // test 2: test having motdPolicy=ALL
+  logMain(LOG_INFO, "** Test 2 having motdPolicy=ALL");
+  coll->motdPolicy = ALL;
+  if (!updateMotd()) goto error;
   
   if (!releaseCollection(coll, CACH)) goto error;
-  /************************************************************************/
+  /**********************************************************************/
   
   freeConfiguration();
   rc = TRUE;
