@@ -183,7 +183,7 @@ main(int argc, char** argv)
 
     // first run functions without error
     if (!(coll = mdtxGetCollection("coll1"))) goto error;
-    if (!loadCollection(coll, CTLG|EXTR)) goto error;
+    if (!loadCollection(coll, EXTR)) goto error;
     
     if ((logo = 
 	 getArchive(coll, "022a34b2f9b893fba5774237e1aa80ea", 24075))
@@ -198,19 +198,12 @@ main(int argc, char** argv)
 	 addArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 123))
 	== 0) goto error;
     
-    //if (!(isCatalogRefbyExtract(coll))) goto error;
     if (!isFileRefbyExtract(coll, iso1)) goto error;
     if (!isFileRefbyExtract(coll, zip)) goto error;
-    //if (!isFileRefbyCatalog(coll, logo)) goto error;
     
     // now, run them on error
-    if (!addArchiveToDocument(coll, new, getDocument(coll, "panthere"))) 
-      goto error;
-    //if (isCatalogRefbyExtract(coll)) goto error;
     if (isFileRefbyExtract(coll, new)) goto error;
     if (isFileRefbyExtract(coll, logo)) goto error;
-    //if (!isFileRefbyCatalog(coll, new)) goto error;
-    if (areNotAlreadyThere(coll, coll)) goto error;
   }
   else {
 
