@@ -5,7 +5,7 @@
  * unit test for openClose
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -85,9 +85,16 @@ main(int argc, char** argv)
   /************************************************************************/
   if (!mdtxGetSupport("SUPP11_logo.png")) goto error;
   if (!(coll = mdtxGetCollection("coll1"))) goto error;
+  
   if (!loadCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   if (!releaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
+
+  // test diseaseArchives()
+  if (!loadCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
+  if (!diseaseArchives(coll)) goto error;
+  if (!releaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
+  if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   /************************************************************************/
 
   rc = TRUE;
