@@ -23,7 +23,7 @@
 
 #include "mediatex.h"
 
-#define UNDEF -1
+#define NODEF -1
 #define INIT  10
 #define GET   11
 #define FREE  12
@@ -76,7 +76,7 @@ usage(char* programName)
 int 
 main(int argc, char** argv)
 {
-  int signal = UNDEF;
+  int signal = NODEF;
   ShmParam param;
   int doError = FALSE;
   // ---
@@ -112,62 +112,62 @@ main(int argc, char** argv)
     switch(cOption) {
 
     case 'I':
-      if (signal != UNDEF) rc=1;
+      if (signal != NODEF) rc=1;
       signal = INIT;
       break;
 
     case 'G':
-      if (signal != UNDEF) rc=2;
+      if (signal != NODEF) rc=2;
       signal = GET;
       break;
 
     case 'F':
-      if (signal != UNDEF) rc=3;
+      if (signal != NODEF) rc=3;
       signal = FREE;
       break;
 
     case 'W':
-      if (signal != UNDEF) rc=4;
+      if (signal != NODEF) rc=4;
       signal = REG_SAVEMD5;
       break;
 
     case 'E':
-      if (signal != UNDEF) rc=5;
+      if (signal != NODEF) rc=5;
       signal = REG_EXTRACT;
       break;
 
     case 'N':
-      if (signal != UNDEF) rc=6;
+      if (signal != NODEF) rc=6;
       signal = REG_NOTIFY;
       break;
 
     case 'Q':
-      if (signal != UNDEF) rc=7;
+      if (signal != NODEF) rc=7;
       signal = REG_QUICKSCAN;
       break;
 
     case 'S':
-      if (signal != UNDEF) rc=7;
+      if (signal != NODEF) rc=7;
       signal = REG_SCAN;
       break;
 
     case 'T':
-      if (signal != UNDEF) rc=7;
+      if (signal != NODEF) rc=7;
       signal = REG_TRIM;
       break;
 
     case 'C':
-      if (signal != UNDEF) rc=7;
+      if (signal != NODEF) rc=7;
       signal = REG_CLEAN;
       break;
 
     case 'P':
-      if (signal != UNDEF) rc=7;
+      if (signal != NODEF) rc=7;
       signal = REG_PURGE;
       break;
 
     case 'd':
-      if (signal != UNDEF) rc=7;
+      if (signal != NODEF) rc=7;
       signal = REG_STATUS;
       break;
 
@@ -198,7 +198,7 @@ main(int argc, char** argv)
   case FREE:
     rc = mdtxShmFree();
     break;
-  case UNDEF:
+  case NODEF:
     usage(programName);
     break;
   default:
