@@ -279,7 +279,7 @@ int createExempleExtractTree(Collection* coll)
     *tbz, *afio, *zip, *rar1, *rar2,
     *tar, *cpio, *gzip, *bzip;
   Container* container = 0;
-  FromAsso* asso = 0;
+  Location* location = 0;
   time_t time = 0;
   struct tm date;
   char dateString[32];
@@ -339,79 +339,61 @@ int createExempleExtractTree(Collection* coll)
 
   // ISO 1
   if (!(container = addContainer(coll, ISO, iso1))) goto error;
-  if (!(asso = addFromAsso(coll, catP1, container, 
-			   "logoP1.cat"))) goto error;
+  if (!addFromAsso(container, catP1, "logoP1.cat")) goto error;
 
   // ISO 2
   if (!(container = addContainer(coll, ISO, iso2))) goto error;
-  if (!(asso = addFromAsso(coll, catP2, container,
-			   "logoP2.cat"))) goto error;
+  if (!addFromAsso(container, catP2, "logoP2.cat")) goto error;
 
   // CAT
   if (!(container = addContainer(coll, CAT, catP1))) goto error;
   if (!addFromArchive(coll, container, catP2)) goto error;
-  if (!(asso = addFromAsso(coll, tgz, container,
-			   "logo.tgz"))) goto error;
+  if (!addFromAsso(container, tgz, "logo.tgz")) goto error;
 
   // TGZ
   if (!(container = addContainer(coll, TGZ, tgz))) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!(container->directory = createString("extractionDir"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // TBZ
   if (!(container = addContainer(coll, TBZ, tbz))) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // AFIO
   if (!(container = addContainer(coll, AFIO, afio))) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // ZIP
   if (!(container = addContainer(coll, ZIP, zip))) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // RAR
   if (!(container = addContainer(coll, RAR, rar1))) goto error;
   if (!addFromArchive(coll, container, rar2)) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // TAR
   if (!(container = addContainer(coll, TAR, tar))) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // CPIO
   if (!(container = addContainer(coll, CPIO, cpio))) goto error;
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "logo/logo.png"))) goto error;
-  if (!(asso = addFromAsso(coll, xpm, container,
-			   "logo/logo.xpm"))) goto error;
+  if (!addFromAsso(container, logo, "logo/logo.png")) goto error;
+  if (!addFromAsso(container, xpm, "logo/logo.xpm")) goto error;
 
   // GZIP
   if (!(container = addContainer(coll, GZIP, gzip))) goto error;
-  if (!(asso = addFromAsso(coll, cpio, container,
-			   "logo.cpio"))) goto error;
+  if (!addFromAsso(container, cpio, "logo.cpio")) goto error;
 
   // BZIP
   if (!(container = addContainer(coll, BZIP, bzip))) goto error;
-  if (!(asso = addFromAsso(coll, cpio, container,
-			   "logo.cpio"))) goto error;
+  if (!addFromAsso(container, cpio, "logo.cpio")) goto error;
 
   // INC
   if (!(time = currentTime())) goto error;
@@ -423,22 +405,26 @@ int createExempleExtractTree(Collection* coll)
 	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
 	  date.tm_hour, date.tm_min, date.tm_sec);
   if (!(container = coll->extractTree->inc)) goto error;
-  if (!(asso = addFromAsso(coll, iso1, container, dateString))) goto error;
-  if (!(asso = addFromAsso(coll, iso2, container, "1994-01-01,00:00:00"))) 
-    goto error;
+  if (!addFromAsso(container, iso1, dateString)) goto error;
+  if (!addFromAsso(container, iso2, "1994-01-01,00:00:00")) goto error;
 
   // this one should be automatically removed
-  if (!(asso = addFromAsso(coll, logo, container, dateString))) goto error;
+  if (!addFromAsso(container, logo, dateString)) goto error;
 
   // IMG
   if (!(container = coll->extractTree->img)) goto error;
-  if (!(asso = addFromAsso(coll, gzip, container,
-			   "here/logo.gz"))) goto error;
+  if (!addFromAsso(container, gzip, "here/logo.gz")) goto error;
 
   // this one should be automatically removed*
-  if (!(asso = addFromAsso(coll, logo, container,
-			   "here/logo.png"))) goto error;  
+  if (!addFromAsso(container, logo, "here/logo.png")) goto error;  
 
+  // Location
+  if (!(location =
+	addLocation(coll, COPY, "746d6ceeb76e05cfa2dea92a1c5753cd",
+		    "/location", "extract_dir"))) goto error;
+  if (!addLocationAsso(location, logo, "logo.png")) goto error;
+  if (!addLocationAsso(location, cpio, "logo.cpio")) goto error;
+  
   return TRUE;
  error:
   logMemory(LOG_ERR, 
@@ -596,12 +582,14 @@ createExempleConfiguration(char* inputPath)
   if (!(self->comment = catString(self->comment, " configuration file")))
     goto error;
   
-  // needed for cgi unit test (wich connect serv1 and serv2)
+  // needed for cgi unit test (which connect serv1 and serv2)
+  //if (env.confLabel[4] == '1') strcpy(self->host, DEFAULT_HOST); ICI!!
   if (env.confLabel[4] == '1') strcpy(self->host, "localhost");
 
   /* test1 collection */
   if (!(coll = addCollection("coll1"))) goto error;
   if (!(coll->masterLabel = createString("mdtx1"))) goto error;
+  //strncpy(coll->masterHost, DEFAULT_HOST, MAX_SIZE_HOST); ICI!!
   strncpy(coll->masterHost, "localhost", MAX_SIZE_HOST);
   coll = 0;
 
