@@ -5,7 +5,7 @@
  * archive producer interface
 
  MediaTex is an Electronic Archives Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -127,14 +127,14 @@ main(int argc, char** argv)
   // search an archive
   if (getArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222))
     goto error;
-  if (!(arch1 =
+  if (!(arch2 =
   	addArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222)))
     goto error;
-  if (getArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222) != arch1)
+  if (getArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222) != arch2)
     goto error;
 
   if (avl_count(coll->archives) != 2) goto error;
-  if (!(diseaseArchives(coll))) goto error;
+  if (!diseaseArchives(coll)) goto error;
   if (avl_count(coll->archives)) goto error;
   /************************************************************************/
 
