@@ -196,7 +196,7 @@ main(int argc, char** argv)
   rgRewind(cont);
   if ((ring = copyRing(ring, cont,
   		       (void*(*)(void*)) destroyString,
-  		       (void*(*)(void*, const void*)) copyString))
+  		       (void*(*)(void*, const void*)) mdtxCopyString))
       == 0) goto error;
 
   while ((it = (char *)rgNext(ring)) != (char *)0) {
