@@ -132,7 +132,7 @@ main(int argc, char** argv)
   prefix = catString(prefix, "/suffix");
   fprintf(hout, "concatenate 1/1 %s\n", prefix);
   
-  prefix = copyString(prefix, "prefix/");
+  prefix = mdtxCopyString(prefix, "prefix/");
   prefix = catString(prefix, (char*)0);
   fprintf(hout, "concatenate 1/0 %s\n", prefix);
   
@@ -153,7 +153,7 @@ main(int argc, char** argv)
     fprintf(hout, "%s", string);
     
     fprintf(hout, "copied  = ");
-    if ((copy = copyString(copy, string)) == 0) goto error;
+    if ((copy = mdtxCopyString(copy, string)) == 0) goto error;
     fprintf(hout, "%s", copy);
     
     string = destroyString(string);
