@@ -27,10 +27,19 @@ set -e
 TEST=$(basename $0)
 TEST=${TEST%.sh}
 
+OPENSSH_VERSION=$(dpkg -l openssh-client | grep ii | awk '{print $3}' | \
+        cut -d'-' -f1 | cut -d':' -f2)
+OPTION="-E md5"
+if [ x$OPENSSH_VERSION == x"5.9p1" ]; then
+    OPTION=""
+fi
+
 # run units tests
 rm -f misc/key misc/key.pub
 ssh-keygen -N "" -t rsa -f misc/key >/dev/null
-ssh-keygen -l -f misc/key.pub | awk '{print $2}' >misc/$TEST.txt
+ssh-keygen -l $OPTION -f misc/key.pub | \
+    awk '{print $2}' | sed -e "s/MD5://" \
+    >misc/$TEST.txt
 misc/utkeys -i misc/key.pub 2>/dev/null >misc/$TEST.out
 
 # compare with the expected outputs
