@@ -93,7 +93,7 @@ usage(char* programName)
  =======================================================================*/
 int main(int argc, char** argv)
 {
-  typedef enum {UNDEF, READER, WRITER, CLEANER} Role;
+  typedef enum {READER=1, WRITER, CLEANER} Role;
   Role role = UNDEF;
   // ---
   int rc = 0;
