@@ -99,7 +99,7 @@ parser/ut$TEST.tab clean >>parser/$TEST.out 2>&1
 parser/ut$TEST.tab clean coll COLL >>parser/$TEST.out 2>&1
 parser/ut$TEST.tab su >>parser/$TEST.out 2>&1
 parser/ut$TEST.tab su coll COLL >>parser/$TEST.out 2>&1
-parser/ut$TEST.tab audit coll COLL for MAIL >>parser/$TEST.out 2>&1
+parser/ut$TEST.tab audit for MAIL coll COLL >>parser/$TEST.out 2>&1
 
 # compare with the expected output
 mrProperOutputs parser/$TEST.out
