@@ -5,7 +5,7 @@
  * configuration scanner test
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -217,6 +217,9 @@ main(int argc, char** argv)
     case confTIME:
       strcpy(token, "TIME");
       break;
+    case confMOTDPOLICY:
+      strcpy(token, "MOTDPOLICY");
+      break;
 
     case 0:
       strcpy(token, "EOF");
