@@ -5,7 +5,7 @@
  * server scanner test
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -167,6 +167,9 @@ main(int argc, char** argv)
     case servWWWPORT:
       strcpy(token, "WWWPORT");
       break;
+    case servDNSHOST:
+      strcpy(token, "DNSHOST");
+      break;
     case servCOLLKEY:
       strcpy(token, "COLLKEY");
       break;
