@@ -319,9 +319,10 @@ utUploadMessage(Collection* coll, char* extra)
   if (!(string = createString(extra))) goto error;
   if (!(localhost = getLocalHost(coll))) goto error;
   if (!(con = utConnexion(coll, UPLOAD, localhost))) goto error;
-  if (!(record = utLocalRecord(coll, 
-			       "3f18841537668dcf4fafd1471c64d52d", 1937,
-			       SUPPLY, string)))
+  if (!(record =
+	utLocalRecord(coll, 
+		      "b34bb9bf9ae4ec5b4a5bc2ab3e2a18c5", 25088,
+		      SUPPLY, string)))
     goto error;
   string = 0;
   
