@@ -124,7 +124,7 @@ main(int argc, char** argv)
   if (!(connexion = utUploadMessage(coll, extra))) goto error;
   avl_free_tree(connexion->message->records);
   connexion->message->records = 0;
-  if (uploadFinaleArchive(connexion)) goto error;
+  if (uploadFinaleArchives(connexion)) goto error;
   logMain(LOG_NOTICE, "reply : %s", connexion->status);
   destroyRecordTree(connexion->message);
   free (connexion);
@@ -137,7 +137,7 @@ main(int argc, char** argv)
   record = destroyRecord(record);
   avl_unlink_node(connexion->message->records, node);
   free(node);
-  if (uploadFinaleArchive(connexion)) goto error;
+  if (uploadFinaleArchives(connexion)) goto error;
   logMain(LOG_NOTICE, "reply : %s", connexion->status);
   destroyRecordTree(connexion->message);
   free (connexion);
@@ -147,7 +147,7 @@ main(int argc, char** argv)
   if (!(connexion = utUploadMessage(coll, extra))) goto error;
   if (!(record = connexion->message->records->head->item)) goto error;
   strcpy(record->extra, "notBeginningWithSlash");
-  if (uploadFinaleArchive(connexion)) goto error;
+  if (uploadFinaleArchives(connexion)) goto error;
   logMain(LOG_NOTICE, "reply : %s", connexion->status);
   destroyRecordTree(connexion->message);
   free (connexion);
@@ -155,7 +155,7 @@ main(int argc, char** argv)
   /*--------------------------------------------------------*/
   utLog("%s", " * Upload using default target:", 0);
   if (!(connexion = utUploadMessage(coll, extra))) goto error;
-  if (!uploadFinaleArchive(connexion)) {
+  if (!uploadFinaleArchives(connexion)) {
     utLog("reply : %s", connexion->status, 0);
     goto error;
   }
@@ -166,7 +166,7 @@ main(int argc, char** argv)
  /*--------------------------------------------------------*/
   utLog("%s", " * Already there:", 0);
   if (!(connexion = utUploadMessage(coll, extra))) goto error;
-  if (uploadFinaleArchive(connexion)) goto error;
+  if (uploadFinaleArchives(connexion)) goto error;
   logMain(LOG_NOTICE, "reply : %s", connexion->status);
   destroyRecordTree(connexion->message);
   free (connexion);
@@ -181,7 +181,7 @@ main(int argc, char** argv)
   if (!(record = connexion->message->records->head->item)) goto error;
   if (!(record->extra = catString(record->extra, ":store"))) 
     goto error;
-  if (!uploadFinaleArchive(connexion))  {
+  if (!uploadFinaleArchives(connexion))  {
     utLog("reply : %s", connexion->status, 0);
     goto error;
   }
@@ -200,7 +200,7 @@ main(int argc, char** argv)
     logMain(LOG_ERR, "cannot add record (already there?)");
     goto error;
   }
-  if (!uploadFinaleArchive(connexion))  {
+  if (!uploadFinaleArchives(connexion))  {
     utLog("reply : %s", connexion->status, 0);
     goto error;
   }
