@@ -33,6 +33,7 @@
 function UNIT_TEST_populate_datadir()
 {
     mkdir -p $MISC
+    mkdir -p $SCRIPTS
 
     for f in cron mediatex.conf supports.txt logo \
 	catalog000.txt extract000.txt servers.txt htgroup \
@@ -42,6 +43,8 @@ function UNIT_TEST_populate_datadir()
     for t in home index cache score cgi; do
 	install -o root -g root -m 444 $srcdir/../misc/$t.htaccess $MISC
     done
+    install -o root -g root -m 444 $srcdir/../scripts/mediatexd1 $SCRIPTS
+    install -o root -g root -m 444 $srcdir/../scripts/mediatexd2 $SCRIPTS
 
     # Note:
     #  Jail dir must be owned by root and not writable by others users,
@@ -54,9 +57,6 @@ function UNIT_TEST_populate_datadir()
     mkdir -p $SYSCONFDIR/cron.d
     mkdir -p $SYSCONFDIR/logrotate.d/httpd-prerotate
     mkdir -p $SYSCONFDIR/init.d
-    
-    install -o root -g root -m 444 $srcdir/../scripts/mediatexd \
-	    $SYSCONFDIR/init.d
 }
 
 # this function set the directory to use for unit tests. 
@@ -71,41 +71,41 @@ function UNIT_TEST_push_root_directory()
     # path configuration variables for unit tests: 
     #  we use "/tmp/ut-XXX" to prefix all paths
     
-
     # overwrite global variables
-    BINDIR="${1}${BINDIR}"
-    DATAROOTDIR="${1}${DATAROOTDIR}"
-    EXEC_PREFIX="${1}${EXEC_PREFIX}"
-    LIBDIR="${1}${LIBDIR}"
-    LOCALSTATEDIR="${1}${LOCALSTATEDIR}"
-    PREFIX="${1}${PREFIX}"
-    SYSCONFDIR="${1}${SYSCONFDIR}"
+    BINDIR="${1}/usr/bin"
+    DATAROOTDIR="${1}/usr/share"
+    EXEC_PREFIX="${1}/usr"
+    LIBDIR="${1}/usr/lib"
+    LOCALSTATEDIR="${1}/var"
+    PREFIX="${1}/usr"
+    SYSCONFDIR="${1}/etc"
 
-    # overwrite scripts variables 
-    ETCDIR="${1}${ETCDIR}"
-    DATADIR="${1}${DATADIR}"
-    STATEDIR="${1}${STATEDIR}"
-    CACHEDIR="${1}${CACHEDIR}"
-    PIDDIR="${1}${PIDDIR}"
-    SCRIPTS="${1}${SCRIPTS}"
-    MISC="${1}${MISC}"
-    HOSTSSH="${1}${HOSTSSH}"
+    # overwrite scripts variables
+    ETCDIR="${SYSCONFDIR}${MEDIATEX}"
+    DATADIR="${DATAROOTDIR}${MEDIATEX}"
+    STATEDIR="${LOCALSTATEDIR}/lib${MEDIATEX}"
+    CACHEDIR="${LOCALSTATEDIR}/cache${MEDIATEX}"
+    PIDDIR="${LOCALSTATEDIR}/run${MEDIATEX}"
+    SCRIPTS="${DATADIR}/scripts"
+    MISC="${DATADIR}/misc"
+    HOSTSSH="${SYSCONFDIR}/ssh"
 
     # overwrite recurent variables
-    GITBARE="${1}${GITBARE}"
-    MDTXHOME="${1}${MDTXHOME}"
-    MD5SUMS="${1}${MD5SUMS}"
-    CACHES="${1}${CACHES}"
-    EXTRACT="${1}${EXTRACT}"
-    GITCLT="${1}${GITCLT}"
-    JAIL="${1}${JAIL}"
-    HOMES="${1}${HOMES}"
-    HTDOCS="${1}${HTDOCS}"
-    MDTXGIT="${1}${MDTXGIT}"
-    CONFFILE="${1}${CONFFILE}"
-    PIDFILE="${1}${PIDFILE}"
+    GITBARE="${STATEDIR}/$MDTX"
+    MDTXHOME="${CACHEDIR}/$MDTX"
+    MD5SUMS="${MDTXHOME}${CONF_MD5SUMS}"
+    CACHES="${MDTXHOME}${CONF_CACHES}"
+    EXTRACT="${MDTXHOME}${CONF_EXTRACT}"
+    GITCLT="${MDTXHOME}${CONF_GITCLT}"
+    JAIL="${MDTXHOME}${CONF_JAIL}"
+    HOMES="${MDTXHOME}${CONF_HOME}"
+    MDTXGIT="${GITCLT}/$MDTX"
+    CONFFILE="${MDTXGIT}/$MDTX${CONF_CONFFILE}"
+    PIDFILE="${PIDDIR}/$MDTX${CONF_PIDFILE}"
 
-    UNIT_TEST_populate_datadir
+    if [ $(id -u) -eq 0 ]; then
+	UNIT_TEST_populate_datadir
+    fi
 }
 
 # so as to pass unit test easier
@@ -116,13 +116,14 @@ function UNIT_TEST_mrProper()
     sed $1 -i -e "s,^\(\[.*\):.*\],\1],"
 
     # hide base directories path
-    sed $1 -i \
-	-e "s,$SYSCONFDIR,SYSCONFDIR,g" \
-	-e "s,$LOCALSTATEDIR,LOCALSTATEDIR,g" \
-	-e "s,$DATAROOTDIR,DATAROOTDIR,g" \
-	-e "s,$BINDIR,BINDIR,g" \
-	-e "s,$EXEC_PREFIX,EXEC_PREFIX,g" \
-	-e "s,$PREFIX,PREFIX,g"
+    sed $1 -i -e "s,/var/ut/ut[0-9]-mdtx,,g"
+
+	# -e "s,$SYSCONFDIR,SYSCONFDIR,g" \
+	# -e "s,$LOCALSTATEDIR,LOCALSTATEDIR,g" \
+	# -e "s,$DATAROOTDIR,DATAROOTDIR,g" \
+	# -e "s,$BINDIR,BINDIR,g" \
+	# -e "s,$EXEC_PREFIX,EXEC_PREFIX,g" \
+	# -e "s,$PREFIX,PREFIX,g"
 
     # hide user and group numbers
     sed $1 -i -e "s,^\(.*:x:\).*:,\1XXX:,"
@@ -136,7 +137,7 @@ function UNIT_TEST_mrProper()
 	-e "s,^   [^ ]* \( master -> master\),   XXX..XXX \1," \
 	-e "s,^\(commit\).*,\1 XXX," \
 	-e "s,^\(\[master (commit racine) \)[^]]*,\1 XXX," \
-	-e "s,^\(\[master \)[^]]*,\1 XXX," \
+	-e "s,^\(\[master \)[^]]*,\1 XXX,"
 	
     # [master (commit racine) 1d93f9d]
     # [master 637f68c]
@@ -146,6 +147,14 @@ function UNIT_TEST_mrProper()
     
     # hide i386/amd64 defferences
     sed $1 -i -e "/^lib64$/ d"
+
+    # hide default SSH port
+    sed $1 -i -e "s,\(localhost\) $SSH_PORT,\1 22,"
+
+    # hide git id and versions differences
+    sed $1 -i -e "s,[0-9a-f]\{40\},XXXX,"
+    sed $1 -i -e "s,[0-9]* \(files changed\),XX \1,"
+    sed $1 -i -e "s,To ssh://ut4-mdtx-hello@localhost,To ssh://localhost,"
 }
 
 # this function switch on into the unit test mode
@@ -162,12 +171,11 @@ function UNIT_TEST_start()
     # log to stderr for tests
     LOG_FACILITY=file
     LOG_SEVERITY=debug
+    export LANG=C
 
     # root directory for tests requiering root user (jails...)
-    if [ $(id -u) -eq 0 ]; then
-	UNIT_TEST_ROOTDIR="/var/ut/$MDTX"
-	UNIT_TEST_push_root_directory $UNIT_TEST_ROOTDIR
-    fi
+    UNIT_TEST_ROOTDIR="/var/ut/$MDTX"
+    UNIT_TEST_push_root_directory $UNIT_TEST_ROOTDIR
 
     # backup stdout and stderr values
     exec 3>&1 4>&2
@@ -193,7 +201,7 @@ function UNIT_TEST_stop()
     [ -f $UNIT_TEST_EXPECTED ] || UNIT_TEST_EXPECTED="/dev/null"
     
     UNIT_TEST_mrProper scripts/$1.out
-    diff $UNIT_TEST_EXPECTED scripts/$1.out
+    diff -I known_hosts $UNIT_TEST_EXPECTED scripts/$1.out
 
     # only needed for check_as_root
     if [ $(id -u) -eq 0 ]; then
