@@ -71,11 +71,11 @@ USERS_coll_create_user $USER
 SSH_build_key $USER
 GIT_coll_import $USER
 SSH_bootstrapKeys $USER
-SSH_configure_client $USER "localhost" "22"
+SSH_configure_client $USER $DEFAULT_HOST $SSH_PORT
 JAIL_add_user $USER	
 
 ## remote login checks
-QUERY="ssh -o PasswordAuthentication=no ${USER}@localhost ls /"
+QUERY="ssh -o PasswordAuthentication=no ${USER}@$DEFAULT_HOST ls /"
 Info "su LABEL -c \"$QUERY\""
 su $USER -c "$QUERY" || Error "Cannot connect via ssh"
 
@@ -87,11 +87,11 @@ touch $CACHEDIR/$MDTX/cache/$USER/hello.txt
 chown $USER.$USER $CACHEDIR/$MDTX/cache/$USER/hello.txt
 
 CACHE="$CACHEDIR/$MDTX/tmp/$USER"
-QUERY="scp ${USER}@localhost:/var/cache/$USER/hello.txt $CACHE"
+QUERY="scp ${USER}@$DEFAULT_HOST:/var/cache/$USER/hello.txt $CACHE"
 
 Info "su USER -c \"$QUERY\""
 su $USER -c "$QUERY" || Error "Cannot copy via ssh"
-GIT_coll_checkout $USER $MDTX $COLL "localhost"
+GIT_coll_checkout $USER $MDTX $COLL $DEFAULT_HOST
     
 #echo "results :"
 #find $UNIT_TEST_ROOTDIR -ls |
