@@ -33,7 +33,7 @@
 
 ## demo
 DEBUG_SERVER=0
-SEVERITY_CLIENT="-s notice"
+SEVERITY_CLIENT="-s err"
 SEVERITY_SERVER="-s notice"
 
 ## debug
@@ -157,8 +157,8 @@ function mdtxConfigure()
     PORT=600${SERVER#serv}
 
     # replace localhost by 127.0.0.1 in configuration
-    sedInPlace "s/\(host.*\)localhost/\1127.0.0.1/" \
-	       /etc/mediatex/$SERVER.conf
+    #sedInPlace "s/\(host.*\)localhost/\1127.0.0.1/" \
+    #	       /etc/mediatex/$SERVER.conf
 
     # set dedicated socket port
     sedInPlace "s/6561/$PORT/" /etc/mediatex/$SERVER.conf
@@ -285,6 +285,7 @@ function cleanAll()
 	mdtxA "adm purge" $SERV
     done
     rm -f /tmp/test.nb
+    exit 0
 }
     
 # Configure and initialise server 1
@@ -296,7 +297,7 @@ function test1()
 	mdtxA "adm add user www-data"
 	mdtxConfigure
 	startInitdScript
-	finalQuestion "is http://localhost/~serv1/ correct ?"
+	finalQuestion "is http://127.0.0.1/~serv1/ correct ?"
     else
 	topo "Cleanup"
 	stopInitdScript
@@ -334,7 +335,7 @@ function test3()
     if [ "x$1" != "xclean" ]; then
 	topo "Create 'Hello' collection on server1"
 	startInitdScriptIfNeeded
-	mdtxA "adm add coll hello@localhost"
+	mdtxA "adm add coll hello@127.0.0.1"
 	mdtxP "make coll hello"
 	echo -ne "\n"
 	mdtxP "add supp iso1 to coll hello"
@@ -378,7 +379,7 @@ function test4()
 	stopInitdScript
 	rm -f ~serv1/md5sums/serv1-hello.md5
 	rm -fr ~serv1/cache/serv1-hello/logo*
-	rm -fr ~serv1/cache/serv1-hello/supports
+	rm -fr ~serv1/cache/serv1-hello/_supports
     fi
 }
 
@@ -406,7 +407,7 @@ function test5()
     else
 	topo "Cleanup"
 	rm -fr ~serv1/cache/serv1-hello/logo*
-	rm -fr ~serv1/cache/serv1-hello/supports
+	rm -fr ~serv1/cache/serv1-hello/_supports
 	mdtxP "srv quick scan"
 	echo -n "!> you may need to re-ask for the logo file"
 	echo " and give an email address."
@@ -421,9 +422,9 @@ function test6()
 	SIGN=$(md5sum $FILE | cut -d' ' -f 1)
 	SIGN=$SIGN:$(ls $FILE -l | cut -d' ' -f 5)
 	cat >/tmp/test.cat <<EOF
-Category "css": "drawing"
+Category "web": "drawing"
 
-Document "css": "css"
+Document "css": "web","drawing"
   With "designer" = "Me" ""
   $SIGN
 EOF
@@ -432,27 +433,71 @@ EOF
 	mdtxP "upload file $FILE catalog /tmp/test.cat to coll hello"
 	mdtxP "make coll hello"
 	finalQuestion "Please, browse score index and download mediatex.css"
-	[ $TEST_OK -eq 0 ] && return
-	
-	# clean extracted files (~test5) on cache for next tests
-	notice "remove supports and extract files"
-	#mdtxP "del supp iso1 from coll hello"
-	mdtxP "del supp /usr/share/mediatex/misc/logoP2.iso from coll hello"
-	rm -fr ~serv1/cache/serv1-hello/logo*
-	rm -fr ~serv1/cache/serv1-hello/supports
-	mdtxP "srv quick scan"
-	mdtxP "upgrade+"
     else
 	topo "Cleanup"
-	rm -fr ~serv1/cache/serv1-hello/incoming
+	rm -fr ~serv1/cache/serv1-hello/20??-??
 	mdtxP "srv quick scan"
 	sedInPlace "/(INC/, /)/ d" ~serv1-hello/git/extract000.txt
+	sedInPlace "/css/, /^$/ d" ~serv1-hello/git/catalog000.txt
 	reloadInitdScript
     fi
 }
 
-# Configure server 2 (as a private network gateway)
+# Upload a file from location
 function test7()
+{
+    if [ "x$1" != "xclean" ]; then
+	FILE=/usr/share/mediatex/misc/put.js
+	FP=$(grep -A2 Server ~serv1/git/serv1-hello/servers.txt | cut -d' ' -f2)
+	SIGN=$(md5sum $FILE | cut -d' ' -f 1)
+	SIGN=$SIGN:$(ls $FILE -l | cut -d' ' -f 5)
+	cat >/tmp/test.ext <<EOF
+(COPY $FP /usr/share/mediatex
+=>
+$SIGN misc/put.js
+)
+EOF
+	cat >/tmp/test.cat <<EOF
+Document "js": "web", "drawing"
+  With "designer" = "Me" ""
+  $SIGN
+EOF
+	topo "Upload file from location"
+	startInitdScriptIfNeeded
+	mdtxP "upload catalog /tmp/test.cat rules /tmp/test.ext to coll hello"
+	mdtxP "make coll hello"
+	finalQuestion "Please, browse score index and download put.js"
+    else
+	topo "Cleanup"
+	rm -f ~serv1/cache/serv1-hello/20??-??/put.js
+	mdtxP "srv quick scan"
+	sedInPlace "/(LOCATION/, /)/ d" ~serv1-hello/git/extract000.txt
+	sedInPlace "/js/, /^$/ d" ~serv1-hello/git/catalog000.txt
+	reloadInitdScript
+    fi
+}
+
+# Cleanup
+function test8()
+{
+    topo "Cleanup for next tests"
+    #sedInPlace "/(LOCATION/, /)/ d" ~serv1-hello/git/extract000.txt
+    #sedInPlace "/js/, /^$/ d" ~serv1-hello/git/catalog000.txt
+	
+    # clean extracted files (~test5) on cache for next tests
+    notice "remove supports and extract files"
+    #mdtxP "del supp iso1 from coll hello"
+    mdtxP "del supp /usr/share/mediatex/misc/logoP2.iso from coll hello"
+    rm -fr ~serv1/cache/serv1-hello/logo*
+    rm -fr ~serv1/cache/serv1-hello/_supports
+    
+    mdtxP "srv quick scan"
+    mdtxP "upgrade+"
+    TEST_NB=$[TEST_NB+1]
+}
+
+# Configure server 2 (as a private network gateway)
+function test9()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Configure server 2 (as a private network gateway)"
@@ -475,7 +520,7 @@ function test7()
 }
 
 # Register collection 'hello' on server 2
-function test8()
+function test10()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Register collection 'hello' on server 2"
@@ -485,12 +530,12 @@ function test8()
 	
 	# create serv2-hello key
 	notice "you will be ask twice for this fingerprint" \
-	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
+	       "ssh-keygen -l -f /etc/ssh/ssh_host_rsa_key.pub"
 	mdtxA "adm add coll serv1-hello" serv2
 	echo -ne "\n"
 
 	# register serv2-hello key on serv1
-	cp ~serv2/home/serv2-hello/.ssh/id_dsa.pub \
+	cp ~serv2/home/serv2-hello/.ssh/id_rsa.pub \
 	    /tmp/key
 	mdtxP "add key /tmp/key to coll hello" serv1
 
@@ -507,7 +552,6 @@ function test8()
 	    "grep -A2 Server ~serv1/git/serv1-hello/servers.txt"
     else
 	topo "Cleanup"
-
 	mdtxA "adm del coll hello" serv2
 	mdtxP "upgrade" serv1
 
@@ -523,7 +567,7 @@ function test8()
 
 # First server notify to second one you ask for an archive record
 # not yet available
-function test9()
+function test11()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Serv1 notify serv2 it is looking for the archive you ask"
@@ -554,7 +598,7 @@ function test9()
 }
 
 # server 2 provides first support and tell it to server 1
-function test10()
+function test12()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "server 2 provides first support and tell it to server 1"
@@ -565,7 +609,7 @@ function test10()
 	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso" serv2
 	mdtxP "motd" serv2
 	
-	question "motd do not ask for 'iso1' anymore" ""
+	question "motd does not ask for 'iso1' anymore" ""
 	[ $TEST_OK -eq 0 ] && return
 	mdtxP "srv notify" serv2
 
@@ -585,7 +629,7 @@ function test10()
 	mdtxP "del supp iso1" serv2
 	for SERV in serv1 serv2; do
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
-	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/_supports
 	    mdtxP "srv quick scan" $SERV
 	done
 	mdtxP "srv notify" serv2
@@ -593,8 +637,8 @@ function test10()
 }
 
 # Configure server 3 (inside a private network)
-# (close to test 7)
-function test11()
+# (close to test 11)
+function test13()
 {
     if [ "x$1" != "xclean" ]; then
         topo "Configure server 3 (from inside a private network)"
@@ -616,8 +660,8 @@ function test11()
 }
 
 # Register collection 'hello' on server 3
-# (close to test 8)
-function test12()
+# (close to test 12)
+function test14()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Register collection 'hello' on server 3"
@@ -627,12 +671,12 @@ function test12()
 	
 	# create serv3-hello key
 	notice "you will be ask twice for this fingerprint" \
-	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
+	       "ssh-keygen -l -f /etc/ssh/ssh_host_rsa_key.pub"
 	mdtxA "adm add coll serv1-hello" serv3
 	echo -ne "\n"
 
 	# register serv3-hello key on serv1
-	cp ~serv3/home/serv3-hello/.ssh/id_dsa.pub \
+	cp ~serv3/home/serv3-hello/.ssh/id_rsa.pub \
 	   /tmp/key
 	mdtxP "add key /tmp/key to coll hello" serv1
 
@@ -649,7 +693,6 @@ function test12()
 		      "grep -A2 Server ~serv1/git/serv1-hello/servers.txt"
     else
 	topo "Cleanup"
-
 	mdtxA "adm del coll hello" serv3
 	mdtxP "upgrade" serv1
 
@@ -664,8 +707,8 @@ function test12()
 }
 
 # First server notify to third one you ask for an archive record
-# not yet available (close to test 9)
-function test13()
+# not yet available (close to test 11)
+function test15()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Serv1 notify serv3 (via serv2) you ask for an archive record"
@@ -687,8 +730,8 @@ function test13()
 }
 
 # Server 3 provides second support and tell it to others
-# (close to test 10)
-function test14()
+# (close to test 12)
+function test16()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Server 3 provides second support and tell it to others"
@@ -726,7 +769,7 @@ function test14()
 }
 
 # Server 1 retrieve the archive and notify other it is no more looking for
-function test15()
+function test17()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Server 1 retrieve the archive"
@@ -753,8 +796,8 @@ function test15()
 }
 
 # Third server notify you ask for an archive record not yet available
-# (close to test 9)
-function test16()
+# (close to test 13)
+function test18()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Serv3 notify serv1 (via serv2) you ask for an archive record"
@@ -762,7 +805,7 @@ function test16()
 	for SERV in serv1 serv2 serv3; do
 	    stopInitdScript $SERV
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
-	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/_supports
 	    rm -f /var/cache/mediatex/$SERV/md5sums/$SERV-hello.md5
 	    startInitdScript $SERV
 	done
@@ -796,8 +839,8 @@ function test16()
 }
 
 # Server 1 provides first support and tell it to others
-# (close to test 10)
-function test17()
+# (close to test 14)
+function test19()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Server 1 provides first support and tell it to others"
@@ -829,7 +872,7 @@ function test17()
 	topo "Cleanup"
 	for SERV in serv1 serv2 serv3; do
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
-	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/_supports
 	    mdtxP "srv quick scan" $SERV
 	done
     fi	    
@@ -837,7 +880,7 @@ function test17()
 
 
 # GIT backup on server 1
-function test18()
+function test20()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "GIT backup on server 1"
@@ -851,14 +894,13 @@ function test18()
 	mdtxP "make" serv1
 
 	finalQuestion "does GITBARE is backuped ?"
-	[ $TEST_OK -eq 0 ] && return
     else
 	topo "Cleanup"
     fi
 }
 
 # Apache's logs backup on server 1
-function test19()
+function test21()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Apache's logs backup on server 1"
@@ -871,14 +913,13 @@ function test19()
 	mdtxP "make" serv1
 
 	finalQuestion "does Apache's logs are backuped ?"
-	[ $TEST_OK -eq 0 ] && return
     else
 	topo "Cleanup"
     fi
 }
 
 # Move GIT repository from serv1 to serv2
-function test20()
+function test22()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Move GIT repository from serv1 to serv2"
@@ -894,18 +935,17 @@ function test20()
 	[ $TEST_OK -eq 0 ] && return
 
 	notice "you will be ask for localhost fingerprint..." \
-	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
+	       "ssh-keygen -l -f /etc/ssh/ssh_host_rsa_key.pub"
 	mdtxA "adm add coll serv2-hello" serv1
 	question "connected to serv2 gitbare ?" \
 		 "grep url ~serv1/git/serv1-hello/.git/config"
 	[ $TEST_OK -eq 0 ] && return
 
 	notice "you will be ask for localhost fingerprint..." \
-	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
+	       "ssh-keygen -l -f /etc/ssh/ssh_host_rsa_key.pub"
 	mdtxA "adm add coll serv2-hello" serv3
 	finalQuestion "connected to serv2 gitbare ?" \
 		      "grep url ~serv3/git/serv3-hello/.git/config"
-	[ $TEST_OK -eq 0 ] && return
 	
 	rm -fr /var/lib/mediatex/serv1/serv1-hello
     else
@@ -918,7 +958,7 @@ function test20()
 }
 
 # Audit on server 1
-function test21()
+function test23()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Audit on server 1"
@@ -926,7 +966,7 @@ function test21()
 	sedInPlace "s/\(logAudit\) *\(.*\)/\1 yes/" \
 		   ~serv1-hello/git/servers.txt
 	read -p "Please enter your mail: " MAIL
-	mdtxP "audit coll hello for $MAIL" serv1
+	mdtxP "audit for $MAIL coll hello" serv1
 	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso"
 	mdtxP "serv save" serv1
 	cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'
@@ -939,12 +979,11 @@ function test21()
 	mdtxP "make" serv1
 
 	finalQuestion "do you receive the audit repport? (mail)"
-	[ $TEST_OK -eq 0 ] && return
     else
 	topo "Cleanup"
 	for SERV in serv1 serv2 serv3; do
 	    stopInitdScript $SERV
-	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports*
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/_supports*
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
 	    rm -f /var/cache/mediatex/$SERV/md5sums/$SERV-hello.md5
 	    startInitdScript $SERV
@@ -954,7 +993,7 @@ function test21()
 }
 
 # Make all functionnal for manuals tests
-function test22()
+function test24()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Make all functionnal for manuals tests"
@@ -964,14 +1003,16 @@ function test22()
 	done
 	mdtxP "serv notify" serv1
 	finalQuestion "All tests done ! Do you want to clean all ?"
-	[ $TEST_OK -eq 0 ] && return
-	cleanAll
-	exit 0	
     else
 	topo "Do not clean (you can run './tests.sh clean' to do it latter)"
     fi
 }
 
+function test25()
+{
+    cleanAll
+}
+
 ############################################
 # main function
 ############################################
@@ -991,15 +1032,19 @@ ps -ef | grep h[e]llo | grep -v http
 }
 
 # cleaning to restart tests from scratch
-if [ "x$1" = "xclean" ]; then
+if [ x"$1" = x"clean" ]; then
     cleanAll
-    exit 0
 fi
 
 # get the last failling test
 TEST_OK=1
 TEST_NB=1
 [ -f /tmp/test.nb ] && TEST_NB=$(cat /tmp/test.nb)
+[ $# -ge 1 ] && TEST_NB=$1
+if [ \( $# -eq 2 \) -a x"$2" = x"clean" ]; then
+    test$TEST_NB clean
+    exit 0
+fi
 
 if [ $DEBUG_SERVER -ne 0 ]; then
     xhost +
