@@ -25,7 +25,7 @@
 #set -x
 set -e
 
-QUERY="mediatex upload++"
+QUERY="mediatex upload+"
 
 USER=${PWD%/public_html/cgi}
 USER=${USER##*/}
