@@ -148,7 +148,7 @@ Archive $SIGN2
  "format" = "gz"
 EOF
 	    
-	    TARGETDIR="mediatex/audits"
+	    TARGETDIR="_mediatex/audits"
 	    cat >/tmp/$AUDIT.ext <<EOF
 (GZIP
 $SIGN2
@@ -157,7 +157,7 @@ $SIGN1 $TARGETDIR/$FILENAME
 )
 EOF
 
-	    mediatex -c $MDTX upload++ file $FILEPATH.gz as $TARGETDIR/ \
+	    mediatex -c $MDTX upload+ file $FILEPATH.gz as $TARGETDIR/ \
 		     catalog /tmp/$AUDIT.cat rules /tmp/$AUDIT.ext \
 		     to coll $COLL
 	    rm -f /tmp/$AUDIT.cat /tmp/$AUDIT.ext $FILEPATH.gz
