@@ -29,7 +29,7 @@ set -e
 [ ! -z $MDTX_SH_INCLUDE ]  || source $libdir/include.sh
 [ ! -z $MDTX_SH_GIT ]      || source $libdir/git.sh
 
-Debug "commit $1 $2"
+Debug "commit $1 '$2'"
 
 MODULE=$1
 COMMENT=$2
@@ -38,7 +38,6 @@ COMMENT=$2
 [ -z "$2" ] && Error "please provide a comment"
 [ "$(whoami)" == "$MODULE" ] || Error "need to be $MODULE user"
  
-GIT_commit $MODULE "$COMMENT" || 
-    Error $0 "cannot commit $MODULE git module"
+GIT_commit $MODULE "$COMMENT"
 
 Info "done"
