@@ -51,8 +51,8 @@ Document "git_$DATE": "backups"
  $SIGN
 EOF
 
-	    $BINDIR/mediatex -c $MDTX -swarning -p upload++ \
-		file $NAME.tgz as mediatex/backups/ \
+	    $BINDIR/mediatex -c $MDTX -swarning -p upload+ \
+		file $NAME.tgz as _mediatex/backups/ \
 		catalog $NAME.cat \
 		to coll $COLL
 	    
