@@ -28,6 +28,7 @@ set -e
 [ -z $libdir ] && libdir=$srcdir/lib
 [ ! -z $MDTX_SH_INCLUDE ]  || source $libdir/include.sh
 [ ! -z $MDTX_SH_USERS ]    || source $libdir/users.sh
+[ ! -z $MDTX_SH_JAIL ]     || source $libdir/jail.sh
 
 Debug "free"
 [ $(id -u) -eq 0 ] || Error "need to be root"
@@ -36,6 +37,7 @@ Debug "free"
 USER="$MDTX-$1"
 
 # changes into /var/lib and /var/cache
+JAIL_del_user $USER
 USERS_coll_remove_user $USER
 
 # do not purge the collection repository
