@@ -48,16 +48,29 @@ HTDOCS_configure_mdtx_cgit
 HTDOCS_configure_mdtx_apache2
 
 # only needed once
-/usr/sbin/a2enmod \
-    authz_core auth_digest authz_groupfile autoindex cgi env include \
-    rewrite userdir setenvif ssl
+APACHE_VERSION=$(dpkg -l apache2 | grep ii | awk '{print $3}' | cut -d'.' -f -2)
+/usr/sbin/a2enmod auth_digest autoindex env include rewrite \
+    userdir setenvif ssl
+if [ x$APACHE_VERSION == x"2.4" ]; then
+    /usr/sbin/a2enmod authz_core authz_groupfile
+    /usr/sbin/a2enconf mediatex
+else
+    /usr/sbin/a2enmod version
+    ln -sf ../conf-available/mediatex.conf \
+	/etc/apache2/conf.d/
+fi
+
 /usr/sbin/a2ensite default-ssl
-/usr/sbin/a2enconf mediatex
 /usr/sbin/invoke-rc.d rsyslog restart
 /sbin/ldconfig
 
 # mdtx config for apache
-/usr/sbin/a2enconf ${MEDIATEX#/}-$MDTX >/dev/null
+if [ x$APACHE_VERSION == x"2.4" ]; then
+    /usr/sbin/a2enconf ${MEDIATEX#/}-$MDTX >/dev/null
+else 
+    ln -sf ../conf-available/${MEDIATEX#/}-$MDTX.conf \
+	/etc/apache2/conf.d/
+fi
 
 # init script is run at startup for mdtx instance
 if [ $MDTX = mdtx ]; then
