@@ -105,7 +105,7 @@ function JAIL_build()
     rm -fr $JAIL
     USERS_install $JAIL "${_VAR_CACHE_M_MDTX_JAIL[@]}"
     mkdir -p $JAIL/{bin,dev,etc,tmp,usr/bin} #,proc,sys,dev/pts}
-    mkdir -p $JAIL/{var/cache,var/lib/gitbare,var/tmp}
+    mkdir -p $JAIL/{var/cache,var/lib/gitbare,var/tmp,var/opt}
 
     for i in $BINARIES; do
 	JAIL_add_binary $i;
@@ -131,6 +131,8 @@ function JAIL_build()
 
     # needed by git
     chmod 755 $JAIL/var/lib
+
+    # sandboxes (who know)
     chmod 777 $JAIL/tmp
     chmod 777 $JAIL/var/tmp
 
@@ -151,6 +153,9 @@ function JAIL_del_user()
     for FILE in /etc/passwd /etc/group; do
 	    sed -i -e "/^$1:/ d" ${JAIL}${FILE}
     done
+
+    # potentialy remove user external content
+    rm -fr ${JAIL}/var/opt/$1
 }
 
 # add a user to the jail
@@ -166,6 +171,9 @@ function JAIL_add_user()
 	sed -i -e "/^$1:/ d" ${JAIL}${FILE}
 	grep "^$1:" $FILE | cat >> ${JAIL}${FILE}
     done
+
+    # allow private scp into (out of mediatex scope)
+    install -o $MDTX -g $1 -m 0770 -d ${JAIL}/var/opt/$1
 }
 
 function JAIL_bind()
@@ -214,17 +222,24 @@ function JAIL_unbind()
     Debug $FUNCNAME 2
     [ $(id -u) -eq 0 ] || Error "need to be root"
 
-    [ $(grep -c $JAIL/var/cache /etc/mtab) -eq 0 ] || \
-	umount $JAIL/var/cache
-    [ $(grep -c $JAIL/var/lib/gitbare /etc/mtab) -eq 0 ] || \
-	umount $JAIL/var/lib/gitbare
+    if grep -q $JAIL/var/cache /etc/mtab; then
+	if ! umount $JAIL/var/cache; then
+	    Warning "Cannot unbind $JAIL/var/cache"
+	fi
+    fi
+	    
+    if grep -q $JAIL/var/lib/gitbare /etc/mtab; then
+	if ! umount $JAIL/var/lib/gitbare; then
+	    Warning "Cannot unbind $JAIL/var/lib/gitbare"
+	fi
+    fi
     
     # wait for umount
     DO_WAIT=1
     NB_WAIT=3
-    while [ $DO_WAIT -eq 1 -a $NB_WAIT -gt 0 ]; do
-        if [ $(grep -c $JAIL/var/cache /etc/mtab) -eq 0 -o \
-            $(grep -c $JAIL/var/lib/gitbare /etc/mtab) -eq 0 ]; then
+    while [ \( $DO_WAIT -eq 1 \) -a \( $NB_WAIT -gt 0 \) ]; do
+        if ! grep -q $JAIL/var/cache /etc/mtab && \
+		! grep -q $JAIL/var/lib/gitbare /etc/mtab; then
             DO_WAIT=0
         fi
         if [ $DO_WAIT -eq 1 ]; then
@@ -234,11 +249,13 @@ function JAIL_unbind()
         NB_WAIT=$[--NB_WAIT]
     done
 
-    [ $(grep -c $JAIL/var/cache /etc/mtab) -eq 0 ] ||
+    if grep -q $JAIL/var/cache /etc/mtab; then
 	Error "Cannot unbind $JAIL/var/cache"
+    fi
 
-    [ $(grep -c $JAIL/var/lib/gitbare /etc/mtab) -eq 0 ] || 
+    if grep -q $JAIL/var/lib/gitbare /etc/mtab; then
 	Error "Cannot unbind $JAIL/var/lib/gitbare"
+    fi						
 
     # not needed (but maybe later)
 
