@@ -110,7 +110,7 @@ function USERS_root_disease()
     # not needed as /var/run is now a tmpfs filesystem
     if [ $ALONE -eq 1 -a -d "$PIDDIR" ]; then
 	if [ $(ls $PIDDIR | wc -l) -eq 0 ]; then
-	    rmdir $DIR
+	    rmdir $PIDDIR
 	fi
     fi
 }
@@ -226,6 +226,7 @@ function USERS_mdtx_enable()
     ROTATE_DIR=$SYSCONFDIR/logrotate.d/httpd-prerotate
     ROTATE_FILE=$ROTATE_DIR/mediatex$POSTFIX
     INIT_FILE=$SYSCONFDIR/init.d/mediatexd$POSTFIX
+    INIT_VERSION=1
 
     # create the mdtx directories
     USERS_mdtx_populate
@@ -260,16 +261,19 @@ EOF
 	chmod +x $ROTATE_FILE
     fi
 
-    # init script for other instances than mdtx
-    if [ "$MDTX" != "mdtx" ]; then
-	if [ ! -f $INIT_FILE ]; then
-	    cp $SYSCONFDIR/init.d/mediatexd $INIT_FILE
-	    sed -i $INIT_FILE \
-		-e "s!\(# Provides:          mediatexd\)!\1$POSTFIX!" \
-		-e "s!USER=mdtx!USER=$MDTX!"
-	fi
+    # install init script
+    if [ -f /lib/init/init-d-script ]; then
+	INIT_VERSION=2
+    fi
+    if [ ! -f $INIT_FILE ]; then
+	cp $DATADIR/scripts/mediatexd$INIT_VERSION $INIT_FILE
 	chmod +x $INIT_FILE
     fi
+    if [ "$MDTX" != "mdtx" ]; then
+	sed -i $INIT_FILE \
+	    -e "s!\(# Provides:          mediatexd\)!\1$POSTFIX!" \
+	    -e "s!USER=mdtx!USER=$MDTX!"
+    fi
 }
 
 # this function unconfigure related services
@@ -290,10 +294,8 @@ function USERS_mdtx_disable()
     # unconfigure logrotate on apache logs
     rm -f $ROTATE_FILE
 
-    # remove init script for other instances than mdtx
-    if [ "$MDTX" != "mdtx" ]; then
-	rm -f $INIT_FILE
-    fi
+    # remove init script
+    rm -f $INIT_FILE
 }
 
 # this function disease a group
