@@ -65,7 +65,7 @@ Archive $SIGN2:$SIZE2
  "format" = "gz"
 EOF
 
-	    TARGETDIR="mediatex/access"
+	    TARGETDIR="_mediatex/access"
 	    /bin/cat >/tmp/$NAME.ext <<EOF
 (GZIP
 $SIGN2:$SIZE2
@@ -74,8 +74,8 @@ $SIGN1:$SIZE1 $TARGETDIR/$NAME.log
 )
 EOF
 	    
-	    $BINDIR/mediatex -c $MDTX -swarning -p upload++ \
-			     file /tmp/$NAME.log.gz as mediatex/backups/ \
+	    $BINDIR/mediatex -c $MDTX -swarning -p upload+ \
+			     file /tmp/$NAME.log.gz as _mediatex/access/ \
 			     catalog /tmp/$NAME.cat rules /tmp/$NAME.ext \
 			     to coll $COLL
 	    
