@@ -48,7 +48,7 @@ HOST=$(echo $TMP | cut -d ":" -f1)
 PORT=$(echo $TMP | cut -s -d ":" -f2)
 [ "$COLL" = "mdtx" ] && Error "collection cannot be labeled mdtx"
 [ -z "$SERV" ] && SERV=$MDTX
-[ -z "$HOST" ] && HOST="localhost"
+[ -z "$HOST" ] && HOST=$DEFAULT_HOST
 [ -z "$PORT" ] && PORT=22
 USER=$MDTX-$COLL
 MUSER=$SERV-$COLL
@@ -59,7 +59,7 @@ SSH_build_key $USER
 HTDOCS_configure_coll_apache2 $USER
 
 # setup a new repository if hosted localy (master host)
-if [ \( "$SERV" = "$MDTX" \) -a \( "$HOST" = "localhost" \) ]; then
+if [ \( "$SERV" = "$MDTX" \) -a \( "$HOST" = $DEFAULT_HOST \) ]; then
     SSH_bootstrapKeys $USER
     GIT_coll_import $USER
     JAIL_bind
@@ -72,6 +72,8 @@ JAIL_bind
 
 # test the connection
 set +e
+Info "su $USER"
+Info "ssh -o PasswordAuthentication=no $MUSER@$HOST ls"
 su $USER 2>/dev/null <<EOF 
 ssh -o PasswordAuthentication=no $MUSER@$HOST ls >/dev/null
 EOF
@@ -81,7 +83,7 @@ if [ $RC -ne 0 ]; then
     if [ $MDTX_KEY_HAVE_CHANGE -eq 1 ]; then
 	Notice "new public key"
     fi
-    Notice "public key: $HOMES/$USER$CONF_SSHDIR/id_dsa.pub"
+    Notice "public key: $HOMES/$USER$CONF_SSHDIR/id_rsa.pub"
     exit 0
 fi
 
