@@ -35,7 +35,6 @@ MODULE=$1
 [ -z $1 ] && Error "please provide a module"
 [ "$(whoami)" == "$MODULE" ] || Error "need to be $MODULE user"
 
-GIT_pull $MODULE ||
-    Error $0 "cannot pull $MODULE git module"
+GIT_pull $MODULE
 
 Info "done"
