@@ -40,11 +40,11 @@ Error "expect MDTX_MDTXUSER variable to be set by the environment"
 
 # only the init script for mdtx server is manage here
 if [ $MDTX = mdtx ]; then
-    invoke-rc.d ${MEDIATEX#/}d stop $MDTX
+    invoke-rc.d ${MEDIATEX#/}d stop $MDTX || true
     update-rc.d -f ${MEDIATEX#/}d remove
 fi
 
-JAIL_unbind
+JAIL_unbind || true
 SSH_chroot_login no
 
 USERS=$(grep "^$MDTX-" /etc/passwd | cut -d':' -f1) || true
@@ -55,12 +55,22 @@ done
 USERS_mdtx_remove_user
 ALONE=0
 USERS_root_disease
-if [ $ALONE -eq 1 ]; then
-    /usr/sbin/a2disconf mediatex
-fi
 
-if [ -f /etc/apache2/conf-enabled/${MEDIATEX#/}-$MDTX.conf ]; then
-    /usr/sbin/a2disconf ${MEDIATEX#/}-$MDTX
+APACHE_VERSION=$(dpkg -l apache2 | grep ii | awk '{print $3}' | cut -d'.' -f -2)
+if [ x$APACHE_VERSION == x"2.4" ]; then
+    if [ $ALONE -eq 1 ]; then
+	/usr/sbin/a2disconf mediatex
+    fi
+    if [ -h /etc/apache2/conf-enabled/${MEDIATEX#/}-$MDTX.conf ]; then
+	/usr/sbin/a2disconf ${MEDIATEX#/}-$MDTX
+    fi
+else
+    if [ $ALONE -eq 1 ]; then
+	rm -f /etc/apache2/conf.d/mediatex.conf
+    fi
+    if [ -h /etc/apache2/conf.d/${MEDIATEX#/}-$MDTX.conf ]; then
+	rm -f /etc/apache2/conf.d/${MEDIATEX#/}-$MDTX.conf	    
+    fi
 fi
 
 # undo apache configuration
@@ -69,7 +79,7 @@ HTDOCS_unconfigure_mdtx_apache2
 
 Notice "Please check if these apache modules are still needed:"
 Notice "* authz_core auth_digest authz_groupfile autoindex cgi env"
-Notice "* include rewrite userdir setenvif ssl"
+Notice "* include rewrite userdir setenvif ssl version"
 
 # do not purge the meta-data repository
 if [ -d $GITBARE ]; then
