@@ -36,7 +36,6 @@ MODULE=$1
 [ -z $1 ] && Error "please provide a module"
 [ "$(whoami)" == "$MODULE" ] || Error "need to be $MODULE user"
  
-GIT_push $MODULE || 
-    Error $0 "cannot push $MODULE git module"
+GIT_push $MODULE
 
 Info "done"
