@@ -39,7 +39,7 @@ Error "expect MDTX_MDTXUSER variable to be set by the environment"
 
 # only the init script for mdtx server is manage here
 if [ $MDTX = mdtx ]; then
-    invoke-rc.d ${MEDIATEX#/}d stop $MDTX
+    invoke-rc.d ${MEDIATEX#/}d stop $MDTX || true
 fi
 
 JAIL_unbind
