@@ -27,7 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 /*=======================================================================
  * Function   : getItemUri
  * Description: compute ending path for an item (not a list)
- * Synopsis   : int catItemUri(char* buf, int id)
+ * Synopsis   : int getItemUri(char* buf, int id)
  *              int id = number use to compute page location
  *              char* suffix = ".shtml" or "/header.shtml"
  * Output     : char* buf = where to write the Uri
@@ -168,16 +168,17 @@ int getArchiveUri2(char* buf, char* path, int id)
 }
 
 /*=======================================================================
- * Function   : getArchiveListUri
+ * Function   : getArchiveContentListUri
  * Description: Get relative path to archive list page
- * Synopsis   : int getArchiveListUri(char* buf, char* path, int id) 
+ * Synopsis   : int getArchiveContentListUri(char* buf, char* path, 
+ *                                           int id) 
  *              char* path = path to use as prefix
  *              int id = number use to compute page location
  * Output     : char* buf = the Uri
  *              TRUE on success
  =======================================================================*/
 int 
-getContentListUri(char* buf, char* path, int archId, int listId) 
+getArchiveContentListUri(char* buf, char* path, int archId, int listId) 
 {
   int rc = FALSE;
 
@@ -202,7 +203,7 @@ int getArchiveUri(char* buf, char* path, Archive* archive)
 
   if (archive->toContainer &&
       avl_count(archive->toContainer->childs) > MAX_INDEX_PER_PAGE) {
-    rc = getContentListUri(buf, path, archive->id, 1);
+    rc = getArchiveContentListUri(buf, path, archive->id, 1);
   }
   else {
     rc = getArchiveUri1(buf, path, archive->id);
@@ -211,6 +212,89 @@ int getArchiveUri(char* buf, char* path, Archive* archive)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : getLocationUri1
+ * Description: Get relative path to location page
+ * Synopsis   : int getLocationUri1(char* buf, char* path, int id) 
+ *              char* path = path to use as prefix
+ *              int id = number use to compute page location
+ * Output     : char* buf = the Uri
+ *              TRUE on success
+ =======================================================================*/
+int getLocationUri1(char* buf, char* path, int id) 
+{
+  int rc = FALSE;
+
+  rc = getRelativeUri(buf, path, "locations");
+  if (rc && id >= 0) 
+    rc = getItemUri(buf + strlen(buf), id, ".shtml");
+
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : getLocationUri2
+ * Description: Get relative path to an location directory
+ * Synopsis   : int getLocationUri2(char* buf, char* path, int id) 
+ *              char* path = path to use as prefix
+ *              int id = number use to compute page location
+ * Output     : char* buf = the Uri
+ *              TRUE on success
+ =======================================================================*/
+int getLocationUri2(char* buf, char* path, int id)
+{
+  int rc = FALSE;
+
+  rc = getLocationUri1(buf, path, -1);
+  if (rc) rc = getItemUri(buf + strlen(buf), id, "");
+
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : getLocationContentListUri
+ * Description: Get relative path to location list page
+ * Synopsis   : int getLocationContentListUri(char* buf, char* path, 
+ *                                            int id) 
+ *              char* path = path to use as prefix
+ *              int id = number use to compute page location
+ * Output     : char* buf = the Uri
+ *              TRUE on success
+ =======================================================================*/
+int 
+getLocationContentListUri(char* buf, char* path, int archId, int listId) 
+{
+  int rc = FALSE;
+
+  rc = getLocationUri2(buf, path, archId);
+  if (rc) rc = getListUri(buf + strlen(buf), listId);
+
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : getLocationUri
+ * Description: Get relative path to location page
+ * Synopsis   : int getLocationUri(char* buf, char* path, int id) 
+ *              char* path = path to use as prefix
+ *              int id = number use to compute page location
+ * Output     : char* buf = the Uri
+ *              TRUE on success
+ =======================================================================*/
+int getLocationUri(char* buf, char* path, Location* location) 
+{
+  int rc = FALSE;
+
+  if (avl_count(location->childs) > MAX_INDEX_PER_PAGE) {
+    rc = getLocationContentListUri(buf, path, location->id, 1);
+  }
+  else {
+    rc = getLocationUri1(buf, path, location->id);
+  }
+ 
+  return rc;
+}
+
 /*=======================================================================
  * Function   : getDocumentUri
  * Description: Get relative path to document page
@@ -717,7 +801,7 @@ serializeHtmlFooter(Collection* coll)
   FILE* fd = stdout;
   time_t now = 0;
   struct tm date;
-  char string[11];
+  char string[MAX_SIZE_HOST+16];
 
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/footer.html"))) goto error;
