@@ -43,7 +43,7 @@ mdtxAddCollection(Collection* coll)
   int rc = FALSE;
   Configuration* conf = 0;
   Collection* self = 0;
-  char buf[MAX_SIZE_COLL + MAX_SIZE_HOST + 8];
+  char buf[MAX_SIZE_COLL + MAX_SIZE_HOST + 20];
   char* argv[3] = {0, 0, 0};
   char* gitFile = 0;
   struct stat sb;
@@ -60,7 +60,7 @@ mdtxAddCollection(Collection* coll)
 
   // default value to localhost (first) if not provided
   if (isEmptyString(coll->masterHost)) {
-    strncpy(coll->masterHost, "localhost", MAX_SIZE_HOST);
+    strncpy(coll->masterHost, DEFAULT_HOST, MAX_SIZE_HOST);
   }
 
   // call script in order to eventually repare collection
