@@ -64,11 +64,50 @@ int getBadListUri(char* buf, char* path, int id)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : getBadListUri
+ * Description: Get relative path to images's list page
+ * Synopsis   : int getImageListUri(char* buf, char* path, int id) 
+ *              char* path = path to use as prefix
+ *              int id = number use to compute page location
+ * Output     : char* buf = the Uri
+ *              TRUE on success
+ =======================================================================*/
+static 
+int getImageListUri(char* buf, char* path, int id) 
+{
+  int rc = FALSE;
+
+  rc = getRelativeUri(buf, path, "imageLists");
+  if (rc && id > 0) rc = getListUri(buf + strlen(buf), id);
+
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : getLocationListUri
+ * Description: Get relative path to location's list page
+ * Synopsis   : int getLocationListUri(char* buf, char* path, int id) 
+ *              char* path = path to use as prefix
+ *              int id = number use to compute page location
+ * Output     : char* buf = the Uri
+ *              TRUE on success
+ =======================================================================*/
+static 
+int getLocationListUri(char* buf, char* path, int id) 
+{
+  int rc = FALSE;
+
+  rc = getRelativeUri(buf, path, "locationLists");
+  if (rc && id > 0) rc = getListUri(buf + strlen(buf), id);
+
+  return rc;
+}
 
 /*=======================================================================
  * Function   : htmlFromAsso
  * Description: HTML for FromAsso.
- * Synopsis   : static int serializeHtmlFromAsso(
+ * Synopsis   : static int htmlFromAsso(
  *                               FromAsso* self, FILE* fd, int isHeader)
  * Input      : FromAsso* self: what to latexalize
  *              FILE* fd: where to latexalize
@@ -130,6 +169,62 @@ htmlFromAsso(FromAsso* self, FILE* fd, int isHeader)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : htmlLocationAsso
+ * Description: HTML for LocationAsso.
+ * Synopsis   : static int serializeHtmlLocationAsso(Collection* coll,
+ *                           LocationAsso* self, FILE* fd, int isHeader)
+ * Input      : LocationAsso* self: what to latexalize
+ *              Collection* coll
+ *              FILE* fd: where to latexalize
+ *              int isHeader:
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+htmlLocationAsso(Collection* coll, LocationAsso* self,
+		 FILE* fd, int isHeader)
+{
+  int rc = FALSE;
+  Location* location = 0;
+  Server* server = 0;
+  char url[64];
+  char text[640];
+
+  if(self == 0) goto error;
+  logMain(LOG_DEBUG, "htmlLocationAsso");
+
+  location = self->location;
+  if (!(server = getServer(coll, location->fingerPrint))) {
+    logMain(LOG_ERR, "fails to get server %s", location->fingerPrint);
+    goto error;
+  }
+  
+  htmlLiOpen(fd);
+  htmlItalic(fd, self->path?self->path:"??");
+  if (!fprintf(fd, _(" from "))) goto error;
+  if (!sprintf(text, "%s %s:%s",
+	       strLType(location->type), server->host, location->uri))
+    goto error;
+  
+  // do not sort !
+  if (isHeader) {
+    getLocationUri(url, "../../../..", location);
+  } else {
+    getLocationUri(url, "../..", location);
+  }
+
+  htmlLink(fd, 0, url, text);    
+  htmlLiClose(fd); 
+  if (!fprintf(fd, "\n")) goto error;
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "htmlLocationAsso fails");
+  }
+  return rc;
+}
+
 
 /*=======================================================================
  * Function   : htmlContainer
@@ -139,7 +234,7 @@ htmlFromAsso(FromAsso* self, FILE* fd, int isHeader)
  *              FILE* fd: where to latexalize
  * Output     : TRUE on success
  =======================================================================*/
-int
+static int
 htmlContainer(Container* self, FILE* fd)
 {
   int rc = FALSE;
@@ -156,8 +251,6 @@ htmlContainer(Container* self, FILE* fd)
 
   fprintf(fd, "%s ", strEType(self->type));
   if (many) fprintf(fd, "%s", getContainerScore(self));
-
-  // do not sort !
   if (many) htmlUlOpen(fd);
 
   for(node = self->childs->head; node; node = node->next) {
@@ -184,9 +277,9 @@ htmlContainer(Container* self, FILE* fd)
 }
 
 /*=======================================================================
- * Function   : serializeHtmlContentList
- * Description: Latexalize aa archive content list.
- * Synopsis   : int serializeHtmlContentList(Collection* coll,
+ * Function   : serializeHtmlArchiveContentList
+ * Description: Latexalize an archive content list.
+ * Synopsis   : int serializeHtmlArchiveContentList(Collection* coll,
  *                                                       int i, int n)
  * Input      : Collection* coll
  *              int i = current archive list
@@ -194,7 +287,7 @@ htmlContainer(Container* self, FILE* fd)
  * Output     : TRUE on success
  =======================================================================*/
 static int
-serializeHtmlContentList(Collection* coll, AVLNode **node,
+serializeHtmlArchiveContentList(Collection* coll, AVLNode **node,
 			 int archId, int i, int n)
 {
   int rc = FALSE;
@@ -206,7 +299,7 @@ serializeHtmlContentList(Collection* coll, AVLNode **node,
   char text[128];
   int j = 0;
 
-  getContentListUri(url, "/", archId, i);
+  getArchiveContentListUri(url, "/", archId, i);
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
@@ -253,7 +346,7 @@ serializeHtmlContentList(Collection* coll, AVLNode **node,
   }
  error:
   if (!rc) {
-    logMain(LOG_ERR, "serializeHtmlContentList fails");
+    logMain(LOG_ERR, "serializeHtmlArchiveContentList fails");
   }
   path = destroyString(path);
   return rc;
@@ -276,6 +369,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   AssoCarac *assoCarac = 0;
   Document* document = 0;
   FromAsso* asso = 0;
+  LocationAsso* locAsso = 0;
   Image* image = 0;
   AVLNode *node = 0;
   FILE *fd = stdout;
@@ -304,7 +398,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   if (isHeader) {
     home = headerHome;
 
-    // make dir archive/0000/000
+    // make dir archives/0000/000
     getArchiveUri2(url, "/", self->id);
     if (!(path = createString(coll->htmlScoreDir))) goto error;
     if (!(path = catString(path, url))) goto error;
@@ -317,8 +411,8 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   }
   
   // serialize the archive shtml file. May be
-  // - archive/0000/000.shtml or
-  // - archive/0000/000/header.shtml
+  // - archives/0000/000.shtml or
+  // - archives/0000/000/header.shtml
   if (!isHeader) {
     getArchiveUri1(url, "/", self->id);
   } else {
@@ -422,7 +516,8 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   if (!fprintf(fd, _("\nComes from:\n"))) goto error;
   htmlUlOpen(fd);
   if (!isEmptyRing(self->fromContainers)) {
-    // already sorted
+    // already sorted (do not remind why)
+    //if (!rgSort(self->fromContainers, cmpContainer)) goto error;
     rgRewind(self->fromContainers);
     while ((asso = rgNext(self->fromContainers))) {
       htmlFromAsso(asso, fd, isHeader);
@@ -448,6 +543,13 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
       htmlLiClose(fd);
     }
   }
+  if (!isEmptyRing(self->fromLocations)) {
+    // already sorted ?
+    rgRewind(self->fromLocations );
+    while ((locAsso = rgNext(self->fromLocations))) {
+      htmlLocationAsso(coll, locAsso, fd, isHeader);
+    }
+  }
   htmlUlClose(fd);
   htmlPClose(fd);
 
@@ -457,6 +559,9 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   htmlUlOpen(fd);
 
   if (isHeader) {
+    fprintf(fd, "%s ", strEType(self->toContainer->type));
+    fprintf(fd, "%s", getContainerScore(self->toContainer));
+    
     // - when included from content list as header
     path = destroyString(path);
     getArchiveUri2(url, "/", self->id);
@@ -470,7 +575,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
     // serialize content lists
     node = self->toContainer->childs->head;
     for (i=1 ; i<=n; ++i) {
-      if (!serializeHtmlContentList(coll, &node, self->id, i, n))
+      if (!serializeHtmlArchiveContentList(coll, &node, self->id, i, n))
   	goto error;
     }
   }
@@ -507,6 +612,294 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   return rc;
 }
 
+
+/*=======================================================================
+ * Function   : htmlLocation
+ * Description: HTML for location.
+ * Synopsis   : int htmlLocation(Location* self, FILE* fd)
+ * Input      : Location* self: what to latexalize
+ *              FILE* fd: where to latexalize
+ * Output     : TRUE on success
+ =======================================================================*/
+static int
+htmlLocation(Location* self, FILE* fd)
+{
+  int rc = FALSE;
+  LocationAsso* asso = 0;
+  AVLNode *node = 0;
+  int many = FALSE;
+  char url [128];
+
+  if(self == 0) goto error;
+  logMain(LOG_DEBUG, "htmllocation");
+
+  many = (avl_count(self->childs) > 1);
+  htmlLiOpen(fd);
+
+  fprintf(fd, "%s ", strLType(self->type));
+  if (many) htmlUlOpen(fd);
+
+  for(node = self->childs->head; node; node = node->next) {
+    asso = node->item;
+
+    getArchiveUri(url, "../..", asso->archive);
+    if (many) htmlLiOpen(fd);
+    htmlLink(fd, 0, url, getArchiveScore(asso->archive));
+    if (!fprintf(fd, "%s", " ")) goto error;
+    htmlItalic(fd, asso->path);
+    if (many) htmlLiClose(fd);
+  }
+
+  if (many) htmlUlClose(fd);
+  htmlLiClose(fd);
+  if (!fprintf(fd, "\n")) goto error;
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "htmlLocation fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : serializeHtmlLocationContentList
+ * Description: Latexalize an location content list.
+ * Synopsis   : int serializeHtmlLocationContentList(Collection* coll,
+ *                                                       int i, int n)
+ * Input      : Collection* coll
+ *              int i = current location list
+ *              int n = last location list
+ * Output     : TRUE on success
+ =======================================================================*/
+static int
+serializeHtmlLocationContentList(Collection* coll, AVLNode **node,
+			 int archId, int i, int n)
+{
+  int rc = FALSE;
+  LocationAsso* asso = 0;
+  Archive* archive = 0;
+  FILE *fd = stdout;
+  char *path = 0;
+  char url[128];
+  char text[128];
+  int j = 0;
+
+  getLocationContentListUri(url, "/", archId, i);
+  if (!(path = createString(coll->htmlScoreDir))) goto error;
+  if (!(path = catString(path, url))) goto error;
+
+  logMain(LOG_DEBUG, "serialize %s", path);
+  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    goto error;
+  }
+
+  fprintf(fd, "<!--#include virtual='../header.shtml' -->");
+  htmlPOpen(fd);
+  htmlUlOpen(fd);
+
+  if (!serializeHtmlListBar(coll, fd, i, n)) goto error;
+
+  for (j = 0; j < MAX_INDEX_PER_PAGE && *node; ++j) {
+    asso = (*node)->item;
+    archive = asso->archive; // the content
+
+    getArchiveUri(url, "../../../..", archive);
+    if (!sprintf(text, "%s:%lli ", archive->hash,
+		 (long long int)archive->size)) goto error;
+
+    htmlLiOpen(fd);
+    htmlVerb(fd, text);
+    htmlLink(fd, 0, url, getArchiveScore(archive));
+    htmlLiClose(fd);
+
+    *node = (*node)->next;
+  }
+
+  if (!serializeHtmlListBar(coll, fd, i, n)) goto error;
+
+  htmlUlClose(fd);
+  htmlPClose(fd);
+  htmlSSIFooter(fd, "../../../../..");
+
+  ++env.progBar.cur;
+  rc = TRUE;
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlLocationContentList fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : serializeHtmlLocation
+ * Description: Latexalize a Location.
+ * Synopsis   : int serializeHtmlLocation(Collection* coll, Location* self)
+ * Input      : Collection* coll
+ *              Location* self = what to latexalize
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlLocation(Collection* coll, Location* self)
+{
+  int rc = FALSE;
+  Configuration* conf = 0;
+  Server* server = 0;
+  AVLNode *node = 0;
+  FILE *fd = stdout;
+  char *path = 0;
+  char url[512];
+  char text[640];
+  int isHeader = FALSE;
+  char mainHome[] = "../..";
+  char headerHome[] = "../../../..";
+  char* home = mainHome;
+  int nb = 0, n = 0, i = 0;
+
+  checkLocation(self);
+  if (!(conf = getConfiguration())) goto error;
+
+  // have to manage 2 cases :
+  // - when use as main page
+  // - when included from content list as header
+
+  // if we need lists for the contents or not
+  isHeader = ((nb = avl_count(self->childs))
+  	      > MAX_INDEX_PER_PAGE);
+
+  if (isHeader) {
+    home = headerHome;
+
+    // make dir locations/0000/000
+    getLocationUri2(url, "/", self->id);
+    if (!(path = createString(coll->htmlScoreDir))) goto error;
+    if (!(path = catString(path, url))) goto error;
+    if (mkdir(path, 0755)) {
+      if (errno != EEXIST) {
+    	logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
+    	goto error;
+      }
+    }
+  }
+  
+  // serialize the location shtml file. May be
+  // - locations/0000/000.shtml or
+  // - locations/0000/000/header.shtml
+  if (!isHeader) {
+    getLocationUri1(url, "/", self->id);
+  } else {
+    getLocationUri2(url, "/", self->id);
+    sprintf(url + strlen(url), "%s", "/header.shtml");
+    path = destroyString(path);
+  }
+  if (!(path = createString(coll->htmlScoreDir))) goto error;
+  if (!(path = catString(path, url))) goto error;
+  logMain(LOG_DEBUG, "serialize %s", path);
+  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    goto error;
+  }
+  
+  if (isHeader) {
+    htmlSSIHeader2(fd, "../../../..", "score");
+  } else {
+    htmlSSIHeader(fd, "../../..", "score");
+  }
+
+  if (!(server = getServer(coll, self->fingerPrint))) {
+    logMain(LOG_ERR, "fails to get server %s", self->fingerPrint);
+    goto error;
+  }
+  if (!sprintf(text, "%s %s:%s",
+	       strLType(self->type), server->host, self->uri))
+    goto error;
+
+  htmlPOpen(fd);
+  htmlBold(fd, _("Location: "));
+  htmlVerb(fd, text);
+  htmlBr(fd);
+ 
+  // servers
+  htmlPOpen(fd);
+  if ((strcmp(self->fingerPrint, "ALL"))) {
+    if (!fprintf(fd, _("\nProvided by server:\n"))) goto error;
+    htmlUlOpen(fd);
+    if (!sprintf(text, "%s/servers/srv_%s.shtml",
+		 home, server->fingerPrint)) goto error;
+    htmlLiOpen(fd);
+    htmlLink(fd, 0, text, server->host);
+    htmlLiClose(fd);
+    htmlUlClose(fd);
+  }
+  else {
+    if (!fprintf(fd, _("\nProvided by all servers:\n"))) goto error;
+  }
+  htmlPClose(fd);
+ 
+  // to
+  htmlPOpen(fd);
+  if (!fprintf(fd, _("\nContent: %i\n"), nb)) goto error;
+  htmlUlOpen(fd);
+
+  if (isHeader) {
+    // - when included from content list as header
+    path = destroyString(path);
+    getLocationUri2(url, "/", self->id);
+    if (!(path = createString(coll->htmlScoreDir))) goto error;
+    if (!(path = catString(path, url))) goto error;
+
+    // make content list directories: location/0000/000/0000
+    n = (nb - 1) / MAX_INDEX_PER_PAGE +1;
+    if (!htmlMakeDirs(path, n)) goto error;
+    
+    // serialize content lists
+    node = self->childs->head;
+    for (i=1 ; i<=n; ++i) {
+      if (!serializeHtmlLocationContentList(coll, &node, self->id, i, n))
+  	goto error;
+    }
+  }
+  else {
+    // - when use as main page
+    if (avl_count(self->childs)) {
+      htmlLocation(self, fd);
+    } else {
+      htmlLiOpen(fd);
+      if (!fprintf(fd, _("No content\n"))) goto error;
+      htmlLiClose(fd);
+    }
+  }
+
+  htmlUlClose(fd);
+  htmlPClose(fd);
+
+  if (!isHeader) {
+    htmlSSIFooter(fd, "../../..");
+  }
+  
+  ++env.progBar.cur;
+  rc = TRUE;
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlLocation fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
 /*=======================================================================
  * Function   : serializeHtmlServer
  * Description: HTML page for Server
@@ -523,10 +916,12 @@ serializeHtmlServer(Collection* coll, Server* server)
   char* path = 0;
   char* string = 0;
   Image* image = 0;
+  Location* location = 0;
   RGIT* curr = 0;
   char url[128];
-  char text[128];
+  char text[640];
   char score[8];
+  int nbLoc = 0;
   struct tm date;
 
   checkServer(server);
@@ -646,6 +1041,32 @@ serializeHtmlServer(Collection* coll, Server* server)
     htmlPClose(fd);
   }
 
+  // locations
+  while ((location = rgNext_r(coll->extractTree->locations, &curr))) {    
+    if (!(strcmp(location->fingerPrint, server->fingerPrint))) ++nbLoc;
+  }
+  if (nbLoc) {
+    htmlPOpen(fd);
+    if (!fprintf(fd, _("Provide locations: %i\n"), nbLoc)) 
+      goto error;
+    htmlUlOpen(fd);
+				    
+    curr = 0;
+    while ((location = rgNext_r(coll->extractTree->locations, &curr))) {
+      if (strcmp(location->fingerPrint, server->fingerPrint)) continue;
+      getLocationUri(url, "..", location);
+      if (!sprintf(text, "%s %s:%s", strLType(location->type),
+		 server->host, location->uri))
+      goto error;
+  
+      htmlLiOpen(fd);
+      htmlLink(fd, 0, url, text);
+      htmlLiClose(fd);
+    }
+    htmlUlClose(fd);
+    htmlPClose(fd);
+  }
+  
   htmlSSIFooter(fd, "../..");
 
   rc = TRUE;
@@ -759,7 +1180,7 @@ serializeHtmlArchiveLists(Collection* coll)
 
   logMain(LOG_DEBUG, "serializeHtmsScoreLists");
 
-  nb = avl_count(coll->archives);
+  nb = coll->maxId;
   if (!getArchiveListUri(tmp, "/", 0)) goto error;
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, tmp))) goto error;
@@ -783,7 +1204,8 @@ serializeHtmlArchiveLists(Collection* coll)
   htmlSSIHeader2(fd, "../..", "score");
   htmlPOpen(fd);
   htmlBold(fd, _("All archives"));
-  if (!fprintf(fd, " : %i", nb)) goto error;
+  // nb may be greater
+  if (!fprintf(fd, " : %i", avl_count(coll->archives))) goto error;
   htmlBr(fd);
   htmlPClose(fd);
 
@@ -825,11 +1247,11 @@ serializeHtmlArchiveLists(Collection* coll)
 
 /*=======================================================================
  * Function   : serializeHtmlBadList
- * Description: Latexalize an Document list.
- * Synopsis   : int serializeHtmlDocList(Collection* coll, int i, int n)
+ * Description: Latexalize an bad archive list.
+ * Synopsis   : int serializeHtmlBadList(Collection* coll, int i, int n)
  * Input      : Collection* coll
- *              int i = current document list
- *              int n = last document list
+ *              int i = current bad archive list
+ *              int n = last bad archive list
  * Output     : TRUE on success
  =======================================================================*/
 static int 
@@ -1005,6 +1427,345 @@ serializeHtmlBadLists(Collection* coll)
   return rc;
 }
 
+
+/*=======================================================================
+ * Function   : serializeHtmlImageList
+ * Description: Latexalize an image list.
+ * Synopsis   : int serializeHtmlImageList(Collection* coll, int i, int n)
+ * Input      : Collection* coll
+ *              int i = current image list
+ *              int n = last image list
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlImageList(Collection* coll, RG* ring, int i, int n)
+{
+  int rc = FALSE;
+  Archive* archive = 0;
+  FILE *fd = stdout;
+  char *path = 0;
+  char url[128];
+  char text[128];
+  int j = 0;
+
+  checkCollection(coll);
+
+  getImageListUri(url, "/", i);
+  if (!(path = createString(coll->htmlScoreDir))) goto error;
+  if (!(path = catString(path, url))) goto error;
+
+  logMain(LOG_DEBUG, "serialize %s", path);
+  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    goto error;
+  }  
+
+  fprintf(fd, "<!--#include virtual='../header.shtml' -->");
+  if (!ring) goto end; // empty page if needed
+
+  htmlPOpen(fd);
+  if (!serializeHtmlListBar(coll, fd, i, n)) goto error;
+
+  htmlUlOpen(fd);
+  archive = rgCurrent(ring);
+  for (j = 0; j < MAX_INDEX_PER_PAGE && archive; ++j) {
+
+    getArchiveUri(url, "../..", archive);
+    if (!sprintf(text, "%s:%lli ", archive->hash,
+		 (long long int)archive->size)) goto error;
+
+    htmlLiOpen(fd);
+    htmlVerb(fd, text);
+    htmlLink(fd, 0, url, getArchiveScore(archive));
+    htmlLiClose(fd);
+
+    archive = rgNext(ring);
+  }
+  htmlUlClose(fd);
+
+  if (!serializeHtmlListBar(coll, fd, i, n)) goto error;
+  htmlPClose(fd);
+ end:
+  htmlSSIFooter(fd, "../../..");
+
+  ++env.progBar.cur;
+  rc = TRUE;
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlImageList fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : serializeHtmlImageLists
+ * Description: HTML index page
+ * Synopsis   : int 
+ * Input      : ExtractTree* self = context
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlImageLists(Collection* coll)
+{ 
+  int rc = FALSE;
+  ServerTree* serverTree = 0;
+  FILE* fd = stdout;
+  char tmp[128];
+  char* path = 0;
+  char* path2 = 0;
+  int nb = 0;
+  int i = 0;
+  int n = 0;
+
+  logMain(LOG_DEBUG, "serializeHtmsImagesLists");
+  if (!(serverTree = coll->serverTree)) goto error;
+  
+  nb = serverTree->archives->nbItems;
+  
+  if (!getImageListUri(tmp, "/", 0)) goto error;
+  if (!(path = createString(coll->htmlScoreDir))) goto error;
+  if (!(path = catString(path, tmp))) goto error;
+
+  // build the directory
+  if (mkdir(path, 0755)) {
+    if (errno != EEXIST) {
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      goto error;
+    }
+  }
+  // serialize header file for the image list
+  if (!(path2 = createString(path))) goto error;
+  if (!(path2 = catString(path2, "/header.shtml"))) goto error;
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
+  if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    goto error;
+  }
+  
+  htmlSSIHeader2(fd, "../..", "score");
+  htmlPOpen(fd);
+  htmlBold(fd, _("Images"));
+  if (!fprintf(fd, " : %i", nb)) goto error;
+  htmlBr(fd);
+  htmlPClose(fd);
+  
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+
+  // sort ring
+  if (!rgSort(serverTree->archives, cmpArchive)) goto error;
+
+  // get the total number of lists of documents
+  n = (nb - 1) / MAX_INDEX_PER_PAGE +1;
+  logMain(LOG_DEBUG, "have %i images, so %i lists", nb, n);
+
+  // build lists sub-directories (group by MAX_FILES_PER_DIR)
+  if (!htmlMakeDirs(path, n)) goto error;
+  
+  // serialize lists
+  rgHead(serverTree->archives); // set current image to the first one
+  for (i=1 ; i<=n; ++i) {
+    if (!serializeHtmlImageList(coll, serverTree->archives, i, n)) goto error;
+  }
+
+  // empty list if needed
+  if (n == 0) {
+    if (!htmlMakeDirs(path, 1)) goto error;
+    if (!serializeHtmlImageList(coll, 0, 1, 0)) goto error;
+  }
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlImageLists fails");
+  }
+  path = destroyString(path);
+  path2 = destroyString(path2);
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : serializeHtmlLocationList
+ * Description: Latexalize an location list.
+ * Synopsis   : int serializeHtmlLocationList(Collection* coll, int i, int n)
+ * Input      : Collection* coll
+ *              RG* ring of locations
+ *              int i = current location list
+ *              int n = last location list
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlLocationList(Collection* coll, RG* ring, int i, int n)
+{
+  int rc = FALSE;
+  Location* location = 0;
+  Server* server = 0;
+  FILE *fd = stdout;
+  char *path = 0;
+  char url[128];
+  char text[640];
+  int j = 0;
+
+  checkCollection(coll);
+
+  getLocationListUri(url, "/", i);
+  if (!(path = createString(coll->htmlScoreDir))) goto error;
+  if (!(path = catString(path, url))) goto error;
+
+  logMain(LOG_DEBUG, "serialize %s", path);
+  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    goto error;
+  }  
+
+  fprintf(fd, "<!--#include virtual='../header.shtml' -->");
+  if (!ring) goto end; // empty page if needed
+
+  htmlPOpen(fd);
+  if (!serializeHtmlListBar(coll, fd, i, n)) goto error;
+
+  htmlUlOpen(fd);
+  location = rgCurrent(ring);
+  for (j = 0; j < MAX_INDEX_PER_PAGE && location; ++j) {
+    
+    getLocationUri(url, "../..", location);
+    if (!(server = getServer(coll, location->fingerPrint))) {
+      logMain(LOG_ERR, "fails to get server %s", location->fingerPrint);
+      goto error;
+    }
+    if (!sprintf(text, "%s %s:%s", strLType(location->type),
+		 server->host, location->uri))
+      goto error;
+
+    htmlLiOpen(fd);
+    htmlLink(fd, 0, url, text);
+    htmlLiClose(fd);
+
+    location = rgNext(ring);
+  }
+  htmlUlClose(fd);
+
+  if (!serializeHtmlListBar(coll, fd, i, n)) goto error;
+  htmlPClose(fd);
+ end:
+  htmlSSIFooter(fd, "../../..");
+
+  ++env.progBar.cur;
+  rc = TRUE;
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlLocationList fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : serializeHtmlLocationLists
+ * Description: HTML index page
+ * Synopsis   : int 
+ * Input      : ExtractTree* self = context
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlLocationLists(Collection* coll)
+{ 
+  int rc = FALSE;
+  ExtractTree* extractTree = 0;
+  FILE* fd = stdout;
+  char tmp[128];
+  char* path = 0;
+  char* path2 = 0;
+  int nb = 0;
+  int i = 0;
+  int n = 0;
+
+  logMain(LOG_DEBUG, "serializeHtmsLocationLists");
+  if (!(extractTree = coll->extractTree)) goto error;
+  
+  nb = extractTree->locations->nbItems;
+  
+  if (!getLocationListUri(tmp, "/", 0)) goto error;
+  if (!(path = createString(coll->htmlScoreDir))) goto error;
+  if (!(path = catString(path, tmp))) goto error;
+
+  // build the directory
+  if (mkdir(path, 0755)) {
+    if (errno != EEXIST) {
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      goto error;
+    }
+  }
+  // serialize header file for the location list
+  if (!(path2 = createString(path))) goto error;
+  if (!(path2 = catString(path2, "/header.shtml"))) goto error;
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
+  if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    goto error;
+  }
+  
+  htmlSSIHeader2(fd, "../..", "score");
+  htmlPOpen(fd);
+  htmlBold(fd, _("Locations"));
+  if (!fprintf(fd, " : %i", nb)) goto error;
+  htmlBr(fd);
+  htmlPClose(fd);
+  
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+
+  // sort already done
+
+  // get the total number of lists of documents
+  n = (nb - 1) / MAX_INDEX_PER_PAGE +1;
+  logMain(LOG_DEBUG, "have %i locations, so %i lists", nb, n);
+
+  // build lists sub-directories (group by MAX_FILES_PER_DIR)
+  if (!htmlMakeDirs(path, n)) goto error;
+  
+  // serialize lists
+  rgHead(extractTree->locations); // set current location to the first one
+  for (i=1 ; i<=n; ++i) {
+    if (!serializeHtmlLocationList(coll, extractTree->locations, i, n)) goto error;
+  }
+
+  // empty list if needed
+  if (n == 0) {
+    if (!htmlMakeDirs(path, 1)) goto error;
+    if (!serializeHtmlLocationList(coll, 0, 1, 0)) goto error;
+  }
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlLocationLists fails");
+  }
+  path = destroyString(path);
+  path2 = destroyString(path2);
+  return rc;
+}
+
 
 /*=======================================================================
  * Function   : serializeHtmsScoreIndex
@@ -1020,9 +1781,9 @@ serializeHtmsScoreIndex(Collection* coll)
   FILE* fd = stdout;
   char* path = 0;
   ServerTree* serverTree = 0;
-  Archive* archive = 0;
-  char url[128];
-  char text[128];
+  //Archive* archive = 0;
+  //char url[128];
+  //char text[128];
 
   if (!(serverTree = coll->serverTree)) goto error;
 
@@ -1087,32 +1848,32 @@ serializeHtmsScoreIndex(Collection* coll)
   htmlUlClose(fd);
   htmlPClose(fd);
 
-  // images
-  htmlPOpen(fd);
-  if (!fprintf(fd, _("\nAll images: %i\n"), 
-	       serverTree->archives->nbItems)) goto error;
-  htmlUlOpen(fd);
-  if (!isEmptyRing(serverTree->archives)) {
-    if (!rgSort(serverTree->archives, cmpArchive)) goto error;
-    while ((archive = rgNext(serverTree->archives))) {
-      getArchiveUri(url, "", archive);
-      if (!sprintf(text, "%s:%lli ", archive->hash, 
-		   (long long int)archive->size)) goto error;
+  /* // images */
+  /* htmlPOpen(fd); */
+  /* if (!fprintf(fd, _("\nAll images: %i\n"),  */
+  /* 	       serverTree->archives->nbItems)) goto error; */
+  /* htmlUlOpen(fd); */
+  /* if (!isEmptyRing(serverTree->archives)) { */
+  /*   if (!rgSort(serverTree->archives, cmpArchive)) goto error; */
+  /*   while ((archive = rgNext(serverTree->archives))) { */
+  /*     getArchiveUri(url, "", archive); */
+  /*     if (!sprintf(text, "%s:%lli ", archive->hash,  */
+  /* 		   (long long int)archive->size)) goto error; */
 
-      htmlLiOpen(fd);
-      htmlVerb(fd, text);
-      htmlLink(fd, 0, url, getArchiveScore(archive));
+  /*     htmlLiOpen(fd); */
+  /*     htmlVerb(fd, text); */
+  /*     htmlLink(fd, 0, url, getArchiveScore(archive)); */
 
-      htmlLiClose(fd);
-    }
-  }
-  else {
-    htmlLiOpen(fd);
-    if (!fprintf(fd, _("No image\n"))) goto error;
-    htmlLiClose(fd);
-  }
-  htmlUlClose(fd);
-  htmlPClose(fd);
+  /*     htmlLiClose(fd); */
+  /*   } */
+  /* } */
+  /* else { */
+  /*   htmlLiOpen(fd); */
+  /*   if (!fprintf(fd, _("No image\n"))) goto error; */
+  /*   htmlLiClose(fd); */
+  /* } */
+  /* htmlUlClose(fd); */
+  /* htmlPClose(fd); */
 
   htmlSSIFooter(fd, "..");
 
@@ -1176,6 +1937,16 @@ serializeHtmlScoreHeader(Collection* coll)
   htmlLink(fd, 0, url, _("Bad images"));
   htmlBr(fd);
 
+  // images lists
+  getImageListUri(url, "<!--#echo var='HOME' -->/score", 1);
+  htmlLink(fd, 0, url, _("Images"));
+  htmlBr(fd);
+
+  // locations lists
+  getLocationListUri(url, "<!--#echo var='HOME' -->/score", 1);
+  htmlLink(fd, 0, url, _("Locations"));
+  htmlBr(fd);
+  
   // each server
   if (!isEmptyRing(self->servers)) {
     // sort already done
@@ -1223,9 +1994,11 @@ int
 serializeHtmlScore(Collection* coll)
 { 
   int rc = FALSE;
-  ServerTree* self = 0;
+  ServerTree* serverTree = 0;
+  ExtractTree* extractTree = 0;
   Server* server = 0;
   Archive *archive = 0;
+  Location *location = 0;
   AVLNode *node = 0;
   char tmp[128];
   char *path1 = 0;
@@ -1233,10 +2006,11 @@ serializeHtmlScore(Collection* coll)
   int nb = 0;
 
   checkCollection(coll);
-  if (!(self = coll->serverTree)) goto error;
+  if (!(serverTree = coll->serverTree)) goto error;
+  if (!(extractTree = coll->extractTree)) goto error;
   logMain(LOG_DEBUG, "serializeHtmlScore: %s collection", coll->label);
  
-  // servers directories
+  // server's directories
   if (!(path1 = createString(coll->htmlScoreDir))) goto error;
   if (!(path1 = catString(path1, "/servers"))) goto error;
   if (mkdir(path1, 0755)) {
@@ -1247,14 +2021,14 @@ serializeHtmlScore(Collection* coll)
   }
 
   // servers
-  if (!isEmptyRing(self->servers)) {
-    if (!rgSort(self->servers, cmpServer)) goto error;
-    while ((server = rgNext(self->servers))) {
+  if (!isEmptyRing(serverTree->servers)) {
+    if (!rgSort(serverTree->servers, cmpServer)) goto error;
+    while ((server = rgNext(serverTree->servers))) {
       if (!serializeHtmlServer(coll, server)) goto error;
     }
   }
 
-  // archives directories
+  // archive's directories
   path1 = destroyString(path1);
   if (!getArchiveUri1(tmp, "/", -1)) goto error;
   if (!(path1 = createString(coll->htmlScoreDir))) goto error;
@@ -1266,22 +2040,43 @@ serializeHtmlScore(Collection* coll)
     }
   }
 
-  if ((nb = avl_count(coll->archives))) {
+  // archives
+  if ((nb = coll->maxId)) {
     logMain(LOG_DEBUG, "have %i archives", nb);
     if (!htmlMakeDirs(path1, nb)) goto error;
-  }
-
-  // archives
-  if (nb) {
     for(node = coll->archives->head; node; node = node->next) {
       archive = (Archive*)node->item;
       if (!serializeHtmlScoreArchive(coll, archive)) goto error;
     }
   }
 
+  // loacation's directories
+  path1 = destroyString(path1);
+  if (!getLocationUri1(tmp, "/", -1)) goto error;
+  if (!(path1 = createString(coll->htmlScoreDir))) goto error;
+  if (!(path1 = catString(path1, tmp))) goto error;
+  if (mkdir(path1, 0755)) {
+    if (errno != EEXIST) {
+      logMain(LOG_ERR, "mkdir %s fails: %s", path1, strerror(errno));
+      goto error;
+    }
+  }
+
+  // locations
+  if ((nb = extractTree->maxIdLocation)) {
+    logMain(LOG_DEBUG, "have %i locations", nb);
+    if (!htmlMakeDirs(path1, nb)) goto error;
+    if (!rgSort(extractTree->locations, cmpServer)) goto error;
+    while ((location = rgNext(extractTree->locations))) {
+      if (!serializeHtmlLocation(coll, location)) goto error;
+    }
+  }
+  
   // others
   if (!serializeHtmlArchiveLists(coll)) goto error;
   if (!serializeHtmlBadLists(coll)) goto error;
+  if (!serializeHtmlImageLists(coll)) goto error;
+  if (!serializeHtmlLocationLists(coll)) goto error;
   if (!serializeHtmsScoreIndex(coll)) goto error;
   if (!serializeHtmlScoreHeader(coll)) goto error;
   
