@@ -125,45 +125,13 @@ int mdtxUploadPlus(char* label, char* catalog, char* extract, RG* upFiles)
   int rc = FALSE;
 
   checkLabel(label);
-  
   if (!mdtxUpload(label, catalog, extract, upFiles)) goto error;
-  if (!mdtxUpgrade(label)) goto error;
-  
-  rc = TRUE;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "mdtxUploadPlus fails");
-  }
-  return rc;
-}
-
-/*=======================================================================
- * Function   : mdtxUploadPlusPlus
- * Author     : Nicolas ROCHE
- * modif      : 2013/10/23
- * Description: Upload + upgrade + make
- * Synopsis   : int mdtxUploadPlusPlus(char* label, char* catalog,
- *                                     char* extract, RG* upFiles)
- * Input      : char* label = collection to pre-process
- *              char* catalog: catalog metadata file to upload
- *              char* extract: extract metadata file to upload
- *              RG* upFiles: ring or UploadFile* ; data to upload
- * Output     : TRUE on success
- =======================================================================*/
-int mdtxUploadPlusPlus(char* label, char* catalog, char* extract, 
-		       RG* upFiles)
-{
-  int rc = FALSE;
-
-  checkLabel(label);
-  
-  if (!mdtxUploadPlus(label, catalog, extract, upFiles)) goto error;
   if (!mdtxMake(label)) goto error;
   
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "mdtxUploadPlusPlus fails");
+    logMain(LOG_ERR, "mdtxUploadPlus fails");
   }
   return rc;
 }
@@ -595,6 +563,7 @@ mdtxAudit(char* label, char* mail)
   char reply[255] = "100 nobody";
   int status = 0;
   int uid = getuid();
+  int nb = 0;
 
   logMain(LOG_DEBUG, "audit %s collection for %s", label, mail);
   checkLabel(label);
@@ -639,7 +608,6 @@ mdtxAudit(char* label, char* mail)
       fd = stdout;
       goto error2;
     }
-    if (!lock(fileno(fd), F_WRLCK)) goto error2;
   }
 
   logMain(LOG_INFO, "Serializing audit into: %s", 
@@ -647,12 +615,19 @@ mdtxAudit(char* label, char* mail)
 
   if (!loadCollection(coll, EXTR)) goto error2;
 
+  // remove locations from audit
+  for(node = coll->archives->head; node; node = node->next) {
+    archive = node->item;
+    if (!belongsToContainers(coll, archive)) continue;
+    ++nb;
+  }
+  
   fprintf(fd, "Audit on %s collection\n", coll->label);
   fprintf(fd, " requested on %04i-%02i-%02i %02i:%02i:%02i\n",
 	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
 	  date.tm_hour, date.tm_min, date.tm_sec); 
   fprintf(fd, " requested by %s\n", mail);
-  fprintf(fd, " %i archives to check\n", avl_count(coll->archives));
+  fprintf(fd, " %i archives to check\n", nb);
   fprintf(fd, " %i archives checked:\n", 0);
   fprintf(fd, "  %i archives ok\n", 0);
   fprintf(fd, "  %i archives ko\n", 0);
@@ -660,7 +635,9 @@ mdtxAudit(char* label, char* mail)
   fprintf(fd, "\nArchive to check:\n");
   if (avl_count(coll->archives)) {
     for(node = coll->archives->head; node; node = node->next) {
-      archive = (Archive*)node->item;
+      archive = node->item;
+      if (!belongsToContainers(coll, archive)) continue;
+      
       fprintf(fd, " %s:%lli\n", archive->hash,
 	      (long long int)archive->size);
       
@@ -705,7 +682,6 @@ mdtxAudit(char* label, char* mail)
   if (!logoutUser(uid)) rc = FALSE;
  error:
   if (fd != stdout) {
-    if (!unLock(fileno(fd))) rc = FALSE;
     if (fclose(fd)) {
       logMemory(LOG_ERR, "fclose fails: %s", strerror(errno));
       rc = FALSE;
