@@ -112,8 +112,9 @@ int clientWriteLock()
   Configuration* conf = 0;
   struct sembuf sembuf;
   int uid = getuid();
+  int semval = -1;
 
-  logMain(LOG_DEBUG, "get the concurrent access"); 
+  logMain(LOG_DEBUG, "get the concurrent access");
 
   if (!(conf = getConfiguration())) goto error;
   if (!setConcurentAccessLock()) goto error;
@@ -125,26 +126,25 @@ int clientWriteLock()
   // force becoming mdtx user 
   if (!becomeUser(env.confLabel, FALSE)) goto error;
 
+  // guess if we were locked or not
+  if ((semval = semctl(conf->sem, 0, GETVAL)) < 0) {
+    logMain(LOG_ERR, "semctl fails: %s", strerror(errno)); 
+  }
+  if (semval != 1) {
+    logMain(LOG_NOTICE, "please wait, a concurent process is running..."); 
+  }
+  
   // P (may I ?)
   logMain(LOG_DEBUG, "get writter lock");
   sembuf.sem_num = 0;
   sembuf.sem_op = -1;
-  sembuf.sem_flg = SEM_UNDO | IPC_NOWAIT; // for crash recovery...
-  //... + do not asleep process if not available but exit with EAGAIN
-  if (semop(conf->sem, &sembuf, 1) < 0) {
-    if (errno == EAGAIN) {
-      logMain(LOG_ERR, 
-	      "cannot take concurent access as it is already locked");
-    }
-    else {
-      logMain(LOG_ERR, "semop fails asking for semaphore: %s", 
-	      strerror(errno)); 
-    }
+  sembuf.sem_flg = SEM_UNDO;
+  if (semop(conf->sem, &sembuf, 1)) {
+      logMain(LOG_ERR, "semop fails: %s", strerror(errno)); 
     goto error;
   }
 
   // Parse files
-  
   rc = TRUE;
  error:
   if (!logoutUser(uid)) rc = FALSE;
@@ -160,14 +160,18 @@ int clientWriteLock()
  * Synopsis   : int clientWriteUnlock()
  * Input      : N/A
  * Output     : TRUE on success
+ * Note       : do not free semaphore IPC ressource else other
+ *              concurent processes will complain
  =======================================================================*/
 int clientWriteUnlock()
 {
   int rc = FALSE;
   Configuration* conf = 0;
-  union semun arg;
+  //union semun arg;
   int uid = getuid();
 
+  struct sembuf sembuf;
+
   logMain(LOG_DEBUG, "release the concurrent access"); 
 
   if (!(conf = getConfiguration())) goto error;
@@ -176,22 +180,33 @@ int clientWriteUnlock()
     goto error;
   }
 
-  // force becoming mdtx user 
+  // force becoming mdtx user
   if (!becomeUser(env.confLabel, FALSE)) goto error;
-  
-  /*
-    As concurent process exit without waiting for the mutex, 
-    we do not need to release first and the free if no more used
-  */
 
-  // Free semaphore IPC ressource
-  arg.val = 0;
-  if (semctl(conf->sem, 0, IPC_RMID, arg) == -1) {
-    logMain(LOG_ERR, "semctl fails: %s", strerror(errno)); 
-    goto error;
+  // V (please)
+  logMain(LOG_DEBUG, "release writter lock");
+  sembuf.sem_num = 0;
+  sembuf.sem_op = +1;
+  sembuf.sem_flg = SEM_UNDO;
+  if (semop(conf->sem, &sembuf, 1) < 0) {
+      logMain(LOG_ERR, "semop fails releasing semaphore: %s", 
+	      strerror(errno)); 
+      goto error;
   }
+  
+  /* /\* */
+  /*   As concurent process exit without waiting for the mutex,  */
+  /*   we do not need to release first and the free if no more used */
+  /* *\/ */
 
-  conf->sem = -1;
+  /* // Free semaphore IPC ressource */
+  /* arg.val = 0; */
+  /* if (semctl(conf->sem, 0, IPC_RMID, arg) == -1) { */
+  /*   logMain(LOG_ERR, "semctl fails: %s", strerror(errno));  */
+  /*   goto error; */
+  /* } */
+
+  /* conf->sem = -1; */
   rc = TRUE;
  error:
   if (!logoutUser(uid)) rc = FALSE;
