@@ -194,6 +194,7 @@ mdtxAddSupport(char* label, char* path)
   Configuration* conf = 0;
   Support *supp = 0;
   time_t now = 0;
+  CheckData data;
 
   logMain(LOG_DEBUG, "mdtxAddSupport");
   if (isEmptyString(path)) goto error;
@@ -210,8 +211,21 @@ mdtxAddSupport(char* label, char* path)
   // look for this name in the support Ring
   if (!loadConfiguration(SUPP)) goto error;
   if ((supp = getSupport(label))) {
-    logMain(LOG_ERR, "a support labeled \"%s\" already exist", label);
-    goto error;
+
+    // already there
+    memset(&data, 0, sizeof(CheckData));
+    strncpy(data.quickMd5sum, supp->quickMd5sum, MAX_SIZE_MD5+1);
+    strncpy(data.quickShasum, supp->quickShasum, MAX_SIZE_SHA+1);
+    data.opp = CHECK_SUPP_ID;
+    data.size = supp->size;
+    data.path = path;
+    if (!doChecksum(&data)) goto error;
+    if (data.rc) {
+      logMain(LOG_ERR, "another \"%s\" support was already added", label);
+      goto error;
+    }
+    logMain(LOG_NOTICE, "same \"%s\" support already added", label);
+    goto end;
   }
 
   // create and complete support object
@@ -219,6 +233,7 @@ mdtxAddSupport(char* label, char* path)
   supp->firstSeen = now;
   if (!doCheckSupport(supp, path)) goto error;
 
+ end:
   rc = TRUE;
  error:
   if (!rc) {
@@ -245,7 +260,8 @@ mdtxAddFile(char* path)
   Support *supp = 0;
   time_t now = 0;
   char* absolutePath = 0;
-
+  CheckData data;
+  
   logMain(LOG_DEBUG, "mdtxAddFile %s", path);
   if (isEmptyString(path)) goto error;
   if (!(conf = getConfiguration())) goto error;
@@ -264,9 +280,23 @@ mdtxAddFile(char* path)
   // look for this name in the support Ring
   if (!loadConfiguration(SUPP)) goto error;
   if ((supp = getSupport(absolutePath))) {
-    logMain(LOG_ERR, "a support labeled \"%s\" already exist", 
+    
+    // already there
+    memset(&data, 0, sizeof(CheckData));
+    strncpy(data.quickMd5sum, supp->quickMd5sum, MAX_SIZE_MD5+1);
+    strncpy(data.quickShasum, supp->quickShasum, MAX_SIZE_SHA+1);
+    data.opp = CHECK_SUPP_ID;
+    data.size = supp->size;
+    data.path = absolutePath;
+    if (!doChecksum(&data)) goto error;
+    if (data.rc) {
+      logMain(LOG_ERR, "another \"%s\" file was already added",
+	      absolutePath);
+      goto error;
+    }
+    logMain(LOG_NOTICE, "same \"%s\" file already added",
 	    absolutePath);
-    goto error;
+    goto end;
   }
 
   // create and complete support object
@@ -274,6 +304,7 @@ mdtxAddFile(char* path)
   supp->firstSeen = now;
   if (!doCheckSupport(supp, absolutePath)) goto error;
 
+ end:
   rc = TRUE;
  error:
   if (!rc) {
@@ -354,7 +385,7 @@ static int
 notifyHave(Support* supp, char* path) 
 {
   int rc = FALSE;
-  int socket = 0;
+  int socket = -1;
   Configuration* conf = 0;
   Collection* coll = 0;
   RecordTree* tree = 0;
