@@ -1,4 +1,3 @@
-
 /*=======================================================================
  * Project: MediaTeX
  * Module : upload
@@ -67,37 +66,6 @@ destroyUploadFile(UploadFile* self)
   return (UploadFile*)0;
 }
 
-
-/*=======================================================================
- * Function   : uploadCatalog
- * Description: parse uploaded catalog file
- * Synopsis   : static int uploadCatalog(Collection* upload, char* path)
- * Input      : Collection* upload: collection used to parse upload
- *              char* path: input catalog file to parse
- * Output     : TRUE on success
- =======================================================================*/
-static int 
-uploadCatalog(Collection* upload, char* path)
-{ 
-  int rc = FALSE;
-
-  logMain(LOG_DEBUG, "uploadCatalog");
-  checkCollection(upload);
-  checkLabel(path);
-  
-  if (!(upload->catalogTree = createCatalogTree())) goto error;
-  if (!(upload->catalogDB = createString(path))) goto error;
-  if (!parseCatalogFile(upload, path)) goto error;
-
-  rc = TRUE;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "uploadCatalog fails");
-  }
-  upload->catalogDB = destroyString(upload->catalogDB);
-  return rc;
-}
-
 /*=======================================================================
  * Function   : uploadExtract
  * Description: parse uploaded extract file
@@ -118,7 +86,10 @@ uploadExtract(Collection* upload, char* path)
   
   if (!(upload->extractTree = createExtractTree())) goto error;
   if (!(upload->extractDB = createString(path))) goto error;
-  if (!parseExtractFile(upload, path)) goto error;
+  if (!parseExtractFile(upload, path)) {
+    logMain(LOG_ERR, "fails to load uploaded extract catalog");
+    goto error;
+  }
 
   // assert there is no INC content  
   if (!(self = upload->extractTree)) goto error;
@@ -140,13 +111,13 @@ uploadExtract(Collection* upload, char* path)
  * Function   : uploadContent
  * Description: add uploaded content file to extract metadata
  * Synopsis   : static Archive* uploadContent(
- *                               Collection* upload, UploadFile* upFile)
- * Input      : Collection* upload: collection used to parse upload
+ *                               Collection* coll, UploadFile* upFile)
+ * Input      : Collection* coll: collection used to add content
  *              char* path: input file to upload
  * Output     : Archive object on success ; NULL on error
  =======================================================================*/
 static Archive* 
-uploadContent(Collection* upload, UploadFile* upFile)
+uploadContent(Collection* coll, UploadFile* upFile)
 { 
   Archive* rc = 0;
   struct stat statBuffer;
@@ -161,12 +132,12 @@ uploadContent(Collection* upload, UploadFile* upFile)
   char* ptr = 0;
 
   logMain(LOG_DEBUG, "uploadContent");
-  checkCollection(upload);
+  checkCollection(coll);
   path = upFile->source;
   checkLabel(path);
 
-  if (!upload->extractTree) {
-    if (!(upload->extractTree = createExtractTree())) goto error;
+  if (!coll->extractTree) {
+    if (!(coll->extractTree = createExtractTree())) goto error;
   }
   
   // get file attributes (size)
@@ -183,7 +154,7 @@ uploadContent(Collection* upload, UploadFile* upFile)
   if (!doChecksum(&md5)) goto error;
 
   // archive to upload
-  if (!(archive = addArchive(upload, md5.fullMd5sum, statBuffer.st_size)))
+  if (!(archive = addArchive(coll, md5.fullMd5sum, statBuffer.st_size)))
     goto error;
 
   // add incoming extraction rule
@@ -197,24 +168,24 @@ uploadContent(Collection* upload, UploadFile* upFile)
 	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
 	  date.tm_hour, date.tm_min, date.tm_sec);
 
-  if (!(container = upload->extractTree->inc)) goto error;
-  if (!(addFromAsso(upload, archive, container, dateString))) 
+  if (!(container = coll->extractTree->inc)) goto error;
+  if (!(addFromAsso(container, archive, dateString))) 
     goto error;
 
-  // add image extraction rule
+  // add extraction rule
   if (upFile->target) {
     if (!(target = createString(upFile->target))) goto error;
     
     // if target is a directory
     if (target[strlen(target)-1] == '/') {
 
-      // concatcat the filename
+      // concat the filename
       for (ptr = path+strlen(path)-1; ptr > path && *ptr != '/'; --ptr);
       if (!(target = catString(target, ptr+1))) goto error;
     }
     
-    if (!(container = upload->extractTree->img)) goto error;
-    if (!(addFromAsso(upload, archive, container, target)))
+    if (!(container = coll->extractTree->img)) goto error;
+    if (!(addFromAsso(container, archive, target)))
       goto error;
   }
   
@@ -261,64 +232,56 @@ isFileRefbyExtract(Collection *coll, Archive* archive)
 }
 
 /*=======================================================================
- * Function   : areNotAlreadyThere
- * Description: check extraction rules are new (else parsing will fails)
- * Synopsis   : int areNotAlreadyThere(Collection *coll, 
- *                                     Collection *upload)
+ * Function   : areAlreadyThere
+ * Description: assert extract refers to known archives
+ * Synopsis   : int areAlreadyThere(Collection *coll,
+ *                                  Collection *upload)
  * Input      : Collection* coll:   actuals extract rules
  *              Collection* upload: new extract rules
- *              Archive* archive
  * Output     : TRUE on success
  =======================================================================*/
-int 
-areNotAlreadyThere(Collection *coll, Collection* upload)
-{ 
+int
+areAlreadyThere(Collection *coll, Collection* upload)
+{
   int rc = FALSE;
   ExtractTree* self = 0;
   Archive* archUp = 0;
   Archive* archCol = 0;
   Container* container = 0;
   AVLNode *node = 0;
-  RGIT* curr = 0; 
+  RGIT* curr = 0;
 
-  logMain(LOG_DEBUG, "areNotAlreadyThere");
+  logMain(LOG_DEBUG, "areAlreadyThere");
   checkCollection(coll);
   checkCollection(upload);
   if (!(self = upload->extractTree)) goto error;
-  if (!loadCollection(coll, EXTR)) goto error;
   rc = TRUE;
   
   // loop on uploaded containers
-  if (avl_count(self->containers)) {
-    for(node = self->containers->head; node; node = node->next) {
-      container = node->item;
-      curr = 0;
-      while ((archUp = rgNext_r(container->parents, &curr))) {
+  for(node = self->containers->head; node; node = node->next) {
+    container = node->item;
+    curr = 0;
 
-	// check container not already into actual extractTree
-	if ((archCol = getArchive(coll, archUp->hash, archUp->size))) {
-	  if (archCol->toContainer) {
-	    logMain(LOG_ERR, 
-		    "Incoming container %s%lli already set as container", 
-		    archUp->hash, archUp->size);
-	    rc = FALSE;
-	  }
-	}
+    // assert parents containers are already into the extractTree
+    while ((archUp = rgNext_r(container->parents, &curr))) {
+      if (!(archCol = getArchive(coll, archUp->hash, archUp->size))) {
+	  logMain(LOG_ERR, "unknown container %s:%lli", 
+		  archUp->hash, archUp->size);
+	  rc = FALSE;
       }
     }
   }
 
  error:
-  if (!releaseCollection(coll, EXTR)) rc = FALSE;
   if (!rc) {
-    logMain(LOG_ERR, "areNotAlreadyThere fails");
+    logMain(LOG_ERR, "areAlreadyThere fails");
   }
   return rc;
 }
 
 /*=======================================================================
  * Function   : uploadFile 
- * Description: Ask daemon to upload the file
+ * Description: Ask daemon to upload the files
  * Synopsis   : static int
  *               uploadFile(Collection* coll, RG* upFiles)
  * Input      : Collection* coll
@@ -418,65 +381,6 @@ uploadFile(Collection* coll, RG* upFiles)
   return rc;
 }
 
-
-/*=======================================================================
- * Function   : concatCatalog
- * Description: concatenate uploaded catalog metadata
- * Synopsis   : static int concatCatalog(Collection* coll, 
- *                                       Collection *upload)
- * Input      : Collection* coll: target
- *              Collection* upload: source
- * Output     : TRUE on success
- =======================================================================*/
-static int 
-concatCatalog(Collection* coll, Collection *upload)
-{ 
-  int rc = FALSE;
-  CvsFile fd = {0, 0, 0, FALSE, 0, cvsCatOpen, cvsCatPrint};
-
-  logMain(LOG_DEBUG, "concatCatalog");
-
-  upload->catalogDB = coll->catalogDB;
-  if (!(serializeCatalogTree(upload, &fd))) goto error;
-
-  rc = TRUE;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "concatCatalog fails");
-  }
-  upload->catalogDB = 0;
-  return rc;
-}
-
-/*=======================================================================
- * Function   : concatExtract
- * Description: concatenate uploaded extract metadata
- * Synopsis   : static int concatExtract(Collection* coll, 
- *                                       Collection *upload)
- * Input      : Collection* coll: target
- *              Collection* upload: source
- * Output     : TRUE on success
- =======================================================================*/
-static int 
-concatExtract(Collection* coll, Collection *upload)
-{ 
-  int rc = FALSE;
-  CvsFile fd = {0, 0, 0, FALSE, 0, cvsCatOpen, cvsCatPrint};
-
-  logMain(LOG_DEBUG, "concatExtract");
-
-  upload->extractDB = coll->extractDB;
-  if (!(serializeExtractTree(upload, &fd))) goto error;
-
-  rc = TRUE;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "concatExtract fails");
-  }
-  upload->extractDB = 0;
-  return rc;
-}
-
 
 /*=======================================================================
  * Function   : mdtxUpload
@@ -509,61 +413,92 @@ mdtxUpload(char* label, char* catalog, char* extract, RG* upFiles)
   if (!(coll = mdtxGetCollection(label))) goto error;
 
   // create a new collection to parse upload contents
-  if ((upload = getCollection("_upload_"))) goto error;
+  if ((upload = getCollection("_upload_"))) {
+    logMain(LOG_ERR, "internal '_upload_' collection already used");
+    goto error;
+  }
   if (!(upload = addCollection("_upload_"))) goto error;
   if (!(upload->masterLabel = createString(coll->masterUser))) goto error;
   if (!(upload->user = createString(coll->user))) goto error;
-  strcpy(upload->masterHost, "localhost");
+  strcpy(upload->masterHost, DEFAULT_HOST);
 
-  // uploaded contents to the new collection
-  if (extract && !uploadExtract(upload, extract)) goto error;
-  if (!isEmptyRing(upFiles)) {
-    while ((upFile = rgNext(upFiles))) {
-      if (!(upFile->archive = uploadContent(upload, upFile)))
-	goto error;
+  // assert there is no INC content (internal use only) 
+  if (extract) {
+    if (!uploadExtract(upload, extract)) goto error;
+    if (avl_count(upload->extractTree->inc->childs) > 0) {
+      logMain(LOG_ERR, "uploaded extract catalog contains incoming rules");
+      goto error;
     }
-  }
-  if (catalog && !uploadCatalog(upload, catalog)) goto error;
+  }    
 
-  // Do some checks depending on what we have
+  // if both extract catalog and extract files are provided, 
+  // we guess user wants to provide rules for all incoming files.
   if (extract && !isEmptyRing(upFiles)) {
     rgRewind(upFiles);
     while ((upFile = rgNext(upFiles))) {
+      if (!(upFile->archive = uploadContent(upload, upFile))) goto error;
       if (!isFileRefbyExtract(upload, upFile->archive)) goto error;
+      upFile->archive = 0;
     }
   }
-    
-  // Check we erase nothing in actual extraction metadata
-  if (extract || !isEmptyRing(upFiles)) {
-    if (!areNotAlreadyThere(coll, upload)) goto error;
+
+  // check archive's consistency while concatenating catalogs
+  // note: catalog and extract may refer to images too
+  if (!loadCollection(coll, EXTR|SERV)) goto error;
+
+  // add rules for incoming files (and get archives for uploadFile)
+  if (!isEmptyRing(upFiles)) {
+    while ((upFile = rgNext(upFiles))) {
+      // incoming files (alones) may be uploaded several times,
+      // if the daemon do not already old them as local supply
+      // (usefull if archive was lost for instance)
+      if (!(upFile->archive = uploadContent(coll, upFile)))
+	goto error;
+    }
+  }
+  
+  // extract rules file may be provided without incoming files
+  // (to add forgotten container's rules for instance).
+  // here we assert that it does not introduce unknown containers
+  if (extract && !areAlreadyThere(coll, upload)) {
+    logMain(LOG_ERR, "uploaded extract catalog refers to unknown containers");
+    goto error;
+  }
+
+  // check new extract rules does not overrides current ones 
+  // (incoming are merged)
+  if (extract) {
+    // concatenate new extract file
+    if (!parseExtractFile(coll, extract)) {
+      logMain(LOG_ERR, "uploaded extract catalog overrides existing rules");
+      goto error;
+    }
+  }
+
+  // and check new catalog does not links to unknown archives
+  if (catalog) {
+    if (!loadCollection(coll, CTLG)) goto error;
+    if (!parseCatalogFile(coll, catalog)) {
+      logMain(LOG_ERR, "fails to upload new catalog."
+	      " Maybe it refers to unknown archives");
+      goto error;
+    }
   }
   
   // ask daemon to upload the file
   if (!isEmptyRing(upFiles)) {
     if (!uploadFile(coll, upFiles)) goto error;
   }
-
-  // prevent saveCollection from unlinking new NNN.txt files,
-  // and also force reload on upload+[+] to use the new NNN.txt files
-  // note: that does not disease upload coll as not set as LOADED
-  // * MAYBE: simplify below code understanding by reparsing upload into
-  // coll (no more NNN files nor reload needed on upload+[+])
-  if (!clientDiseaseAll()) goto error;
-
-  // serialize NNN.txt files
-  upload->memoryState |= EXPANDED;
-  if (catalog && !concatCatalog(coll, upload)) goto error;
-  if (extract || !isEmptyRing(upFiles)) {
-    if (!concatExtract(coll, upload)) goto error;
+  
+  // save changes
+  if (catalog) {
+    if (!wasModifiedCollection(coll, CTLG)) goto error;
+    if (!releaseCollection(coll, CTLG)) goto error;
   }
-
-  // tell the server we have upgraded the extraction metadata
   if (extract || !isEmptyRing(upFiles)) {
-    if (!env.noRegression && !env.dryRun) {
-      mdtxAsyncSignal(0); // send HUP signal to daemon
-    }
+    if (!wasModifiedCollection(coll, EXTR)) goto error;
   }
-
+  if (!releaseCollection(coll, EXTR|SERV)) goto error;
   rc = TRUE;
  error:
   if (!rc) {
