@@ -188,7 +188,7 @@ computeContainer(Collection* coll, Container* self, int depth)
 
 /*=======================================================================
  * Function   : isNewIncoming
- * Description: state if an archive was newly upload
+ * Description: state if an archive was newly uploaded
  * Synopsis   : static int isNewIncoming(Collection* coll, 
  *                                                    Archive* archive)
  * Input      : Collection* coll: to get uploadTTL parameter
@@ -311,7 +311,7 @@ computeExtractScore(Collection* coll)
       if (archive->incInherency) continue;
 
       // global score = min ( archive's score )
-      if (archive->extractScore > -1) {
+      if (belongsToContainers(coll, archive) && archive->extractScore > -1) {
 	if (self->score > archive->extractScore)
 	  self->score = archive->extractScore;
       }
@@ -367,6 +367,9 @@ getExtractStatus(Collection* coll, off_t* badSize, RG** badArchives)
     // looking for top containers as content cannot have worse score
     if (!isEmptyRing(archive->fromContainers)) continue;
 
+    // do not display a global bad score due to locations
+    if (!belongsToContainers(coll, archive)) continue;
+    
     // do not display a global bad score due to incomings
     if (archive->incInherency) continue;
 
