@@ -44,6 +44,7 @@ callUpgrade(char* user, char* fingerprint, char* url)
   int rc = FALSE;  
   Configuration* conf = 0;
   char *argv[] = {0, 0, 0, 0, 0, 0};
+  int nbTry = 0;
 
   checkLabel(user);
   logCommon(LOG_INFO, "callUpgrade %s: fp=%s url=%s",
@@ -56,15 +57,24 @@ callUpgrade(char* user, char* fingerprint, char* url)
   argv[2] = conf->host;
   argv[3] = *fingerprint?fingerprint:"?";
   argv[4] = url;
+
+  if (env.noRegression || env.dryRun || env.noGit) {
+    rc = TRUE;
+    goto error;
+  }
   
-  if (!env.noRegression && !env.dryRun && !env.noGit) {
-    if (!execScript(argv, user, 0, FALSE)) goto error;
+  while (!rc && nbTry < 3) {
+      sleep(nbTry++);
+      rc = execScript(argv, user, 0, FALSE);
+      if (!rc) {
+	logCommon(LOG_WARNING, "fails (%i/3) callUpgrade %s: fp=%s url=%s",
+		  nbTry, user, fingerprint?fingerprint:"?", url?url:"");
+      }
   }
 
-  rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "callUpgrade fails");
+    logCommon(LOG_ERR, "callUpgrade fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -84,7 +94,8 @@ callCommit(char* user, char* comment)
   int rc = FALSE;  
   Configuration* conf = 0;
   char *argv[] = {0, 0, 0, 0};
-
+  int nbTry = 0;
+ 
   checkLabel(user);
   env.commandLine[strlen(env.commandLine)-1] = 0; // \n -> \0
   logCommon(LOG_INFO, "callCommit %s: %s", user,
@@ -96,14 +107,23 @@ callCommit(char* user, char* comment)
   argv[1] = user;
   argv[2] = comment?comment:env.commandLine;
   
-  if (!env.noRegression && !env.dryRun && !env.noGit) {
-    if (!execScript(argv, user, 0, FALSE)) goto error;
+  if (env.noRegression || env.dryRun || env.noGit) {
+    rc = TRUE;
+    goto error;
+  }
+  
+  while (!rc && nbTry < 3) {
+    sleep(nbTry++);
+    rc = execScript(argv, user, 0, FALSE);
+    if (!rc) {
+      logCommon(LOG_WARNING, "fails (try %i/3) callCommit %s: %s",
+		nbTry, user, comment?comment:env.commandLine);
+    }
   }
 
-  rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "callCommit fails");
+    logCommon(LOG_ERR, "callCommit fails");
   }
   argv[0] = destroyString(argv[0]);
   env.commandLine[strlen(env.commandLine)] = '\n';
@@ -123,7 +143,8 @@ callPull(char* user)
   int rc = FALSE;
   Configuration* conf = 0;
   char *argv[] = {0, 0, 0};
-
+  int nbTry = 0;
+  
   checkLabel(user);
   logCommon(LOG_INFO, "callPull %s", user);
 
@@ -132,14 +153,22 @@ callPull(char* user)
   if (!(argv[0] = catString(argv[0], "/pull.sh"))) goto error;
   argv[1] = user;
 
-  if (!env.noRegression && !env.dryRun && !env.noGitPullPush) {
-    if (!execScript(argv, user, 0, FALSE)) goto error;
+  if (env.noRegression || env.dryRun || env.noGit) {
+    rc = TRUE;
+    goto error;
+  }
+  
+  while (!rc && nbTry < 3) {
+    sleep(nbTry++);
+    rc = execScript(argv, user, 0, FALSE);
+    if (!rc) {
+      logCommon(LOG_WARNING, "fails (%i/3) callPull %s", nbTry, user);
+    }
   }
 
-  rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "callPull fails");
+    logCommon(LOG_ERR, "callPull fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -158,7 +187,8 @@ callPush(char* user)
   int rc = FALSE;  
   Configuration* conf = 0;
   char *argv[] = {0, 0, 0};
-
+  int nbTry = 0;
+  
   checkLabel(user);
   logCommon(LOG_INFO, "callPush %s", user);
 
@@ -166,15 +196,23 @@ callPush(char* user)
   if (!(argv[0] = createString(conf->scriptsDir))) goto error;
   if (!(argv[0] = catString(argv[0], "/push.sh"))) goto error;
   argv[1] = user;
+
+  if (env.noRegression || env.dryRun || env.noGit) {
+    rc = TRUE;
+    goto error;
+  }
   
-  if (!env.noRegression && !env.dryRun && !env.noGitPullPush) {
-    if (!execScript(argv, user, 0, FALSE)) goto error;
+  while (!rc && nbTry < 3) {
+    sleep(nbTry++);
+    rc = execScript(argv, user, 0, FALSE);
+    if (!rc) {
+      logCommon(LOG_WARNING, "fails (%i/3) callPush %s", nbTry, user);
+    }
   }
 
-  rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "callPush fails");
+    logCommon(LOG_ERR, "callPush fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -199,9 +237,11 @@ int loadConfiguration(int confFiles)
   }
   if (!(conf = getConfiguration())) goto error;
 
-  if (!env.noGit) {
+  if (!env.noGit &&
+      conf->fileState[iCFG] == DISEASED &&                                             
+      conf->fileState[iSUPP] == DISEASED) {     
     if (!callCommit(env.confLabel, "manual user edition")) goto error;
-    if (!env.noGitPullPush) callPull(env.confLabel);
+    if (!env.noGitPullPush && !callPull(env.confLabel)) goto error;
   }
   
   if ((confFiles & CFG) && conf->fileState[iCFG] == DISEASED) {
@@ -256,12 +296,10 @@ int loadRecords(Collection* coll)
     logCommon(LOG_ERR, "cannot open records file: %s", coll->md5sumsDB);
     goto error;
   }
-  if (!lock(fd, F_RDLCK)) goto error;
 
   // parse md5sumsDB file into the main recordTree
   if ((tree = parseRecords(fd)) == 0) goto error;
 
-  if (!unLock(fd)) goto error;
   if (close(fd) == -1) {
     logCommon(LOG_ERR, "close: %s", strerror(errno));
     logCommon(LOG_ERR, "cannot close records file: %s", coll->md5sumsDB);
@@ -337,10 +375,11 @@ collectionLoop(Collection* coll, int collFiles,
 }
 
 /*=======================================================================
- * Function   : releaseCollection
- * Description: Call serializer on private files
- * Synopsis   : int releaseCollection()
- * Input      : N/A
+ * Function   : releaseColl
+ * Description: indicate that we no more use tree(s)
+ * Synopsis   : int releaseColl(Collection* coll, int i)
+ * Input      : Collection* coll: collection to load
+ *              int fileIdx: CTLG,EXTR or SERV
  * Output     : TRUE on success
  =======================================================================*/
 static int 
@@ -558,10 +597,12 @@ loadColl(Collection* coll, int fileIdx)
 /*=======================================================================
  * Function   : loadCollectionNbSteps
  * Description: Estimate the maximum number of steps for progBar
- * Synopsis   : 
+ * Synopsis   : static int loadCollectionNbSteps(Collection* coll, 
+ *                                                       int collFiles)
  * Input      : Collection* coll: collection to load
  *              int collFiles: OR from CollFiles (CTLG,EXTR,SERV)
  * Output     : TRUE on success
+ * Note       : do nothing for SERV
  =======================================================================*/
 static int
 loadCollectionNbSteps(Collection* coll, int collFiles)
@@ -576,6 +617,8 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
 
   env.progBar.cur = env.progBar.max = 0;
   for (fileIdx=iCTLG; fileIdx<=iCACH; ++fileIdx) {
+
+    // SERV is not handle
     if (collFiles & (CTLG | EXTR) & (1<<fileIdx)) {
       if (coll->fileState[i] != DISEASED) continue;
       switch (fileIdx) {
@@ -615,13 +658,13 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
 	fclose(fd);
       }
       path = destroyString(path);
-    }    
+    }
+
+    // add 3 percent
+    env.progBar.max *= 1.03;
   }
 
-  // add 3%
-  env.progBar.max *= 1.03;
-
-  if (env.progBar.max > 0) {
+  if (env.progBar.max > 0 && !env.noRegression) {
     logCommon(LOG_INFO, "estimate %i steps for load", env.progBar.max);
   }
   rc = TRUE;
@@ -661,7 +704,8 @@ loadCollection(Collection* coll, int collFiles)
     if (!env.noGitPullPush) {
       if (coll->toUpdate && collFiles & (CTLG | EXTR | SERV)) {
 	logMain(LOG_INFO, "Git pull %s collection", coll->label);
-	if (callPull(coll->user)) coll->toUpdate = FALSE;
+	if (!callPull(coll->user)) goto error;
+	coll->toUpdate = FALSE;
       }
     }
   }
@@ -677,7 +721,7 @@ loadCollection(Collection* coll, int collFiles)
   if (!collectionLoop(coll, collFiles, loadColl)) goto error;
   stopProgBar();
 
-  if (env.progBar.max) {
+  if (env.progBar.max && !env.noRegression) {
     logCommon(LOG_INFO, "steps: %lli / %lli", 
 	      env.progBar.cur, env.progBar.max);
   }
@@ -792,9 +836,7 @@ saveConfiguration()
   if (change && !env.noGit) {
     if (!callUpgrade(env.confLabel, conf->hostFingerPrint, 0)) goto error;
     if (!callCommit(env.confLabel, 0)) goto error;
-    if (!env.noGitPullPush) {
-	callPush(env.confLabel);
-    }
+    if (!env.noGitPullPush && !callPush(env.confLabel)) goto error;
   }
 
   rc = TRUE;
@@ -872,7 +914,7 @@ saveColl(Collection* coll, int i)
       logCommon(LOG_DEBUG, "... as not modified");
     }
     if (nbInUse) {
-      logCommon(LOG_DEBUG, "... as still used by %i functions", nbInUse);
+      logCommon(LOG_ERR, "... as still used by %i functions", nbInUse);
     }
   }
 
@@ -911,6 +953,7 @@ saveCollectionNbSteps(Collection* coll, int collFiles)
 	env.progBar.max += avl_count(coll->catalogTree->humans);
       case iEXTR:
 	env.progBar.max += avl_count(coll->extractTree->containers);
+	env.progBar.max += coll->extractTree->locations->nbItems;
 	break;
       default:
 	goto error;
@@ -918,7 +961,7 @@ saveCollectionNbSteps(Collection* coll, int collFiles)
     }
   }
 
-  if (env.progBar.max > 0) { // else nothing to do
+  if (env.progBar.max > 0 && !env.noRegression) { // else nothing to do
     logCommon(LOG_INFO, "estimate %i steps for save", env.progBar.max);
   }
   rc = TRUE;
@@ -959,19 +1002,20 @@ saveCollection(Collection* coll, int collFiles)
   startProgBar(progBarLabel);
   if (!collectionLoop(coll, collFiles, saveColl)) goto error;
   stopProgBar();
-  logCommon(LOG_INFO, "steps: %lli / %lli", 
-	    env.progBar.cur, env.progBar.max);
+  if (!env.noRegression) {
+    logCommon(LOG_INFO, "steps: %lli / %lli", 
+	      env.progBar.cur, env.progBar.max);
+  }
 
   // commit changes
   if (coll->toCommit && !env.noGit) {
     if (!callCommit(coll->user, 0)) goto error;
     if (!env.noGitPullPush) {
       logMain(LOG_INFO, "Git push %s collection", coll->label);
-      if (callPush(coll->user)) {
-	conf->toHup = TRUE;
-	coll->toCommit = FALSE;
-	coll->toUpdate = TRUE;
-      }
+      if (!callPush(coll->user)) goto error;
+      conf->toHup = TRUE;
+      coll->toCommit = FALSE;
+      coll->toUpdate = TRUE;
     }
   }
 
@@ -1082,7 +1126,9 @@ diseaseColl(Collection* coll, int i)
       logCommon(LOG_DEBUG, "... as not loaded");
     }
     if (nbInUse) {
-      logCommon(LOG_DEBUG, "... as still used by %i functions", nbInUse);
+      // rq: this is reach when malloc try to disease the collection
+      // we are currently loading (cannot anticipate here)
+      logCommon(LOG_NOTICE, "... as still used by %i functions", nbInUse);
     }
   }
 
@@ -1141,6 +1187,8 @@ clientDiseaseAll()
   logCommon(LOG_DEBUG, "clientDiseaseAll");
   if (!(conf = env.confTree)) goto error; // do not malloc
 
+  // rq: we also try to disease the collection
+  // we are currently loading (cannot anticipate here)
   while ((coll = rgNext_r(conf->collections, &curr))) {
     if (!(coll->memoryState & EXPANDED)) continue;
     if (!saveCollection(coll, CTLG|EXTR|SERV)) goto error;
@@ -1175,6 +1223,8 @@ int serverDiseaseAll()
   logCommon(LOG_DEBUG, "serverDiseaseAll");
   if (!(conf = env.confTree)) goto error; // do not malloc
 
+  // rq: we also try to disease the collection
+  // we are currently loading (cannot anticipate here)
   while ((coll = rgNext_r(conf->collections, &curr))) {
     if (!(coll->memoryState & EXPANDED)) continue;
     if (!saveCollection(coll, CACH)) goto error;
