@@ -193,7 +193,7 @@ mdtxAsyncSignal(int signal)
   logCommon(LOG_INFO, "sending signal %i to %i", signal, pid);
 
   if (kill(pid, signal) == -1) {
-    logCommon(LOG_ERR, "kill signal to daemon fails: %s", strerror(errno));
+    logCommon(LOG_NOTICE, "kill signal to daemon fails: %s", strerror(errno));
     goto error;
   }
 
