@@ -119,10 +119,9 @@ serializeSshConfig(Collection* coll)
   fprintf(fd, "%s", "# This file is managed by MediaTeX software.\n\n");
   fprintf(fd, "%s", "# Do not ask for password\n"); 
   fprintf(fd, "%s", "BatchMode yes\n");
-  fprintf(fd, "%s", "Compression yes\n");
+  fprintf(fd, "%s", "#Compression yes\n");
   fprintf(fd, "%s", "#LogLevel DEBUG3\n\n");
-
-
+  
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
     while ((server = rgNext_r(self->servers, &curr))) {
@@ -192,11 +191,15 @@ serializeKnownHosts(Collection* coll)
   fprintf(fd, "# This file is managed by MediaTeX software.\n");
 
   // add twice localhost keys:
-  // here using "localhost" name for local connexions
-  fprintf(fd, "localhost %s\n", conf->hostKey);
+  // here using DEFAULT_HOST name for local connexions
+  fprintf(fd, "%s %s\n", DEFAULT_HOST, conf->hostKey);
+  if (!strcmp(conf->host, DEFAULT_HOST)) {
+    logCommon(LOG_WARNING, 
+	      "Please avoid using %s into the configuration", DEFAULT_HOST);
+  }
   if (!strcmp(conf->host, "localhost")) {
     logCommon(LOG_WARNING, 
-	    "Please avoid using localhost in the configuration");
+	    "Please avoid using localhost into the configuration");
   }
 
   // add all keys using the host name provided by servers.txt
@@ -214,9 +217,13 @@ serializeKnownHosts(Collection* coll)
 	}
 
 	// warning message as you cannot be reach from the outside
+	if (!strcmp(server->host, DEFAULT_HOST)) {
+	  logCommon(LOG_WARNING, 
+		    "Please avoid having %s into the servers list", DEFAULT_HOST);
+	}
 	if (!strcmp(server->host, "localhost")) {
 	  logCommon(LOG_WARNING, 
-		  "Please avoid having localhost in the servers list");
+		  "Please avoid having localhost into the servers list");
 	}
       }
     }
