@@ -97,7 +97,7 @@ doCheckSupport(Support *supp, char* path)
   rc = TRUE;
   if (!doChecksum(&data)) {
       logMain(LOG_DEBUG, 
-	      "internal error on md5sum computation for \"%s\" support", 
+	      "internal error on checksum computation for \"%s\" support", 
 	      supp->name);
       rc = FALSE;
       goto error;
@@ -441,7 +441,7 @@ upgradeCollection(Collection* coll)
   // check if we are the collection master host
   isMaster = 
     (!strcmp(coll->masterLabel, env.confLabel) &&
-     (!strcmp(coll->masterHost, "localhost") ||
+     (!strcmp(coll->masterHost, DEFAULT_HOST) ||
       !strcmp(coll->masterHost, conf->host)));
   
   // if master change his collection key, we need
@@ -451,7 +451,8 @@ upgradeCollection(Collection* coll)
   }
 
   // else we trust the servers.txt file
-  if (!(master = coll->serverTree->master)) {
+  if (!(master = coll->serverTree->master) ||
+      !master->host || !master->label) {
     logCommon(LOG_ERR, "loose master server for %s collection", 
 	    coll->label);
     goto error;
@@ -488,7 +489,7 @@ upgradeCollection(Collection* coll)
   if (!env.noRegression && !upgradeSshConfiguration(coll)) goto error;
 
   // upgrade GIT settings
-  if (sprintf(url, "ssh://%s@%s:/var/lib/gitbare/%s",
+  if (sprintf(url, "ssh://%s@%s/var/lib/gitbare/%s",
 	      coll->serverTree->master->user,
 	      coll->serverTree->master->host,
 	      coll->serverTree->master->user) <= 0) goto error;
