@@ -223,13 +223,10 @@ int mdtxFind(RecordTree *tree)
   case 220:
     url = reply + 7; // "220 ok URL"
     logMain(LOG_DEBUG, "found at %s", url);
-    
-    fprintf(stdout, "Content-Type: text/html; charset=utf-8\r\n");
-    fprintf(stdout, "Refresh: 0; url=%s\r\n", url);
+
+    // use 3xx status to allow curl to pass redirection 
+    fprintf(stdout, "Location: %s\r\n", url);
     fprintf(stdout, "\r\n");
-    sendTemplate(coll, "cgiHeader.shtml");
-    fprintf(stdout, "Please follow <a href=\"%s\"> link</a>!", url);
-    sendTemplate(coll, "footer.html");
     break;
 
   default:
@@ -315,7 +312,7 @@ int mdtxRegister(RecordTree *tree)
     sendTemplate(coll, "cgiHeader.shtml");
     fprintf(stdout, "%s",
 	    "You will be notified by mail as soon as the file become "
-	    "available\n"
+	    "available.\n"
 	    "Please follow this <a href=\"../index\"> link</a>!");
     sendTemplate(coll, "footer.html");
     break;
