@@ -74,6 +74,8 @@ typedef struct Image Image;
 typedef struct ExtractTree ExtractTree;
 typedef struct Container Container;
 typedef struct FromAsso FromAsso;
+typedef struct Location Location;
+typedef struct LocationAsso LocationAsso;
 
 typedef struct CatalogTree CatalogTree;
 typedef struct Category Category;
@@ -93,6 +95,7 @@ typedef void* yyscan_t;
 // define the fundamental boolean constants
 #define TRUE 1
 #define FALSE 0
+#define UNDEF 0
 
 // no ipv4 for localhost to optimize sort
 #define LOCALHOST 0 
@@ -101,11 +104,10 @@ typedef void* yyscan_t;
 #define MAX_SIZE_MD5 32 // MD5_DIGEST_LENGTH bytes printed using %x
 #define MAX_SIZE_SHA 40 // SHA_DIGEST_LENGTH bytes printed using %x
 #define MAX_SIZE_SIZE 19 // off_t printed using %lli
-#define MAX_SIZE_COLL 20 
+#define MAX_SIZE_COLL 32
 #define MAX_SIZE_STAT 10
 #define MAX_SIZE_AES  16
 #define MAX_SIZE_HOST 255 // http://en.wikipedia.org/wiki/Hostname
-#define MAX_SIZE_CMD 4    // 3 + \0
 #define MAX_SIZE_STRING 511 // hope is enought
 
 // HTML
@@ -124,7 +126,6 @@ typedef void* yyscan_t;
 #define MONTH  ((long int)60*60*24*30)
 #define YEAR   ((long int)60*60*24*365)
 #define DEFAULT_MDTXUSER "mdtx"
-#define DEFAULT_HOST "localhost"
 #define DEFAULT_CACHE_SIZE 100*MEGA // cache size
 #define DEFAULT_TTL_CACHE  15*DAY    // local-supply TTL on cache
 #define DEFAULT_TTL_QUERY  7*DAY     // final-query  TTL 
@@ -270,7 +271,7 @@ struct ScoreParam {
 
 #define checkLabel(label) {					\
     if (!label || !(*label))	{				\
-      logMisc(LOG_ERR, "%s", "please provide a label");		\
+      logMisc(LOG_ERR, "please provide a label");		\
       goto error;						\
     }								\
   }
@@ -317,6 +318,20 @@ struct ScoreParam {
     }								\
   }
 
+#define checkLocation(location) {				\
+    if(!location) {						\
+      logMisc(LOG_ERR, "%s", "please provide a location");	\
+      goto error;						\
+    }								\
+  }
+
+#define checkDocument(document) {				\
+    if(!document) {						\
+      logMisc(LOG_ERR, "%s", "please provide a document");	\
+      goto error;						\
+    }								\
+  }
+
 #define checkRecord(record) {					\
     if (!record) {						\
       logMisc(LOG_ERR, "%s", "please provide a record");	\
