@@ -46,7 +46,7 @@ usage(char* programName)
   fprintf(stderr, " [ -a ] query");
 
   mdtxOptions();
-  fprintf(stderr, "  -a, --alone\t\tdo not make cvs remote queries\n");
+  fprintf(stderr, "  -a, --alone\t\tdo not make git remote queries\n");
   
   fprintf(stderr, "\nExamples:\n"	  
 	  "\nAdmin queries:\n"
@@ -64,7 +64,7 @@ usage(char* programName)
 	  "  check supp SUPP on PATH  Provide an external support (that is accessible now).\n"
 	  "  add supp SUPP to (all|coll COLL)  Share a support with a collection.\n"
 	  "  del supp SUPP from (all|coll COLL)  Withdraw a support from a collection.\n"
-	  "  upload+{0,2} [file FILE as TARGET]* [catalog FILE] [rules FILE] to coll COLL  Upload an incoming archive into the cache. Appending one or two '+' will run ``uprade'' or ``upgrade+make'' queries too.\n"
+	  "  upload[+] [file FILE as TARGET]* [catalog FILE] [rules FILE] to coll COLL  Upload an incoming archive into the cache. Appending one '+' will run ``make'' queries too.\n"
 	  
 	  "\nMeta-data management:\n"
 	  "  list [master] coll  List collections.\n"	  
@@ -78,7 +78,7 @@ usage(char* programName)
 	  "  audit coll COLL for MAIL  Extract all archives from a collection.\n"
 
 	  "\nQueries to daemon:\n"
-	  "  srv (save|extract|notify)  repectively ask server to dump its state into disk, perform extractions, communicate its state to other servers, deliver mails related to extracted archives (no more needed).\n"
+	  "  srv (save|extract|notify)  repectively ask server to dump its state into disk, perform extractions, communicate its state to other servers.\n"
 	  "  srv [quick] scan  ask server to manage file added manually to the cache. Only check file's sizes but do not compute checksums on quick scan.\n"
 	  "  srv (trim|clean|purge)  ask server remove from the cache all files that repectively can be extracted by using containers present into the cache, are safe and can be extracted locally using local supports or that are safe.\n"
 
