@@ -340,7 +340,7 @@ socketJob(void* arg)
   case UPLOAD:
     logMain(LOG_NOTICE, "socketJob %i: UPLOAD", me);
     con->status[1] = '1';
-    if (!uploadFinaleArchive(con)) goto error;
+    if (!uploadFinaleArchives(con)) goto error;
     break;
 
   case CGI:
