@@ -42,6 +42,7 @@ createArchive(void)
   memset(rc, 0, sizeof(Archive));
   if ((rc->images = createRing()) == 0) goto error;
   if ((rc->fromContainers = createRing()) == 0) goto error;
+  if ((rc->fromLocations = createRing()) == 0) goto error;
   if ((rc->documents = createRing()) == 0) goto error;
   if ((rc->assoCaracs = createRing()) == 0) goto error;
   if ((rc->records = createRing()) == 0) goto error;
@@ -91,6 +92,7 @@ destroyArchive(Archive* self)
   // we do not free the objects (owned by trees), just the rings
   self->images = destroyOnlyRing(self->images);
   self->fromContainers = destroyOnlyRing(self->fromContainers);
+  self->fromLocations = destroyOnlyRing(self->fromLocations);
   self->documents = destroyOnlyRing(self->documents);
   self->records = destroyOnlyRing(self->records);
   self->demands = destroyOnlyRing(self->demands);
@@ -292,6 +294,7 @@ diseaseArchive(Collection* coll, Archive* self)
   // check container's rings
   if (self->fromContainers->nbItems >0) goto next;
   if (self->toContainer) goto next;
+  if (self->fromLocations->nbItems >0) goto next;
 
   // check incoming flag
   if (self->uploadTime) goto next;
@@ -312,7 +315,7 @@ diseaseArchive(Collection* coll, Archive* self)
   if (self->finalSupplies->nbItems >0) goto next;
   if (self->localSupply) goto next;
   
-  // delete archive from collection ring and free it
+  // delete archives from collection ring and free them
   avl_delete(coll->archives, self);
 
  next:
@@ -369,14 +372,33 @@ diseaseArchives(Collection* coll)
  * Requirement: loadCollection(coll, EXTR)
  * Note       : archive is no more an incoming when having a good score
  =======================================================================*/
-int isIncoming(Collection* coll, Archive* self)
+int 
+isIncoming(Collection* coll, Archive* self)
 {
-  return self->uploadTime && 
-    (self->extractScore ==-1 || 
+  return self->uploadTime &&
+    (self->extractScore ==-1 || // still not computed
      self->extractScore <
      coll->serverTree->scoreParam.maxScore /2);
 }
 
+/*=======================================================================
+ * Function   : belongsToContainers
+ * Description: check if archive adready exists on extraction containers
+ * Synopsis   : int belongsToContainers(Collection* coll,
+ *                                                    Archive* archive)
+ * Input      : Collection* coll
+ *              Archive* archive
+ * Output     : TRUE if referenced into extraction containers
+ * Requirement: loadCollection(coll, EXTR)
+ =======================================================================*/
+int
+belongsToContainers(Collection* coll, Archive* archive)
+{
+  return (isIncoming(coll, archive) ||
+  	  archive->fromContainers->nbItems ||
+  	  archive->toContainer);
+}
+
 /*=======================================================================
  * Function   : isBadTopContainer
  * Description: check if archive is a top container having bad score
@@ -388,14 +410,33 @@ int isIncoming(Collection* coll, Archive* self)
  * Requirement: loadCollection(coll, EXTR)
  * Note       : maybe check minGeoDup and nb REMOTE_SUPPLY too in future
  =======================================================================*/
-int isBadTopContainer(Collection* coll, Archive* archive)
+int 
+isBadTopContainer(Collection* coll, Archive* archive)
 {
   // looking for top containers (as content cannot have worse score)
-  return (!archive->fromContainers->nbItems &&
+  return (belongsToContainers(coll, archive) &&
+	  !archive->fromContainers->nbItems &&
 	  // looking for archive having a bad score
 	  archive->extractScore<=coll->serverTree->scoreParam.maxScore/2);
 }
 
+/*=======================================================================
+ * Function   : belongsToExtractTree
+ * Description: check if archive adready exists on extraction metadata
+ * Synopsis   : int belongsToExtractTree(Collection* coll,
+ *                                                    Archive* archive)
+ * Input      : Collection* coll
+ *              Archive* archive
+ * Output     : TRUE if referenced into extraction metadata
+ * Requirement: loadCollection(coll, EXTR)
+ =======================================================================*/
+int
+belongsToExtractTree(Collection* coll, Archive* archive)
+{
+  return (belongsToContainers(coll, archive) ||
+	  archive->fromLocations->nbItems);
+}
+
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
