@@ -313,7 +313,8 @@ computeArchiveStatus(Collection* coll, Archive* archive)
   // - having a bad score (incoming included)
   // - still in use for extraction
   if (haveRecords(archive->demands) ||
-      archive->extractScore <= coll->serverTree->scoreParam.maxScore /2
+      (belongsToContainers(coll, archive) &&
+       archive->extractScore <= coll->serverTree->scoreParam.maxScore /2)
       || archive->localSupply->date > date) {
     archive->state = TOKEEP;
   }
