@@ -23,17 +23,12 @@
 
 #include "mediatex-config.h"
 
-void* avl_insert_2(AVLTree* tree, void* item)
-{
-  return avl_insert(tree, item);
-}
-
 
 /*=======================================================================
- * Function   : caracType2string
- * Description: get the type as a string to be displayed
- * Synopsis   : char* caracType2string(CType type)
- * Input      : CaracType type: type of carac
+ * Function   : strCType
+ * Description: get the label of a caracteristic entity
+ * Synopsis   : char* strCType(CType type)
+ * Input      : CType type: type of carac
  * Output     : The correspondaing string
  =======================================================================*/
 char*
@@ -55,8 +50,8 @@ strCType(CType self)
  * Function   : createCarac
  * Description: Create, by memory allocation a Carac
  * Synopsis   : Carac* createCarac(void)
- * Input      : CaracType type: type of carac
- * Output     : The address of the create empty configuration.
+ * Input      : N/A
+ * Output     : The address of the created carac
  =======================================================================*/
 Carac* 
 createCarac()
@@ -1062,10 +1057,8 @@ serializeCatalogTree(Collection* coll, CvsFile* fd)
 /*=======================================================================
  * Function   : getCarac
  * Description: Search or may create a Carac
- * Synopsis   : Carac* getCarac(Collection* coll, 
- *                                           CaracType type, char* label)
+ * Synopsis   : Carac* getCarac(Collection* coll, char* label)
  * Input      : Collection* coll: where to find
- *              CaracType type: type of carac
  *              char* label: id of the carac
  * Output     : The address of the Carac.
  =======================================================================*/
@@ -1088,10 +1081,8 @@ getCarac(Collection* coll, char* label)
 /*=======================================================================
  * Function   : addCarac
  * Description: Search or may create a Carac
- * Synopsis   : Carac* addCarac(Collection* coll, 
- *                                           CaracType type, char* label)
+ * Synopsis   : Carac* addCarac(Collection* coll, char* label)
  * Input      : Collection* coll: where to find
- *              CaracType type: type of carac
  *              char* label: id of the carac
  * Output     : The address of the Carac.
  =======================================================================*/
@@ -1145,6 +1136,7 @@ delCarac(Collection* coll, Carac* self)
   }
 
   // free the carac
+  self->label = destroyString(self->label);
   destroyCarac(self);
 
   rc = TRUE;
@@ -1158,26 +1150,25 @@ delCarac(Collection* coll, Carac* self)
 /*=======================================================================
  * Function   : getAssoCarac
  * Description: Search or may create an AssoCarac
- * Synopsis   : AssoCarac* getAssoCarac(Collection* coll, 
- *                            Carac* carac, void* entity, char* value)
+ * Synopsis   : AssoCarac* getAssoCarac(Collection* coll, Carac* carac, 
+ *                                 CType type, void* entity, char* value)
  * Input      : Collection* coll: where to find
  *              Carac* carac: related carac
+ *              CType type: type of carac
  *              Entity* entity: related entity
- *              char* value: ie
  * Output     : The address of the AssoCarac.
  =======================================================================*/
 AssoCarac* 
-getAssoCarac(Collection* coll, Carac* carac, CType type, 
-	     void* entity, char* value)
+getAssoCarac(Collection* coll, Carac* carac, CType type, void* entity)
 {
   AssoCarac* rc = 0;
   RG* ring = 0;
   RGIT* curr = 0;
 
   checkCollection(coll);
-  if (!carac || !entity || !value) goto error;
-  logMemory(LOG_DEBUG, "getAssoCarac %s %s=%s", 
-	  strCType(type), carac->label, value);
+  if (!carac || !entity) goto error;
+  logMemory(LOG_DEBUG, "getAssoCarac %s %s",
+	    strCType(type), carac->label);
 
   switch (type) {
   case CATE:
@@ -1199,7 +1190,7 @@ getAssoCarac(Collection* coll, Carac* carac, CType type,
 
   // look for assoCarac
   while ((rc = rgNext_r(ring, &curr))) {
-    if (carac == rc->carac && !strcmp(rc->value, value)) break;
+    if (carac == rc->carac) break;
   }
   
  error:
@@ -1208,13 +1199,14 @@ getAssoCarac(Collection* coll, Carac* carac, CType type,
 
 /*=======================================================================
  * Function   : addAssoCarac
- * Description: Search or may create an AssoCarac
- * Synopsis   : AssoCarac* addAssoCarac(Collection* coll, 
- *                            Carac* carac, void* entity, char* value)
+ * Description: Search and update or create an AssoCarac
+ * Synopsis   : AssoCarac* addAssoCarac(Collection* coll, Carac* carac, 
+ *                               CType type, void* entity, char* value)
  * Input      : Collection* coll: where to find
  *              Carac* carac: related carac
+ *              CType type: type of carac
  *              Entity* entity: related entity
- *              char* value: ie
+ *              char* value: related value
  * Output     : The address of the AssoCarac.
  =======================================================================*/
 AssoCarac* 
@@ -1231,11 +1223,10 @@ addAssoCarac(Collection* coll, Carac* carac, CType type,
 	  strCType(type), carac->label, value);
 
   // already there
-  if ((asso = getAssoCarac(coll, carac, type, entity, value))) goto end;
+  if ((asso = getAssoCarac(coll, carac, type, entity))) goto end;
 
   // add new one if not already there
   if ((asso = createAssoCarac()) == 0) goto error;
-  if (!(asso->value = createString(value))) goto error; 
   asso->carac = carac;
 
   // add it to the entity tree
@@ -1259,6 +1250,15 @@ addAssoCarac(Collection* coll, Carac* carac, CType type,
   if (!rgInsert(ring, asso)) goto error;
 
  end:
+  // add or update value
+  if (!asso->value || strcmp(asso->value, value)) {
+    if (asso->value) {
+      logMemory(LOG_NOTICE, "update carac %s %s : %s -> %s",
+		strCType(type), carac->label, asso->value, value);
+      asso->value = destroyString(asso->value);
+    }
+    if (!(asso->value = createString(value))) goto error;
+  }
   rc = asso;
  error:
   if (!rc) {
@@ -1268,6 +1268,63 @@ addAssoCarac(Collection* coll, Carac* carac, CType type,
   return rc;
 }
 
+/*=======================================================================
+ * Function   : delAssoCarac
+ * Description: Delete an AssoCarac
+ * Synopsis   : AssoCarac* delAssoCarac(Collection* coll, 
+ *                           CType type, void* entity, AssoCarac* self)
+ * Input      : Collection* coll: where to delete
+ *              CType type: type of carac
+ *              Entity* entity: related entity
+ *              AssoCarac* self: asso carac to del
+ * Output     : TRUE on success
+ =======================================================================*/
+int
+delAssoCarac(Collection* coll, CType type, void* entity, AssoCarac* self)
+{
+  int rc = FALSE;
+  RG* ring = 0;
+  RGIT* curr = 0;
+
+  checkCollection(coll);
+  if (!entity || !self) goto error;
+  logMemory(LOG_DEBUG, "delAssoCarac %s %s=%s", 
+	  strCType(type), self->carac->label, self->value);
+
+  // del it from the entity tree
+  switch (type) {
+  case CATE:
+    ring = ((Category*)entity)->assoCaracs;
+    break;
+  case DOC:
+    ring = ((Document*)entity)->assoCaracs;
+    break;
+  case HUM:
+    ring = ((Human*)entity)->assoCaracs;
+    break;
+  case ARCH:
+    ring = ((Archive*)entity)->assoCaracs;
+    break;
+  default:
+    logMemory(LOG_INFO, "unknown carac type %i", type);
+    goto error;
+  }
+  if ((curr = rgHaveItem(ring, self))) {
+    rgRemove_r(ring, &curr);
+  }
+
+  self->carac = 0;
+  self->value = destroyString(self->value); 
+  destroyAssoCarac(self);
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMemory(LOG_ERR, "delAssoCarac fails");
+  }
+  return rc;
+}
+
 /*=======================================================================
  * Function   : getRole
  * Description: Search or may create a Role
@@ -1436,7 +1493,7 @@ addAssoRole(Collection* coll,
   asso->document = document;
   
   // add it to the role ring
-  if (!avl_insert_2(role->assos, asso)) {
+  if (!avl_insert(role->assos, asso)) {
     logMemory(LOG_ERR, "assoRole already added ?");
     goto error;
   }
@@ -1632,7 +1689,7 @@ addHuman(Collection* coll, char* firstName, char* secondName)
   if (!(human->firstName = createString(firstName))) goto error;
   if (!(human->secondName = createString(secondName))) goto error;
   human->id = coll->catalogTree->maxId[HUM]++;
-  if (!avl_insert_2(coll->catalogTree->humans, human)) goto error;
+  if (!avl_insert(coll->catalogTree->humans, human)) goto error;
 
  end:
   rc = human;
@@ -1787,7 +1844,7 @@ int addDocumentToCategory(Collection* coll, Document* document,
 	  document->label, category->label);
 
   // add document to category tree
-  if (!avl_insert_2(category->documents, document)) {
+  if (!avl_insert(category->documents, document)) {
     if (errno != EEXIST) {
       goto error;
     }
@@ -1806,17 +1863,17 @@ int addDocumentToCategory(Collection* coll, Document* document,
 }
 
 /*=======================================================================
- * Function   : delDocumentToCategory
- * Description: Del a document to a category
- * Synopsis   : int delDocumentToCategory(Collection* coll, 
+ * Function   : delDocumentFromCategory
+ * Description: Del a document from a category
+ * Synopsis   : int delDocumentFromCategory(Collection* coll, 
  *                          Document* document, Category* category)
  * Input      : Collection* coll: where to find
  *              Document* document
  *              Category* category
  * Output     : TRUE on success
  =======================================================================*/
-int delDocumentToCategory(Collection* coll, Document* document, 
-			  Category* category)
+int delDocumentFromCategory(Collection* coll, Document* document, 
+			    Category* category)
 {
   int rc = FALSE;
   RGIT* curr = 0;
@@ -1844,7 +1901,7 @@ int delDocumentToCategory(Collection* coll, Document* document,
 
 /*=======================================================================
  * Function   : getDocument
- * Description: Search or may create a Document
+ * Description: Search a Document
  * Synopsis   : Document* getDocument(Collection* coll, int id);
  * Input      : Collection* coll: where to find
  *             int id: ie
@@ -1893,7 +1950,7 @@ addDocument(Collection* coll, char* label)
   // add new one if not already there
   if ((document = createDocument()) == 0) goto error;
   if (!(document->label = createString(label))) goto error; 
-  if (avl_insert_2(coll->catalogTree->documents, document)) {
+  if (avl_insert(coll->catalogTree->documents, document)) {
     document->id = coll->catalogTree->maxId[DOC]++;
   }
   else {
