@@ -211,7 +211,7 @@ expandCollection(Collection* self)
   if (!(conf = getConfiguration())) goto error;
 
   // replace localhost with hostname on master server
-  if (!strncmp(self->masterHost, "localhost", MAX_SIZE_HOST)) {
+  if (!strncmp(self->masterHost, DEFAULT_HOST, MAX_SIZE_HOST)) {
     strncpy(self->masterHost, conf->host, MAX_SIZE_HOST);
   }
 
@@ -372,7 +372,7 @@ populateCollection(Collection* self)
   if (!rc) goto error;
   rc = FALSE;
 
-  // load the user public key
+  // load the user public key (rsa key choosen first)
   if (!access(self->sshRsaPublicKey, F_OK) &&
       (self->userKey = readPublicKey(self->sshRsaPublicKey))) goto next;
   if (!access(self->sshDsaPublicKey, F_OK) &&
@@ -814,7 +814,6 @@ serializeConfiguration(Configuration* self)
       fd = stdout;
       goto error;
     }
-    if (!lock(fileno(fd), F_WRLCK)) goto error;
   }
 
   fprintf(fd, "# This is the MediaTeX software configuration file.\n");
@@ -899,7 +898,6 @@ serializeConfiguration(Configuration* self)
   rc = TRUE;
  error:
   if (fd != stdout) {
-    if (!unLock(fileno(fd))) rc = FALSE;
     if (fclose(fd)) {
       logMemory(LOG_ERR, "fclose fails: %s", strerror(errno));
       rc = FALSE;
