@@ -80,14 +80,14 @@ struct Collection {
   char  *masterUser; // ie: "MDTX2-COLL"
 
   /* shared parameters (used by servers.txt) */
-  char *userKey;   // ~/.ssh/id_dsa.pub content
+  char *userKey;   // ~/.ssh/id_rsa.pub content
   char  userFingerPrint[MAX_SIZE_MD5+1];
 
   /* -load/save */
   MemoryState memoryState;
-  FileState fileState[4];
-  pthread_mutex_t mutex[4];
-  int cptInUse[4];
+  FileState fileState[4];   // CollFileIdx
+  pthread_mutex_t mutex[4]; // CollFileIdx
+  int cptInUse[4];          // CollFileIdx
   int toUpdate;
   int toCommit;
 
