@@ -48,7 +48,6 @@ int cvsClose(CvsFile* fd)
     goto end;
   }
 
-  if (!unLock(fileno(fd->fd))) rc = FALSE;
   if (fclose(fd->fd)) {
     logMemory(LOG_ERR, "fclose fails: %s", strerror(errno));
     goto error;
@@ -137,7 +136,6 @@ int cvsCutOpen(CvsFile* fd)
     goto error;
   }
 
-  if (!lock(fileno(fd->fd), F_WRLCK)) goto error;
  end:
   ++fd->nb;
   fd->offset = 0;
@@ -177,7 +175,6 @@ int cvsCatOpen(CvsFile* fd)
     goto error;
   }
 
-  if (!lock(fileno(fd->fd), F_WRLCK)) goto error;
  end:
   ++fd->nb;
   rc = TRUE;
