@@ -25,11 +25,10 @@
 
 
 /*=======================================================================
- * Function   : serializeEtype
- * Description: Serialize a Etype.
- * Synopsis   : int serializeEtype(Etype self, CvsFile* fd)
- * Input      : Etype self : what to serialize
- *              CvsFile* fd : where to serialize
+ * Function   : serializeEType
+ * Description: Serialize an extract type.
+ * Synopsis   : int serializeEtype(EType self)
+ * Input      : EType self : what to serialize
  * Output     : TRUE on success
  =======================================================================*/
 char*
@@ -54,9 +53,32 @@ strEType(EType self)
 
 
 /*=======================================================================
- * Function   : getEtype
- * Description: Get a Etype.
- * Synopsis   : EType getEtype(char* label)
+ * Function   : serializeLType
+ * Description: Serialize a location type.
+ * Synopsis   : int serializeEtype(LType self)
+ * Input      : LType self : what to serialize
+ * Output     : TRUE on success
+ =======================================================================*/
+char*
+strLType(LType self)
+{
+
+  static char* typeLabels[LTYPE_MAX] =
+    {"UNDEF", "COPY", "WGET"};
+
+  if (self < 0 || self >= LTYPE_MAX) {
+    logMemory(LOG_WARNING, "unknown location type %i", self);
+    return "???";
+  }
+
+  return typeLabels[self];
+}
+
+
+/*=======================================================================
+ * Function   : getEType
+ * Description: Get an extract type.
+ * Synopsis   : EType getEType(char* label)
  * Input      : char* label : label to translate
  * Output     : corresponding EType
  =======================================================================*/
@@ -64,6 +86,7 @@ EType
 getEType(char* label)
 {
   if (!strcasecmp(label, "INC")) return INC;
+  if (!strcasecmp(label, "IMG")) return IMG;
   if (!strcasecmp(label, "ISO")) return ISO;
   if (!strcasecmp(label, "CAT")) return CAT;
   if (!strcasecmp(label, "TGZ")) return TGZ;
@@ -78,13 +101,29 @@ getEType(char* label)
   return -1;
 }
 
+
+/*=======================================================================
+ * Function   : getLType
+ * Description: Get a location type.
+ * Synopsis   : LType getLType(char* label)
+ * Input      : char* label : label to translate
+ * Output     : corresponding LType
+ =======================================================================*/
+LType
+getLType(char* label)
+{
+  if (!strcasecmp(label, "COPY")) return COPY;
+  if (!strcasecmp(label, "WGET")) return WGET;
+  return -1;
+}
+
 
 /*=======================================================================
  * Function   : createFromAsso
- * Description: Create, by memory allocation an FromAsso
+ * Description: Create, by memory allocation a FromAsso
  * Synopsis   : FromAsso* createFromAsso(void)
  * Input      : N/A
- * Output     : The address of the create empty configuration.
+ * Output     : The address of the created empty fromAsso.
  =======================================================================*/
 FromAsso* 
 createFromAsso(void)
@@ -147,7 +186,7 @@ cmpFromAssoAvl(const void *p1, const void *p2)
  * Description: Create, by memory allocation an Container
  * Synopsis   : Container* createContainer(void)
  * Input      : N/A
- * Output     : The address of the create empty configuration.
+ * Output     : The address of the created empty container.
  =======================================================================*/
 Container* 
 createContainer(void)
@@ -185,7 +224,11 @@ destroyContainer(Container* self)
   if(self == 0) goto error;
  
   // do not free the Archive provided by collection
-  self->parents = destroyOnlyRing(self->parents); 
+  self->parents = destroyOnlyRing(self->parents);
+
+  if (self->directory) {
+    self->directory = destroyString(self->directory);
+  }
 
   // free the FromAsso tree (and content) too
   avl_free_tree(self->childs);
@@ -218,7 +261,7 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
     goto error;
   }
 
-  if (avl_count(self->childs) < 1) {
+  if (!avl_count(self->childs)) {
     // not blocking but we prefer to stop now
     logMemory(LOG_CRIT, "do not serialize an empty container!");
     goto error;
@@ -240,6 +283,9 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
   // serialize childs
   if (avl_count(self->childs) > 0) {
     fd->print(fd, "=>\n");
+    if (self->directory) {
+      fd->print(fd, "directory: %s\n", self->directory);
+    }
 
     for (node = self->childs->head; node; node = node->next) {
       asso = node->item;
@@ -247,7 +293,7 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
       // remove safe incoming
       if (self->type == INC && !isIncoming(coll, asso->archive)) continue;
 
-      // remove image extraction path whan available from another rule
+      // remove image extraction path when available from another rule
       if (self->type == IMG && asso->archive->fromContainers->nbItems > 0) continue;
       
       if (!serializeExtractRecord(asso->archive, fd)) goto error;
@@ -266,6 +312,37 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
   return(rc);
 }
 
+/*  */
+/* /\*======================================================================= */
+/*  * Function   : cmpContainer */
+/*  * Description: Compare 2 containers */
+/*  * Synopsis   : int cmpContainer(const void *p1, const void *p2) */
+/*  * Input      : const void *p1, const void *p2: the containers to compare */
+/*  * Output     : like strcmp */
+/*  =======================================================================*\/ */
+/* int  */
+/* cmpContainer(const void *p1, const void *p2) */
+/* { */
+/*   int rc = 0; */
+
+/*   /\* p1 and p2 are pointers on &items */
+/*    * and items are suposed to be Container*  */
+/*    *\/ */
+  
+/*   Container* v1 = *((Container**)p1); */
+/*   Container* v2 = *((Container**)p2); */
+
+/*   rc = v1->type - v2->type; */
+
+/*   // manage INC container (which has no parent) */
+/*   if (!v1->parent && !v2->parent) return 0; */
+/*   if (!v1->parent) return -1; */
+/*   if (!v2->parent) return +1; */
+
+/*   if (!rc) rc = cmpArchive(&v1->parent, &v2->parent); */
+/*   return rc; */
+/* } */
+
 
 /*=======================================================================
  * Function   : cmpContainerAvl
@@ -319,13 +396,220 @@ serializeExtractRecord(Archive* self, CvsFile* fd)
   return rc;
 }
 
+
+/*=======================================================================
+ * Function   : createLocationAsso
+ * Description: Create, by memory allocation a LocationAsso
+ * Synopsis   : LocationAsso* createLocationAsso(void)
+ * Input      : N/A
+ * Output     : The address of the created empty locationAsso.
+ =======================================================================*/
+LocationAsso* 
+createLocationAsso(void)
+{
+  LocationAsso* rc = 0;
+
+  if ((rc = (LocationAsso*)malloc(sizeof(LocationAsso))) == 0)
+    goto error;
+
+  memset(rc, 0, sizeof(LocationAsso));
+ 
+  return rc;  
+ error:  
+  logMemory(LOG_ERR, "malloc: cannot create LocationAsso");
+  return destroyLocationAsso(rc);
+}
+
+/*=======================================================================
+ * Function   : destroyLocationAsso
+ * Description: Destroy an LocationAsso by freeing own allocated memory.
+ * Synopsis   : void destroyLocationAsso(LocationAsso* self)
+ * Input      : LocationAsso* self = the address of the configuration to
+ *              destroy.
+ * Output     : Nil address of a LocationAsso.
+ =======================================================================*/
+LocationAsso* 
+destroyLocationAsso(LocationAsso* self)
+{
+  if (self == 0) goto error;
+  self->path = destroyString(self->path);
+  free(self);
+ error:
+  return (LocationAsso*)0;
+}
+
+/*=======================================================================
+ * Function   : cmpLocationAssoAvl
+ * Description: compare two LocationAsso
+ * Synopsis   : int cmpLocationAssoAvl(const void *p1, const void *p2)
+ * Input      : p1 and p2 are pointers on LocationAsso
+ * Output     : p1 = p2 ? 0 : (p1 < p2 ? -1 : 1)
+ =======================================================================*/
+int 
+cmpLocationAssoAvl(const void *p1, const void *p2)
+{
+  int rc = 0;
+
+  /* p1 and p2 are pointers on &items */
+  LocationAsso* v1 = (LocationAsso*)p1;
+  LocationAsso* v2 = (LocationAsso*)p2;
+
+  rc = cmpArchiveAvl(v1->archive, v2->archive);
+  if (!rc) rc = cmpLocation(&(v1->location), &(v2->location));
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : createLocation
+ * Description: Create, by memory allocation a Location
+ * Synopsis   : Location* createLocation(void)
+ * Input      : N/A
+ * Output     : The address of the created empty location.
+ =======================================================================*/
+Location* 
+createLocation(void)
+{
+  Location* rc = 0;
+
+  if ((rc = (Location*)malloc(sizeof(Location))) == 0)
+    goto error;
+  
+  memset(rc, 0, sizeof(Location));
+  if (!(rc->childs = 
+	avl_alloc_tree(cmpLocationAssoAvl, 
+		       (avl_freeitem_t)destroyLocationAsso)))
+    goto error;
+
+  return rc;  
+ error:  
+  logMemory(LOG_ERR, "malloc: cannot create Location");
+  return destroyLocation(rc);
+}
+
+/*=======================================================================
+ * Function   : destroyLocation
+ * Description: Destroy a Location by freeing own allocated memory.
+ * Synopsis   : void destroyLocation(Location* self)
+ * Input      : Location* self = the address of the configuration to
+ *              destroy.
+ * Output     : Nil address of a Location.
+ =======================================================================*/
+Location* 
+destroyLocation(Location* self)
+{
+  if(self == 0) goto error;
+
+  destroyString(self->uri);
+
+  if (self->directory) {
+    self->directory = destroyString(self->directory);
+  }
+
+  if (self->options) {
+    self->options = destroyString(self->options);
+  }
+
+  // free the LocationAsso tree (and content) too
+  avl_free_tree(self->childs);
+
+  free(self);
+ error:
+  return (Location*)0;
+}
+
+/*=======================================================================
+ * Function   : serializeLocation
+ * Description: Serialize a Location.
+ * Synopsis   : int serializeLocation(Location* self, CvsFile* fd)
+ * Input      : Location* self : what to serialize
+ *              CvsFile* fd : where to serialize
+ * Output     : TRUE on success
+ =======================================================================*/
+int 
+serializeLocation(Location* self, CvsFile* fd)
+{
+  int rc = FALSE;
+  LocationAsso* asso = 0;
+  AVLNode *node = 0;
+
+  if(self == 0) {
+    logMemory(LOG_INFO, "cannot serialize empty Location");
+    goto error;
+  }
+
+  if (!avl_count(self->childs)) {
+    logMemory(LOG_NOTICE, "serialze empty location: %s", self->uri);
+  }
+
+  node = self->childs->head;
+  while (node) {
+    fd->print(fd, "\n(%s\n", strLType(self->type));
+    fd->doCut = FALSE;
+    fd->print(fd, "%s %s %s\n",
+	      self->fingerPrint, self->uri, self->directory);
+    
+    // serialize childs
+    fd->print(fd, "=>\n");
+    if (self->options) {
+      fd->print(fd, "options: %s\n", self->options);
+    }
+    
+    // allow to cut location stanza into multiple files
+    do {
+      asso = node->item;
+      if (!serializeExtractRecord(asso->archive, fd)) goto error;
+      fd->print(fd, "\t%s\n", asso->path);
+      
+      node = node->next;
+    } while (node && fd->offset < env.cvsprintMax);
+    
+    fd->print(fd, ")\n");
+    fd->doCut = TRUE;
+  }
+
+  ++env.progBar.cur;
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMemory(LOG_ERR, "serializeLocation fails");
+  }
+  return(rc);
+}
+
+/*=======================================================================
+ * Function   : cmpLocation
+ * Description: Compare 2 locations
+ * Synopsis   : int cmpLocation(const void *p1, const void *p2)
+ * Input      : const void *p1, const void *p2: the locations to compare
+ * Output     : like strcmp
+ =======================================================================*/
+int 
+cmpLocation(const void *p1, const void *p2)
+{
+  int rc = 0;
+
+  /* p1 and p2 are pointers on &items
+   * and items are suposed to be Location* 
+   */
+  
+  Location* a1 = *((Location**)p1);
+  Location* a2 = *((Location**)p2);
+
+  rc = a1->type - a2->type;
+  if (!rc) rc = strcmp(a1->fingerPrint, a2->fingerPrint);
+  if (!rc) rc = strcmp(a1->uri, a2->uri);
+  if (!rc) rc = strcmp(a1->directory, a2->directory);
+  return rc;
+}
+
 
 /*=======================================================================
  * Function   : createExtractTree
  * Description: Create, by memory allocation a ExtractTree projection.
  * Synopsis   : ExtractTree* createExtractTree(void)
  * Input      : N/A
- * Output     : The address of the create empty configuration.
+ * Output     : The address of the created empty extractTree.
  =======================================================================*/
 ExtractTree* 
 createExtractTree(void)
@@ -348,6 +632,9 @@ createExtractTree(void)
   if (!(rc->img = createContainer())) goto error;
   rc->img->type = IMG;
 
+  // location ring
+  if ((rc->locations = createRing()) == 0) goto error;
+  
   rc->score = -1;
 
   return rc;
@@ -369,10 +656,11 @@ destroyExtractTree(ExtractTree* self)
 {
   if (!self) goto error;
 
-  avl_free_tree(self->containers);
   self->inc = destroyContainer(self->inc);
   self->img = destroyContainer(self->img);
-
+  avl_free_tree(self->containers);
+  self->locations = destroyRing(self->locations,
+				(void*(*)(void*)) destroyLocation);
   free(self);
 
  error:
@@ -396,7 +684,9 @@ serializeExtractTree(Collection* coll, CvsFile* fd)
   int rc = FALSE;
   ExtractTree* self = 0;
   Container* container = 0;
+  Location* location = 0;
   AVLNode *node = 0;
+  RGIT* curr = 0;
   int uid = getuid();
 
   checkCollection(coll);
@@ -434,7 +724,7 @@ serializeExtractTree(Collection* coll, CvsFile* fd)
   if (avl_count(self->img->childs) > 0) {
     if (!serializeContainer(coll, self->img, fd)) goto error;
   }
-
+  
   // serialize all other containers
   if (avl_count(self->containers)) {
     for(node = self->containers->head; node; node = node->next) {
@@ -442,7 +732,15 @@ serializeExtractTree(Collection* coll, CvsFile* fd)
       if (!serializeContainer(coll, container, fd)) goto error;
     }
   }
- 
+
+  // serialize locatons if not empty
+  if (!isEmptyRing(self->locations)) {
+    if (!rgSort(self->locations, cmpLocation)) goto error;
+    while ((location = rgNext_r(self->locations, &curr))) {
+      if (!serializeLocation(location, fd)) goto error;
+    }
+  }
+  
   rc = TRUE;
  error:
   if (!cvsClose(fd)) rc = FALSE;
@@ -488,8 +786,8 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
   if (container->parents->nbItems == 0) goto next;
   switch (container->type) {
   case ISO:
-    logMemory(LOG_ERR, 
-	    "ISO containers must only comes from one archive");
+    logMemory(LOG_ERR, "%s containers must only comes from one archive",
+	      strEType(container->type));
     goto error;
   case TGZ:
   case TBZ:
@@ -498,12 +796,12 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
   case CPIO:
   case ZIP:
     logMemory(LOG_ERR, 
-	    "multi-volume archive is only implemented for RAR container");
+	      "multi-volume archive is only implemented for RAR container");
     goto error;
   case GZIP:
   case BZIP:
     logMemory(LOG_ERR, 
-	    "compression only container must only comes from one archive");
+	      "compression only container must only comes from one archive");
     goto error;
   default:
     break;
@@ -623,18 +921,16 @@ getFromAsso(Container* container, Archive* archive)
 /*=======================================================================
  * Function   : addFromAsso
  * Description: Add a fromAsso if not already into this container
- * Synopsis   : FromAsso* addFromAsso(Collection* coll, Archive* archive
- *                                    Container* container)
- * Input      : Collection* coll : where to add
+ * Synopsis   : FromAsso* addFromAsso(Container* container, 
+ *                                    Archive* archive, char* path)
+ * Input      : Container* container : id
  *              Archive* archive : id
- *              Container* container : id
  *              char* path : path to file into the container
  * Output     : FromAsso* : the FromAsso we have found/added
- * Note       : as an archive may comes from severals containers
+ * Note       : an archive may comes from severals containers
  =======================================================================*/
 FromAsso* 
-addFromAsso(Collection* coll, Archive* archive, Container* container,
-	    char* path)
+addFromAsso(Container* container, Archive* archive, char* path)
 {
   FromAsso* rc = 0;
   FromAsso* asso = 0;
@@ -642,7 +938,6 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   struct tm date;
   time_t time = 0;
 
-  checkCollection(coll);
   if (!container || !archive) goto error;
   logMemory(LOG_DEBUG, "addFromAsso %s:%lli -> %s/%s:%lli",
 	    archive->hash, (long long int)archive->size,
@@ -657,7 +952,7 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   case BZIP:
     if (avl_count(container->childs) > 0) {
       logMemory(LOG_ERR, 
-	      "compression only container must only provides one archive");
+		"compression only container must only provides one archive");
       goto error;
     }    
     break;
@@ -673,15 +968,15 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
     }
 
     if (sscanf(path, "%d-%d-%d,%d:%d:%d",
-	       &date.tm_year, &date.tm_mon, &date.tm_mday,
-	       &date.tm_hour, &date.tm_min, &date.tm_sec)
-	!= 6) {
+    	       &date.tm_year, &date.tm_mon, &date.tm_mday,
+    	       &date.tm_hour, &date.tm_min, &date.tm_sec)
+    	!= 6) {
       logCommon(LOG_ERR, "sscanf: error parsing date '%s'", path);
       goto error;
     }
 
     date.tm_year -= 1900; // from GNU/Linux burning date
-    date.tm_mon -= 1;     // month are managed from 0 to 11 
+    date.tm_mon -= 1;     // month are managed from 0 to 11
     date.tm_isdst = -1;   // no information available about spring date
     if ((time = mktime(&date)) == -1) goto error;
 
@@ -692,7 +987,7 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
     break;
     
   case IMG:
-    // if IMG asso is already, check it match the current's one
+    // if IMG asso is already there, check it match the current's one
     if ((asso = getFromAsso(container, archive))) {
       if (strcmp(asso->path, path)) {
 	logMemory(LOG_ERR,
@@ -749,12 +1044,13 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
     }
     goto error;
   }
+  
  end:
   rc = asso;
  error:
   if (!rc) {
     logMemory(LOG_ERR, "addFromAsso fails");
-    if (asso) delFromAsso(coll, asso);
+    if (asso) delFromAsso(asso);
   }
   return rc;
 }
@@ -762,18 +1058,16 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
 /*=======================================================================
  * Function   : delFromAsso
  * Description: Del a fromAsso
- * Synopsis   : void delFromAsso(Collection* coll, FromAsso* self)
- * Input      : Collection* coll: where to del
- *              FromAsso* self: association to del
+ * Synopsis   : void delFromAsso(FromAsso* self)
+ * Input      : FromAsso* self: association to del
  * Output     : TRUE on success
  =======================================================================*/
 int
-delFromAsso(Collection* coll, FromAsso* self)
+delFromAsso(FromAsso* self)
 {
   int rc = FALSE;
   RGIT* curr = 0;
  
-  checkCollection(coll);
   if (!self) goto error;
   logMemory(LOG_DEBUG, "delFromAsso %s:%lli -> %s/%s:%lli",
 	    self->archive->hash, (long long int)self->archive->size,
@@ -844,7 +1138,7 @@ getContainer(Collection* coll, EType type, Archive* parent)
  * Function   : addContainer
  * Description: Add a new extraction container
  * Synopsis   : Container* addContainer(Collection* coll, EType type,
-                           Archive* parent)
+ Archive* parent)
  * Input      : Collection* coll : where to add
  *              EType type : type of the new container
  *              Archive* parent : first parent
@@ -881,14 +1175,14 @@ addContainer(Collection* coll, EType type, Archive* parent)
   if (!avl_insert(coll->extractTree->containers, container)) {
     if (errno != EEXIST) {
       logMemory(LOG_ERR, "fails to add %s container", strEType(type))
-    }
+	}
     else {
       logMemory(LOG_ERR, "cannot add %i container (already there)",
 		strEType(type))
-    }
+	}
     goto error;
   }
-  
+
   rc = container;
  error:
   if (!rc) {
@@ -911,7 +1205,7 @@ int
 delContainer(Collection* coll, Container* self)
 {
   int rc = FALSE;
-  Archive* arch = 0;
+  Archive* archive = 0;
   AVLNode *node = 0;
 
   checkCollection(coll);
@@ -925,21 +1219,301 @@ delContainer(Collection* coll, Container* self)
 
   // delete content associations to archives
   while ((node = self->childs->head)) {
-    if (!delFromAsso(coll, node->item)) goto error;
+    if (!delFromAsso(node->item)) goto error;
   }
 
+  // INC and IMG do not have parent and do not belong to containers
+  if (self->type == INC || self->type == IMG) goto end;
+  
   // delete container link with archives
-  // (INC and IMG do not had parent)
-  while ((arch = rgHead(self->parents))) {
-    arch->toContainer = 0;
+  while ((archive = rgHead(self->parents))) {
+    archive->toContainer = 0;
     rgRemove(self->parents);
   } 
 
   // delete container from extract tree and free it
   avl_delete(coll->extractTree->containers, self);
 
+ end:
   rc = TRUE;
  error:
+  if (!rc) {
+    logMemory(LOG_ERR, "delContainer fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : getLocationAsso
+ * Description: Search a locationAsso into a Location
+ * Synopsis   : locationAsso* getLocationAsso(Location* location, 
+ *                                    Archive* parent)
+ * Input      : Location* location: where to find
+ *              Archive* archive: content to find 
+ * Output     : The address of the locationAsso.
+ =======================================================================*/
+LocationAsso* 
+getLocationAsso(Location* location, Archive* archive)
+{
+  LocationAsso* rc = 0;
+  LocationAsso asso;
+  AVLNode* node = 0;
+
+  checkLocation(location);
+  checkArchive(archive);
+  logMemory(LOG_DEBUG, "%s", "getLocationAsso");
+
+  // look for locationAsso
+  asso.archive = archive;
+  if ((node = avl_search(location->childs, &asso))) {
+    rc = (LocationAsso*)node->item;
+  }
+ error:
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : addLocationAsso
+ * Description: Add a locationAsso or erase if already into this location
+ * Synopsis   : LocationAsso* addLocationAsso(Collection* coll, 
+ *                     Location* location, Archive* archive, char* path)
+ * Input      : Collection* coll : where to add
+ *              Location* : related location
+ *              Archive* archive : id 
+ *              char* path : path to file into the location
+ * Output     : LocationAsso* : the LocationAsso we have added/erased
+ =======================================================================*/
+LocationAsso* 
+addLocationAsso(Location* location, Archive* archive, char* path)
+{
+  LocationAsso* rc = 0;
+  LocationAsso* asso = 0;
+
+  checkLocation(location);
+  checkArchive(archive);
+  checkString(path, "path");
+  
+  logMemory(LOG_DEBUG, "addLocationAsso %s:%lli -> %s:%s",
+	    archive->hash, (long long int)archive->size,
+	    location->fingerPrint, location->uri);
+  
+  // add new content
+  if (!(asso = createLocationAsso())) goto error;
+  if (!(asso->path = createString(path))) goto error;
+  asso->archive = archive;
+  asso->location = location;
+
+  // only provide archives once by location
+  if (!avl_insert(location->childs, asso)) {
+
+    // add fails
+    if (errno != EEXIST) {
+      logMemory(LOG_ERR, "fails to add add %s:%lli content",
+		archive->hash, (long long int)archive->size);
+      goto error;
+    }
+
+    // already there
+    logMemory(LOG_NOTICE, "erase %s:%lli on location %s:%s",
+	      archive->hash, (long long int)archive->size,
+	      location->fingerPrint, location->uri);
+    
+    if (!(rc = getLocationAsso(location, archive))) {
+      logMemory(LOG_ERR, "fails to erase %s:%lli on location %s:%s",
+		archive->hash, (long long int)archive->size,
+		location->fingerPrint, location->uri);
+      goto error;
+    }
+    
+    rc->path = destroyString(rc->path);
+    rc->path = asso->path;
+    asso->path = 0;
+    goto end;
+  }
+
+  // link archive to location
+  if (!rgInsert(archive->fromLocations, asso)) goto error;
+  
+  rc = asso;
+  asso = 0;
+ end:
+  ;
+ error:
+   if (!rc) {
+     logMemory(LOG_ERR, "addLocationAsso fails");
+   }
+ destroyLocationAsso(asso);
+ return rc;
+}
+
+/*=======================================================================
+ * Function   : delLocationAsso
+ * Description: Del a locationAsso
+ * Synopsis   : void delLocationAsso(LocationAsso* self)
+ * Input      : LocationAsso* asso: association to del
+ * Output     : TRUE on success
+ =======================================================================*/
+int
+delLocationAsso(LocationAsso* self)
+{
+  int rc = FALSE;
+  RGIT* curr = 0;
+ 
+  if (!self) goto error;
+  logMemory(LOG_DEBUG, "delLocationAsso %s:%lli -> %s:%s",
+	    self->archive->hash, (long long int)self->archive->size,
+	    self->location->fingerPrint, self->location->uri);
+
+  // unlink asso from archive
+  if ((curr = rgHaveItem(self->archive->fromLocations, self))) {
+    rgRemove_r(self->archive->fromLocations, &curr);
+  }
+  
+  // delete asso location and free it
+  avl_delete(self->location->childs, self);
+  
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMemory(LOG_ERR, "delLocationAsso fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : getLocation
+ * Description: Search a Location
+ * Synopsis   : Location* getLocation(Collection* coll, LType type,
+ *                            char* fingerPrint, char* path, char* dir)
+ * Input      : Collection* coll: where to find
+ *              LType type: first id
+ *              char* fingerPrint : server that old the directory
+ *              char* path : absolute path of the directory
+ *              char* dir : prefix to add to child's extraction paths
+ * Output     : The address of the Location.
+ =======================================================================*/
+Location* 
+getLocation(Collection* coll, LType type, char* fingerPrint, char* path,
+	    char* dir)
+{
+  Location* rc = 0;
+  RGIT* curr = 0;
+
+  checkCollection(coll);
+  checkString(fingerPrint, "server fingerprint");
+  checkString(path, "path");
+  logMemory(LOG_DEBUG, "getLocation %s:%s", fingerPrint, path);
+
+  // look for location
+  while ((rc = rgNext_r(coll->extractTree->locations, &curr))) {
+    if (rc->type == type &&
+	!strcmp(rc->fingerPrint, fingerPrint) && 
+	!strcmp(rc->uri, path) &&
+	!strcmp(rc->directory, dir)) break;
+  }
+  
+ error:
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : addLocation
+ * Description: Add a new location (or get previous one)
+ * Synopsis   : Location* addLocation(Collection* coll, 
+ *                            char* fingerPrint, char* uri, char* dir)
+ * Input      : Collection* coll: where to find
+ *              char* fingerPrint : server or 'ALL'
+ *              char* uri : absolute path of the directory
+ *              char* dir : prefix to add to child's extraction paths
+ * Output     : Location* : the location (may be already there)
+ =======================================================================*/
+Location*
+addLocation(Collection* coll, LType type, char* fingerPrint, char* uri,
+	    char* dir)
+{
+  Location* rc = 0;
+  Location* location = 0;
+  char* default_dir = ".";
+
+  checkCollection(coll);
+  checkString(fingerPrint, "server fingerprint");
+  checkString(uri, "uri");
+  if (!dir) dir = default_dir;
+  logMemory(LOG_DEBUG, "addLocation %s:%s", fingerPrint, uri);
+
+  if (type == COPY && *uri != '/') {
+    logMemory(LOG_ERR, "COPY location must use an absolute path: get %s",
+	      uri);
+    goto error;
+  }
+
+  // already there
+  if ((location = getLocation(coll, type, fingerPrint, uri, dir))) {
+    logMemory(LOG_INFO, "location already there");
+    goto end;
+  }
+
+  // add new one
+  if ((location = createLocation()) == 0) goto error;
+  if (!(location->uri = createString(uri))) goto error;
+  if (!(location->directory = createString(dir))) goto error;
+  strncpy(location->fingerPrint, fingerPrint, MAX_SIZE_MD5);
+  location->type = type;
+
+  // add location to extractTree
+  if (!rgInsert(coll->extractTree->locations, location)) goto error;
+  location->id = coll->extractTree->maxIdLocation++;
+  
+ end:
+  rc = location;
+ error:
+  if (!rc) {
+    logMemory(LOG_ERR, "addLocation fails");
+    location = destroyLocation(location);
+  }
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : delLocation
+ * Description: Del a location
+ * Synopsis   : int delLocation(Collection* coll, Location* self)
+ * Input      : Collection* coll: where to del
+ *              Location* self: the location to delete
+ * Output     : TRUE on success
+ =======================================================================*/
+int
+delLocation(Collection* coll, Location* self)
+{
+  int rc = FALSE;
+  AVLNode *node = 0;
+  RGIT* curr = 0;
+
+  checkCollection(coll);
+  checkLocation(self);
+  logMemory(LOG_DEBUG, "delLocation %s:%s",
+	    self->fingerPrint, self->uri);
+
+  // delete location associations to archives
+  while ((node = self->childs->head)) {
+    if (!delLocationAsso(node->item)) goto error;
+  }
+  
+  // delete location from extract tree
+  if ((curr = rgHaveItem(coll->extractTree->locations, self))) {
+    rgRemove_r(coll->extractTree->locations, &curr);
+  }
+  
+  // free the location (and locationAsso's avl tree)
+  destroyLocation(self);
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMemory(LOG_ERR, "delLocation fails");
+  }
   return rc;
 }
 
@@ -955,17 +1529,23 @@ int
 diseaseExtractTree(Collection* coll)
 {
   int rc = FALSE;
+  Location* location = 0;
   AVLNode *node = 0;
 
   if(coll == 0) goto error;
   logMemory(LOG_DEBUG, "diseaseExtractTree %s", coll);
 
-  // diseases containers
+  // disease containers
   if (!delContainer(coll, coll->extractTree->inc)) goto error;
   if (!delContainer(coll, coll->extractTree->img)) goto error;
   while ((node = coll->extractTree->containers->head))
     if (!delContainer(coll, node->item)) goto error;
 
+  // disease locations
+  while ((location = rgHead(coll->extractTree->locations))) {
+    if (!delLocation(coll, location)) goto error;
+  }    
+    
   // force scores to be re-computed next
   coll->extractTree->score = -1;
 
@@ -985,4 +1565,3 @@ diseaseExtractTree(Collection* coll)
 /* mode: font-lock */
 /* mode: auto-fill */
 /* End: */
-
