@@ -105,7 +105,7 @@ serializeImage(Image* self, FILE* fd)
  * Function   : cmpImage
  * Description: Compare 2 image files
  * Synopsis   : int cmpImage(const void *p1, const void *p2)
- * Input      : const void *p1, const void *p2: the image to compare
+ * Input      : const void *p1, const void *p2: the images to compare
  * Output     : like strcmp
  =======================================================================*/
 int 
@@ -467,7 +467,6 @@ serializeServerTree(Collection* coll)
       fd = stdout;
       goto error;
     }
-    if (!lock(fileno(fd), F_WRLCK)) goto error;
   }
 
   fprintf(fd, "# This file is managed by MediaTeX software.\n");
@@ -525,7 +524,6 @@ serializeServerTree(Collection* coll)
   rc = TRUE;
  error:
   if (fd != stdout) {
-    if (!unLock(fileno(fd))) rc = FALSE;
     if (fclose(fd)) {
       logMemory(LOG_ERR, "fclose fails: %s", strerror(errno));
       rc = FALSE;
