@@ -41,7 +41,7 @@ createString(const char* content)
     logMemory(LOG_WARNING, "create null String");
   }
 
-  if ((rc = copyString(rc, content)) == 0) {
+  if ((rc = mdtxCopyString(rc, content)) == 0) {
     logMemory(LOG_ERR, "malloc: cannot create String: \"%s\"", content);
   }
 
@@ -96,18 +96,18 @@ destroyString(char* self)
 }
 
 /*=======================================================================
- * Function   : copyString (strdsm) [MediaTeX]
+ * Function   : mdtxCopyString (strdsm) [MediaTeX]
  * Description: Copy a source string into a destination string. The
  *              destination string's memory, if any, is released and a
  *              new allocation is used.
- * Synopsis   : char* copyString(char* destination, char* source)
+ * Synopsis   : char* mdtxCopyString(char* destination, char* source)
  * Input      : char* destination = the destination string
  *              char* source = the source string
  * Output     : Address of the destination string. It changes at each
  *              call.
  =======================================================================*/
 char* 
-copyString(char* destination, const char* source)
+mdtxCopyString(char* destination, const char* source)
 {
   char* rc = 0;
 
