@@ -27,12 +27,16 @@
 
 char* createString(const char* content);
 char* createSizedString(size_t size, const char* content);
-char* copyString(char* destination, const char* source);
+
+// poppler also define copyString so rename it in order a program
+// may link with both mediatex and poppler.
+char* mdtxCopyString(char* destination, const char* source);
+
 char* copySizedString(size_t size, char* destination, const char* source);
 char* catString(char* prefix, const char* suffix);
 char* destroyString(char* self);
 
-inline int isEmptyString(const char* content);
+int isEmptyString(const char* content);
 int cmpString(const void *p1, const void *p2);
 
 #endif /* MDTX_MEMORY_STRDSM_H */
