@@ -75,7 +75,7 @@ miscUsage(char* programName)
 {
   fprintf(stderr, "\nUsage: %s", basename(programName));
   fprintf(stderr, 
-	  "-h | -V | [ -v ]"
+	  " -h | -V | [ -v ]"
 	  " [ -f facility ] [ -l logFile ]"
 	  " [ -s severity[:module(,module)*] ]"
 	  " [ -m memoryLimit ] [ -n ] [ -p ] ");
@@ -300,6 +300,11 @@ setEnv(char* programName, MdtxEnv *self)
   if (!initMalloc(self->allocLimit*MEGA, self->allocDiseaseCallBack))
     goto error2;
 
+  // get tools speaking english for non-regression tests
+  if (self->noRegression) {
+    mdtxSetEnv("LANG", "C");
+  }
+  
   rc = TRUE;
  error2:
   if (!rc) {
@@ -408,7 +413,7 @@ execScript(char** argv, char* user, char* pwd, int doHideStderr)
   
   // fork: new process
   if ((childId = fork()) == -1) {
-      logMisc(LOG_ERR, "fork failed: ", strerror(errno));
+      logMisc(LOG_ERR, "fork failed: %s", strerror(errno));
       goto error;
     }
   
