@@ -5,7 +5,7 @@
  * HTML generator
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -65,7 +65,7 @@ int htmlCaps(FILE* fd, char* text);
   if (!fprintf(fd, "%s", "\n</A>")) goto error;				\
 
 int htmlMainHeadBasic(FILE* fd, char* title, char* url);
-int htmlLeftPageHeadBasic(FILE* fd, char* rep, char* url);
+int htmlLeftPageHeadBasic(FILE* fd, char* rep, char* srcUrl, char* dstUrl);
 int htmlLeftPageTail(FILE* fd);
 int htmlRightHeadBasic(FILE* fd, char* url);
 int htmlMainTail(FILE* fd, char* date);
@@ -73,8 +73,10 @@ int htmlMainTail(FILE* fd, char* date);
 #define SSI_HOME_TEMPLATE "<!--#echo var='HOME' -->"
 #define htmlMainHead(fd, title) \
   htmlMainHeadBasic(fd, title, SSI_HOME_TEMPLATE)
-#define htmlLeftPageHead(fd, rep) \
-  htmlLeftPageHeadBasic(fd, rep, SSI_HOME_TEMPLATE)
+#define htmlLeftPageHead(fd, rep, srcUrl, dstUrl)			\
+  htmlLeftPageHeadBasic(fd, rep,					\
+			srcUrl?srcUrl:SSI_HOME_TEMPLATE,		\
+			dstUrl?dstUrl:SSI_HOME_TEMPLATE)
 #define htmlRightHead(fd) \
   htmlRightHeadBasic(fd, SSI_HOME_TEMPLATE)
 
