@@ -92,21 +92,33 @@ readPublicKey(char* path)
 
 /*=======================================================================
  * Function   : getFingerPrint
- * Description: compute the fingerprint of a key as:
- *              ssh-keygen -lf /etc/ssh/ssh_host_dsa_key.pub
+ * Description: compute the md5 fingerprint of a key as:
+ *              ssh-keygen -lf /etc/ssh/ssh_host_rsa_key.pub
  * Synopsis   : int getFingerPrint(char* key, 
  *                                 char fingerprint[MAX_SIZE_MD5])
  * Input      : char* key: the input key
- *              char fingerprint[MAX_SIZE_MD5]: the fingerprint to store
+ *                 char fingerprint[MAX_SIZE_MD5]: the fingerprint to store
  * Output     : TRUE on success
  *
- * Note       :
+ * Note:
  * 1) http://www.federationhq.de/blog/calculate-ssh-rsa-fingerprint
  * 2) The EVP digest routines are a hight level interface to message
  * digests
  * 3) '=' are use by ssh to pad the base64 encoding, however 
  * the 'key_unbased64_length - nbEquals' trick I found looks very
  * strange (but working)
+
+Keep compatibility with OpenSSH 6.7 and earlier :
+In OpenSSH 6.7 and earlier this fingerprint was a hexadecimal MD5
+checksum ,
+instead a of the base64-encoded SHA256 checksum currently used:
+
+$ cat misc/key.pub 
+ssh-rsa {B64} login@host
+$ echo {B64} | base64 -d | sha256sum 
+xx:xx:... format (key match)
+$ echo {B64} | base64 -d | sha256sum | base64
+sould be new format  (but do not match !?)
  =======================================================================*/
 int 
 getFingerPrint(char* key, char fingerprint[MAX_SIZE_MD5+1])
@@ -115,7 +127,7 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_MD5+1])
   unsigned char *key_unbase64 = (unsigned char *)0;
   int key_unbased64_length = 0;
   int i;
-  EVP_MD_CTX mdctx;
+  EVP_MD_CTX *mdctx;
   unsigned char md_value[EVP_MAX_MD_SIZE];
   unsigned int md_len;
   char* end;
@@ -154,27 +166,31 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_MD5+1])
     goto error;
   }
 
-  // The next step is, to calculate an MD5 hash from key_unbase64.
-
+  // The next step is, to calculate an SHA256 hash from key_unbase64.
+  if (!(mdctx = EVP_MD_CTX_create())) {
+    logMisc(LOG_ERR, "EVP_MD_CTX_create fails");
+    goto error;
+  }
+  
   // get us an openssl context
-  EVP_MD_CTX_init(&mdctx);
+  EVP_MD_CTX_init(mdctx);
 
   // initialize our context to use MD5 as the hashing algorithm
-  if (EVP_DigestInit_ex(&mdctx, EVP_md5(), 0) != 1) {
+  if (EVP_DigestInit_ex(mdctx, EVP_md5(), 0) != 1) {
     logMisc(LOG_ERR, "EVP_DigestInit_ex fails");
     goto error;
   }
 
   // put the unbase64 key into the context
   // -nbEquals is neeeded to work by looks very strange
-  if (EVP_DigestUpdate(&mdctx, key_unbase64,
+  if (EVP_DigestUpdate(mdctx, key_unbase64,
   		       key_unbased64_length - nbEquals) != 1) {
     logMisc(LOG_ERR, "EVP_DigestUpdate fails");
     goto error;
   }
 
   // finish the hashing and get us the hash value in md_value
-  if (EVP_DigestFinal_ex(&mdctx, md_value, &md_len) != 1) {
+  if (EVP_DigestFinal_ex(mdctx, md_value, &md_len) != 1) {
     logMisc(LOG_ERR, "EVP_DigestFinal fails");
     goto error;
   }
@@ -183,8 +199,8 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_MD5+1])
   for(i=0; i<MD5_DIGEST_LENGTH; i++)
     sprintf(fingerprint+(i<<1), "%02x", md_value[i]);
   fingerprint[MAX_SIZE_MD5] = (char)0;
- 
-  EVP_MD_CTX_cleanup(&mdctx);
+
+  EVP_MD_CTX_destroy(mdctx);
   rc = TRUE;
  error:
   *end = (char)0;
