@@ -65,7 +65,7 @@ callAccess(char* path, int* isThere)
 {
   int rc = FALSE;
 
-  logMain(LOG_DEBUG, "callAccess %s", path);
+  logMisc(LOG_DEBUG, "callAccess %s", path);
   checkLabel(path);
   *isThere = FALSE;
 
@@ -73,8 +73,8 @@ callAccess(char* path, int* isThere)
     *isThere = TRUE;
   }
   else {
-    if (!errno == ENOENT) {
-      logMain(LOG_ERR, "unexpected error code (%i): %s", 
+    if (!(errno == ENOENT)) {
+      logMisc(LOG_ERR, "unexpected error code (%i): %s", 
 	      errno, strerror(errno));
       goto error;
     }
@@ -83,7 +83,7 @@ callAccess(char* path, int* isThere)
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "callAccess fails");
+    logMisc(LOG_ERR, "callAccess fails");
   }
   return rc;
 }
@@ -102,12 +102,12 @@ checkDirectory(char* path, int *isDirectory)
   int rc = FALSE;
   struct stat statBuffer;
 
-  logMain(LOG_DEBUG, "checkDirectory %s", path);
+  logMisc(LOG_DEBUG, "checkDirectory %s", path);
   checkLabel(path);
   
   // get file attributes
   if (lstat(path, &statBuffer)) {
-    logMain(LOG_ERR, "status error on %s: %s", path, strerror(errno));
+    logMisc(LOG_ERR, "status error on %s: %s", path, strerror(errno));
     goto error;
   }
   
@@ -115,7 +115,7 @@ checkDirectory(char* path, int *isDirectory)
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "checkDirectory fails");
+    logMisc(LOG_ERR, "checkDirectory fails");
   }
   return rc;
 }
@@ -139,7 +139,7 @@ makeDir(char* base, char* path, mode_t mode)
   mode_t mask;
   int isThere = FALSE;
 
-  logMain(LOG_DEBUG, "makeDir %s - %s", path, base);
+  logMisc(LOG_DEBUG, "makeDir %s - %s", path, base);
   mask = umask(0000);
   checkLabel(path);
 
@@ -152,11 +152,11 @@ makeDir(char* base, char* path, mode_t mode)
       path[i] = (char)0;
 
       if (!mkdir(path, mode)) { // (mode & ~umask & 0777)
-	logMain(LOG_INFO, "mkdir %s", path);
+	logMisc(LOG_INFO, "mkdir %s", path);
       }
       else {
 	if (errno != EEXIST) {
-	  logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
+	  logMisc(LOG_ERR, "mkdir fails: %s", strerror(errno));
 	  goto error;
 	}
 	else {
@@ -174,7 +174,7 @@ makeDir(char* base, char* path, mode_t mode)
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "makeDir fails");
+    logMisc(LOG_ERR, "makeDir fails");
   }
   umask(mask);
   return rc;
@@ -198,7 +198,7 @@ removeDir(char* base, char* path)
   int lastSlash = 0;
 
   checkLabel(path);
-  logMain(LOG_DEBUG, "removeDir %s - %s", path, base);
+  logMisc(LOG_DEBUG, "removeDir %s - %s", path, base);
 
   // remove the temporary extraction directory into the cache
   i = strlen(path)-1;
@@ -213,16 +213,16 @@ removeDir(char* base, char* path)
     while (i>l && path[i] != '/') --i;
 
     if (!rmdir(path)) {
-      logMain(LOG_INFO, "rmdir %s", path);
+      logMisc(LOG_INFO, "rmdir %s", path);
     }
     else {
       if (errno != ENOTEMPTY && errno != EBUSY) {
-	logMain(LOG_ERR, "rmdir fails: (%i) %s", errno, strerror(errno));
+	logMisc(LOG_ERR, "rmdir fails: (%i) %s", errno, strerror(errno));
 	goto error;
       }
       else {
 	// still used
-	logMain(LOG_INFO, "keep not empty directory: %s", path);
+	logMisc(LOG_INFO, "keep not empty directory: %s", path);
 	goto end;
       }
     }
@@ -235,7 +235,7 @@ removeDir(char* base, char* path)
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "removeDir fails");
+    logMisc(LOG_ERR, "removeDir fails");
   }
   return rc;
 }
@@ -263,7 +263,7 @@ getUnusedPath(char* path, int lenFilename)
   int i = 0;
   int j = 0;
 
-  logMain(LOG_DEBUG, "getUnusedPath %s / %i", path, lenFilename);
+  logMisc(LOG_DEBUG, "getUnusedPath %s / %i", path, lenFilename);
   checkLabel(path);
   if ((lenPath = strlen(path)) + 3 > MAX_SIZE_STRING) goto error;
 
@@ -304,7 +304,7 @@ getUnusedPath(char* path, int lenFilename)
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "getUnusedPath fails");
+    logMisc(LOG_ERR, "getUnusedPath fails");
   }
   return rc;
 }
@@ -337,17 +337,17 @@ buildAbsoluteTargetPath(char** newAbsolutePath, char* prefix, char* postfix)
   int lastFileOne = 0;
   int collision = 0;
 
-  logMain(LOG_DEBUG, "buildAbsoluteTargetPath %s / %s", prefix, postfix);
+  logMisc(LOG_DEBUG, "buildAbsoluteTargetPath %s / %s", prefix, postfix);
 
   checkLabel(prefix);
   if (strlen(prefix) > MAX_SIZE_STRING) {
-    logMain(LOG_ERR, "prefix is too long");
+    logMisc(LOG_ERR, "prefix is too long");
     goto error;
   }
 
   checkLabel(postfix);
   if (strlen(postfix) > MAX_SIZE_STRING) {
-    logMain(LOG_ERR, "postfix is too long");
+    logMisc(LOG_ERR, "postfix is too long");
     goto error;
   }
 
@@ -400,7 +400,7 @@ buildAbsoluteTargetPath(char** newAbsolutePath, char* prefix, char* postfix)
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "buildAbsoluteTargetPath fails");
+    logMisc(LOG_ERR, "buildAbsoluteTargetPath fails");
     *newAbsolutePath = 0;
   }
   return rc;
@@ -558,6 +558,7 @@ cmpDirectoryAcl(char* path, char* aclVal, char* collUser, int *res)
   }
 
   // retrieve existing default acl (only on directories)
+  acl_free(acl2);
   if (!(acl2 = acl_get_file(path, ACL_TYPE_DEFAULT))) {
     logMisc(LOG_ERR, "fails getting default acl of %s: %s",
 	    path, strerror(errno));
