@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -150,7 +150,7 @@ extern int cata_debug;
 
 /* Value type.  */
 #if ! defined CATA_STYPE && ! defined CATA_STYPE_IS_DECLARED
-typedef union CATA_STYPE CATA_STYPE;
+
 union CATA_STYPE
 {
 #line 60 "parser/catalogFile.y" /* yacc.c:355  */
@@ -165,6 +165,8 @@ union CATA_STYPE
 
 #line 167 "parser/catalogFile.tab.c" /* yacc.c:355  */
 };
+
+typedef union CATA_STYPE CATA_STYPE;
 # define CATA_STYPE_IS_TRIVIAL 1
 # define CATA_STYPE_IS_DECLARED 1
 #endif
@@ -201,7 +203,7 @@ int cata_parse (yyscan_t yyscanner, Collection* coll, Category* category, Human*
 
 #define YYSTYPE CATA_STYPE
 
-#line 205 "parser/catalogFile.tab.c" /* yacc.c:355  */
+#line 207 "parser/catalogFile.tab.c" /* yacc.c:355  */
 
 #endif /* !YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED  */
 
@@ -217,7 +219,7 @@ void cata_error(yyscan_t yyscanner, Collection* coll, Category* category,
 		Human* human, Document* document, Archive* archive,
 		const char* message);
 
-#line 221 "parser/catalogFile.tab.c" /* yacc.c:358  */
+#line 223 "parser/catalogFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1372,7 +1374,7 @@ yyreduce:
   logParser(LOG_WARNING, "the %s' catalog file was empty",
 	    coll->label);
 }
-#line 1376 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1378 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
@@ -1381,7 +1383,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "stanzas: stanzas stanza");
 }
-#line 1385 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1387 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
@@ -1389,7 +1391,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanzas: stanza");
 }
-#line 1393 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1395 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
@@ -1397,7 +1399,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: defCategory");
 }
-#line 1401 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1403 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 7:
@@ -1405,7 +1407,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: defHuman");
 }
-#line 1409 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1411 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 8:
@@ -1413,7 +1415,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: defDocument");
 }
-#line 1417 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1419 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
@@ -1421,7 +1423,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: deFaRCHIVE");
 }
-#line 1425 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1427 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
@@ -1430,7 +1432,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "cateCaracs: cateCaracs cateCarac");
 }
-#line 1434 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1436 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
@@ -1438,7 +1440,7 @@ yyreduce:
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "cateCaracs: cateCarac");
 }
-#line 1442 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1444 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
@@ -1449,7 +1451,7 @@ yyreduce:
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, CATE, category, (yyvsp[0].string))) YYERROR;
 }
-#line 1453 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1455 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
@@ -1458,7 +1460,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCaracs: docCaracs docCarac");
 }
-#line 1462 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1464 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
@@ -1466,7 +1468,7 @@ yyreduce:
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "docCaracs: docCarac");
 }
-#line 1470 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1472 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
@@ -1477,7 +1479,7 @@ yyreduce:
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, DOC, document, (yyvsp[0].string))) YYERROR;
 }
-#line 1481 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1483 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
@@ -1486,7 +1488,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "humCaracs: humCaracs humCarac");
 }
-#line 1490 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1492 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
@@ -1494,7 +1496,7 @@ yyreduce:
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "humCaracs: humCarac");
 }
-#line 1498 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1500 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1505,7 +1507,7 @@ yyreduce:
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, HUM, human, (yyvsp[0].string))) YYERROR;
 }
-#line 1509 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1511 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
@@ -1514,7 +1516,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "archCaracs: archCaracs archCarac");
 }
-#line 1518 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1520 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1522,7 +1524,7 @@ yyreduce:
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "archCaracs: archCarac");
 }
-#line 1526 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1528 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1533,7 +1535,7 @@ yyreduce:
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, ARCH, archive, (yyvsp[0].string))) YYERROR;
 }
-#line 1537 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1539 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 22:
@@ -1543,7 +1545,7 @@ yyreduce:
 	    "newCategory : category caracs");
   category = 0;
 }
-#line 1547 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1549 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1553,7 +1555,7 @@ yyreduce:
 	    "newCategory : category");
   category = 0;
 }
-#line 1557 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1559 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 24:
@@ -1563,7 +1565,7 @@ yyreduce:
 	    "newCategory cateCaracs");
   category = 0;
 }
-#line 1567 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1569 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 25:
@@ -1572,7 +1574,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "newCategory");
   category = 0;
 }
-#line 1576 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1578 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 26:
@@ -1583,7 +1585,7 @@ yyreduce:
   if (!((yyval.category) = addCategory(coll, (yyvsp[0].string), TRUE))) YYERROR;
   category = (yyval.category);
 }
-#line 1587 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1589 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 27:
@@ -1594,7 +1596,7 @@ yyreduce:
   if (!((yyval.category) = addCategory(coll, (yyvsp[0].string), FALSE))) YYERROR;
   category = (yyval.category);
 }
-#line 1598 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1600 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 28:
@@ -1604,7 +1606,7 @@ yyreduce:
 	    "categories: categories , category");
   if (!addCategoryLink(coll, (yyvsp[0].category), category)) YYERROR;
 }
-#line 1608 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1610 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 29:
@@ -1613,7 +1615,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "categories: category");
   if (!addCategoryLink(coll, (yyvsp[0].category), category)) YYERROR;
 }
-#line 1617 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1619 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 30:
@@ -1622,7 +1624,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: category: %s", LINENO, (yyvsp[0].string));
   if (!((yyval.category) = addCategory(coll, (yyvsp[0].string), FALSE))) YYERROR;
 }
-#line 1626 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1628 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 31:
@@ -1632,7 +1634,7 @@ yyreduce:
 	    "defHuman: newHuman COLON humCategories humCaracs");
   human = 0;
 }
-#line 1636 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1638 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 32:
@@ -1642,7 +1644,7 @@ yyreduce:
 	    "defHuman: newHuman : humCategories");
   human = 0;
 }
-#line 1646 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1648 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 33:
@@ -1652,7 +1654,7 @@ yyreduce:
 	    "defHuman: newHuman humCaracs");
   human = 0;
 }
-#line 1656 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1658 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 34:
@@ -1661,7 +1663,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "defHuman: newHuman");
   human = 0;
 }
-#line 1665 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1667 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 35:
@@ -1671,7 +1673,7 @@ yyreduce:
 	    "newHuman: HUMAN human");
   human = (yyvsp[0].human);
 }
-#line 1675 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1677 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 36:
@@ -1680,7 +1682,7 @@ yyreduce:
     logParser(LOG_DEBUG, "line %i: human: %s %s", LINENO, (yyvsp[-1].string), (yyvsp[0].string));
     if (!((yyval.human) = addHuman(coll, (yyvsp[-1].string), (yyvsp[0].string)))) YYERROR;
 }
-#line 1684 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1686 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 37:
@@ -1690,7 +1692,7 @@ yyreduce:
 	    "humCategories: humCategories , category");
   if (!addHumanToCategory(coll, human, (yyvsp[0].category))) YYERROR;
 }
-#line 1694 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1696 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 38:
@@ -1700,7 +1702,7 @@ yyreduce:
 	    "humCategories: category");
   if (!addHumanToCategory(coll, human, (yyvsp[0].category))) YYERROR;
 }
-#line 1704 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1706 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 39:
@@ -1710,7 +1712,7 @@ yyreduce:
 	    "defArchive: newArchive caracs");
   archive = 0;
 }
-#line 1714 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1716 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 40:
@@ -1720,7 +1722,7 @@ yyreduce:
 	    "defArchive: neWArchive");
   archive = 0;
 }
-#line 1724 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1726 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 41:
@@ -1730,7 +1732,7 @@ yyreduce:
 	    "newArchive: ARCHIVE archive");
   archive = (yyvsp[0].archive);
 }
-#line 1734 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1736 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 42:
@@ -1743,7 +1745,7 @@ yyreduce:
     YYERROR;
   }
 }
-#line 1747 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1749 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 43:
@@ -1754,7 +1756,7 @@ yyreduce:
 	    "docWiths docCaracs docArchives");
   document = 0;
 }
-#line 1758 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1760 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 44:
@@ -1764,7 +1766,7 @@ yyreduce:
 	    "newDocument: DOCUMENT document");
   document = (yyvsp[0].document);
 }
-#line 1768 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1770 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 45:
@@ -1773,7 +1775,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: document: %s", LINENO, (yyvsp[0].string));
   if (!((yyval.document) = addDocument(coll, (yyvsp[0].string)))) YYERROR;
 }
-#line 1777 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1779 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 46:
@@ -1782,7 +1784,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCategories2: : docCategories");
 }
-#line 1786 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1788 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 47:
@@ -1791,7 +1793,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCategories: nil");
 }
-#line 1795 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1797 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 48:
@@ -1801,7 +1803,7 @@ yyreduce:
 	    "docCategories: docCategories , category");
   if (!addDocumentToCategory(coll, document, (yyvsp[0].category))) YYERROR;
 }
-#line 1805 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1807 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 49:
@@ -1811,7 +1813,7 @@ yyreduce:
 	    "docCategories: category");
   if (!addDocumentToCategory(coll, document, (yyvsp[0].category))) YYERROR;
 }
-#line 1815 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1817 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 50:
@@ -1820,7 +1822,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCaracs2: docCaracs");
 }
-#line 1824 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1826 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 51:
@@ -1829,7 +1831,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCaracs2: (0)");
 }
-#line 1833 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1835 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 52:
@@ -1837,7 +1839,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "docWiths: roles");
 }
-#line 1841 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1843 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 53:
@@ -1845,7 +1847,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "docWiths: (0)");
 }
-#line 1849 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1851 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 54:
@@ -1853,7 +1855,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "roles: roles role");
 }
-#line 1857 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1859 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 55:
@@ -1861,7 +1863,7 @@ yyreduce:
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "roles: role");
 }
-#line 1865 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1867 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 56:
@@ -1872,7 +1874,7 @@ yyreduce:
   if (!(role = addRole(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoRole(coll, role, (yyvsp[0].human), document)) YYERROR;
 }
-#line 1876 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1878 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 57:
@@ -1880,7 +1882,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: docArchives: archives", LINENO);
 }
-#line 1884 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1886 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 58:
@@ -1888,7 +1890,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %i: docArchives: (0)", LINENO);
 }
-#line 1892 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1894 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 59:
@@ -1898,7 +1900,7 @@ yyreduce:
 	    "archives: archives archive");
   if (!addArchiveToDocument(coll, (yyvsp[0].archive), document)) YYERROR;
 }
-#line 1902 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1904 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 60:
@@ -1907,11 +1909,11 @@ yyreduce:
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "archives: archive");
  if (!addArchiveToDocument(coll, (yyvsp[0].archive), document)) YYERROR;
 }
-#line 1911 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1913 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1915 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1917 "parser/catalogFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2195,7 +2197,6 @@ int parseCatalogFile(Collection* coll, const char* path)
       logParser(LOG_ERR, "cannot open input stream: %s", path); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
 
   cata_set_in(inputStream, scanner);
@@ -2209,14 +2210,10 @@ int parseCatalogFile(Collection* coll, const char* path)
     logParser(LOG_ERR, "catalog parser fails on line %i",
 	    cata_get_lineno(scanner));
     logParser(LOG_ERR, "please edit %s", path?path:"stdin");
-    goto error3;
+    goto error2;
   }
 
   rc = TRUE;
- error3:
-  if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) rc = FALSE;
-  }
  error2:
   if (inputStream != stdin) {
     fclose(inputStream);
