@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -192,7 +192,7 @@ extern int conf_debug;
 
 /* Value type.  */
 #if ! defined CONF_STYPE && ! defined CONF_STYPE_IS_DECLARED
-typedef union CONF_STYPE CONF_STYPE;
+
 union CONF_STYPE
 {
 #line 60 "parser/confFile.y" /* yacc.c:355  */
@@ -205,6 +205,8 @@ union CONF_STYPE
 
 #line 207 "parser/confFile.tab.c" /* yacc.c:355  */
 };
+
+typedef union CONF_STYPE CONF_STYPE;
 # define CONF_STYPE_IS_TRIVIAL 1
 # define CONF_STYPE_IS_DECLARED 1
 #endif
@@ -241,7 +243,7 @@ int conf_parse (yyscan_t yyscanner, Collection* coll);
 
 #define YYSTYPE CONF_STYPE
 
-#line 245 "parser/confFile.tab.c" /* yacc.c:355  */
+#line 247 "parser/confFile.tab.c" /* yacc.c:355  */
 
 #endif /* !YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED  */
 
@@ -256,7 +258,7 @@ int conf_parse (yyscan_t yyscanner, Collection* coll);
 void conf_error(yyscan_t yyscanner, Collection* coll, 
 		const char* message);
 
-#line 260 "parser/confFile.tab.c" /* yacc.c:358  */
+#line 262 "parser/confFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1423,7 +1425,7 @@ yyreduce:
 	    "collectionStanza: newCollection collectionLines confENDBLOCK");
   coll = 0;
 }
-#line 1427 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1429 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 7:
@@ -1438,7 +1440,7 @@ yyreduce:
   strncpy(coll->masterHost, (yyvsp[-2].string), MAX_SIZE_HOST);
   coll->masterPort = (yyvsp[0].number);
 }
-#line 1442 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1444 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
@@ -1447,7 +1449,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i localhost = %s", LINENO, (yyvsp[0].string));
   strncpy(coll->userFingerPrint, (yyvsp[0].string), MAX_SIZE_MD5+1);
 }
-#line 1451 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1453 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
@@ -1456,7 +1458,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache size");
   coll->cacheSize = (yyvsp[-1].number)*(yyvsp[0].size);
 }
-#line 1460 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1462 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
@@ -1465,7 +1467,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache TTL");
   coll->cacheTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1469 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1471 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
@@ -1474,7 +1476,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "query TTL");
   coll->queryTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1478 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1480 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
@@ -1483,7 +1485,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "motd policy");
   coll->motdPolicy = (yyvsp[0].number);
 }
-#line 1487 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1489 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1494,7 +1496,7 @@ yyreduce:
   if (!(supp = addSupport((yyvsp[0].string)))) YYERROR;
   if (!addSupportToCollection(supp, coll)) YYERROR;
 }
-#line 1498 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1500 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1503,7 +1505,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i host = %s", LINENO, (yyvsp[0].string));
   strncpy(getConfiguration()->host, (yyvsp[0].string), MAX_SIZE_HOST);
 }
-#line 1507 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1509 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 22:
@@ -1511,7 +1513,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %-3i networks", LINENO);
 }
-#line 1515 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1517 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1519,7 +1521,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %-3i gateways", LINENO);
 }
-#line 1523 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1525 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 24:
@@ -1529,7 +1531,7 @@ yyreduce:
   destroyString(getConfiguration()->comment);
   if (!(getConfiguration()->comment = createString((yyvsp[0].string)))) YYERROR;
 }
-#line 1533 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1535 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 25:
@@ -1538,7 +1540,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i mdtxPort = %i", LINENO, (yyvsp[0].number));
   getConfiguration()->mdtxPort = (yyvsp[0].number);
 }
-#line 1542 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1544 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 26:
@@ -1547,7 +1549,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i sshPort = %i", LINENO, (yyvsp[0].number));
   getConfiguration()->sshPort = (yyvsp[0].number);
 }
-#line 1551 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1553 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 27:
@@ -1556,7 +1558,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i httpPort = %i", LINENO, (yyvsp[0].number));
   getConfiguration()->httpPort = (yyvsp[0].number);
 }
-#line 1560 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1562 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 28:
@@ -1565,7 +1567,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i httpsPort = %i", LINENO, (yyvsp[0].number));
   getConfiguration()->httpsPort = (yyvsp[0].number);
 }
-#line 1569 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1571 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 29:
@@ -1574,7 +1576,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache size");
   getConfiguration()->cacheSize = (yyvsp[-1].number)*(yyvsp[0].size);
 }
-#line 1578 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1580 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 30:
@@ -1583,7 +1585,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache TTL");
   getConfiguration()->cacheTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1587 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1589 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 31:
@@ -1592,7 +1594,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "query TTL");
   getConfiguration()->queryTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1596 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1598 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 32:
@@ -1601,7 +1603,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "check TTL");
   getConfiguration()->checkTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1605 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1607 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 33:
@@ -1610,7 +1612,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "check TTL");
   getConfiguration()->fileTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1614 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1616 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 34:
@@ -1619,7 +1621,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "supp TTL");
   getConfiguration()->scoreParam.suppTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1623 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1625 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 35:
@@ -1628,7 +1630,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: max");
   getConfiguration()->scoreParam.maxScore = (yyvsp[0].score);
 }
-#line 1632 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1634 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 36:
@@ -1637,7 +1639,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: bad");
   getConfiguration()->scoreParam.badScore = (yyvsp[0].score);
 }
-#line 1641 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1643 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 37:
@@ -1646,7 +1648,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: pow supp");
   getConfiguration()->scoreParam.powSupp = (yyvsp[0].score);
 }
-#line 1650 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1652 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 38:
@@ -1655,7 +1657,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: fact supp");
   getConfiguration()->scoreParam.factSupp = (yyvsp[0].score);
 }
-#line 1659 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1661 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 39:
@@ -1664,7 +1666,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i %s", LINENO, "motd policy");
   getConfiguration()->motdPolicy = (yyvsp[0].number);
 }
-#line 1668 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1670 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 48:
@@ -1673,7 +1675,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i network: %s", LINENO, (yyvsp[0].string));
   if (!addNetworkToRing(coll->networks, (yyvsp[0].string))) YYABORT;
 }
-#line 1677 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1679 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 49:
@@ -1682,7 +1684,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i gateway: %s", LINENO, (yyvsp[0].string));
   if (!addNetworkToRing(coll->gateways, (yyvsp[0].string))) YYABORT;
 }
-#line 1686 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1688 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 50:
@@ -1691,7 +1693,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i network: %s", LINENO, (yyvsp[0].string));
   if (!addNetworkToRing(getConfiguration()->networks, (yyvsp[0].string))) YYABORT;
 }
-#line 1695 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1697 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 51:
@@ -1700,11 +1702,11 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i gateway: %s", LINENO, (yyvsp[0].string));
   if (!addNetworkToRing(getConfiguration()->gateways, (yyvsp[0].string))) YYABORT;
 }
-#line 1704 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1706 "parser/confFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1708 "parser/confFile.tab.c" /* yacc.c:1646  */
+#line 1710 "parser/confFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1983,7 +1985,6 @@ parseConfiguration(const char* path)
       logParser(LOG_ERR, "cannot open input stream: %s", path); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
 
   conf_set_in(inputStream, scanner);
@@ -1997,14 +1998,10 @@ parseConfiguration(const char* path)
     logParser(LOG_ERR, "configuration parser fails on line %i", 
 	    conf_get_lineno(scanner));
     logParser(LOG_ERR, "please edit %s", path?path:"stdin");
-    goto error3;
+    goto error2;
   }
 
   rc = TRUE;
-error3:
-  if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) rc = FALSE;
-  }
  error2:
   if (inputStream != stdin) {
     fclose(inputStream);
