@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -121,51 +121,61 @@ extern int extr_debug;
     extrERROR = 258,
     extrOPEN = 259,
     extrCLOSE = 260,
-    extrTYPE = 261,
-    extrIMPLIES = 262,
-    extrAS = 263,
-    extrHASH = 264,
-    extrCOLON = 265,
-    extrSIZE = 266,
-    extrCOMMA = 267,
-    extrSTRING = 268
+    extrETYPE = 261,
+    extrLTYPE = 262,
+    extrIMPLIES = 263,
+    extrDIRECTORY = 264,
+    extrOPTIONS = 265,
+    extrHASH = 266,
+    extrFINGERPRINT = 267,
+    extrCOLON = 268,
+    extrSIZE = 269,
+    extrCOMMA = 270,
+    extrSTRING = 271
   };
 #endif
 /* Tokens.  */
 #define extrERROR 258
 #define extrOPEN 259
 #define extrCLOSE 260
-#define extrTYPE 261
-#define extrIMPLIES 262
-#define extrAS 263
-#define extrHASH 264
-#define extrCOLON 265
-#define extrSIZE 266
-#define extrCOMMA 267
-#define extrSTRING 268
+#define extrETYPE 261
+#define extrLTYPE 262
+#define extrIMPLIES 263
+#define extrDIRECTORY 264
+#define extrOPTIONS 265
+#define extrHASH 266
+#define extrFINGERPRINT 267
+#define extrCOLON 268
+#define extrSIZE 269
+#define extrCOMMA 270
+#define extrSTRING 271
 
 /* Value type.  */
 #if ! defined EXTR_STYPE && ! defined EXTR_STYPE_IS_DECLARED
-typedef union EXTR_STYPE EXTR_STYPE;
+
 union EXTR_STYPE
 {
 #line 60 "parser/extractFile.y" /* yacc.c:355  */
 
-  off_t  size;
-  char   string[MAX_SIZE_STRING+1];
+  EType  eType;
+  LType  lType;
   char   hash[MAX_SIZE_MD5+1];
-  EType  type; 
+  char   fp[MAX_SIZE_MD5+1];
+  char   string[MAX_SIZE_STRING+1];
+  off_t  size;
   Archive* archive;
 
-#line 161 "parser/extractFile.tab.c" /* yacc.c:355  */
+#line 169 "parser/extractFile.tab.c" /* yacc.c:355  */
 };
+
+typedef union EXTR_STYPE EXTR_STYPE;
 # define EXTR_STYPE_IS_TRIVIAL 1
 # define EXTR_STYPE_IS_DECLARED 1
 #endif
 
 
 
-int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
+int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container, Location* location);
 /* "%code provides" blocks.  */
 #line 26 "parser/extractFile.y" /* yacc.c:355  */
 
@@ -195,12 +205,12 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 
 #define YYSTYPE EXTR_STYPE
 
-#line 199 "parser/extractFile.tab.c" /* yacc.c:355  */
+#line 209 "parser/extractFile.tab.c" /* yacc.c:355  */
 
 #endif /* !YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 68 "parser/extractFile.y" /* yacc.c:358  */
+#line 70 "parser/extractFile.y" /* yacc.c:358  */
 
 // we need YYSTYPE defined first to include the Flex headers
 #include "parser/extractFile.h"
@@ -208,9 +218,10 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 #define LINENO extr_get_lineno(yyscanner)
   
 void extr_error(yyscan_t yyscanner, Collection* coll, 
-		Container* container, const char* message);
+		Container* container, Location* location,
+		const char* message);
 
-#line 214 "parser/extractFile.tab.c" /* yacc.c:358  */
+#line 225 "parser/extractFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -450,23 +461,23 @@ union yyalloc
 #endif /* !YYCOPY_NEEDED */
 
 /* YYFINAL -- State number of the termination state.  */
-#define YYFINAL  9
+#define YYFINAL  11
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   15
+#define YYLAST   32
 
 /* YYNTOKENS -- Number of terminals.  */
-#define YYNTOKENS  14
+#define YYNTOKENS  17
 /* YYNNTS -- Number of nonterminals.  */
-#define YYNNTS  13
+#define YYNNTS  19
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  20
+#define YYNRULES  32
 /* YYNSTATES -- Number of states.  */
-#define YYNSTATES  27
+#define YYNSTATES  46
 
 /* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
    by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   268
+#define YYMAXUTOK   271
 
 #define YYTRANSLATE(YYX)                                                \
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -501,16 +512,18 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
-       5,     6,     7,     8,     9,    10,    11,    12,    13
+       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
+      15,    16
 };
 
 #if EXTR_DEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
-static const yytype_uint8 yyrline[] =
+static const yytype_uint16 yyrline[] =
 {
-       0,   110,   110,   112,   118,   122,   128,   136,   137,   138,
-     144,   162,   175,   179,   185,   187,   196,   200,   206,   213,
-     220
+       0,   117,   117,   119,   125,   129,   135,   140,   147,   148,
+     149,   155,   173,   179,   186,   199,   203,   209,   214,   217,
+     219,   228,   232,   238,   245,   252,   257,   260,   261,   264,
+     268,   274,   281
 };
 #endif
 
@@ -520,10 +533,12 @@ static const yytype_uint8 yyrline[] =
 static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "extrERROR", "extrOPEN", "extrCLOSE",
-  "extrTYPE", "extrIMPLIES", "extrAS", "extrHASH", "extrCOLON", "extrSIZE",
-  "extrCOMMA", "extrSTRING", "$accept", "file", "stanzas", "stanza",
-  "container", "orphaneContainer", "stdContainer", "parents", "childs",
-  "childs2", "parent", "child", "archive", YY_NULLPTR
+  "extrETYPE", "extrLTYPE", "extrIMPLIES", "extrDIRECTORY", "extrOPTIONS",
+  "extrHASH", "extrFINGERPRINT", "extrCOLON", "extrSIZE", "extrCOMMA",
+  "extrSTRING", "$accept", "file", "stanzas", "stanza", "container",
+  "orphaneContainer", "location", "stdContainer", "parents", "contOptions",
+  "childs", "childs2", "parent", "child", "locOptions", "locChilds",
+  "locChilds2", "locChild2", "archive", YY_NULLPTR
 };
 #endif
 
@@ -533,14 +548,14 @@ static const char *const yytname[] =
 static const yytype_uint16 yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268
+     265,   266,   267,   268,   269,   270,   271
 };
 # endif
 
-#define YYPACT_NINF -9
+#define YYPACT_NINF -24
 
 #define yypact_value_is_default(Yystate) \
-  (!!((Yystate) == (-9)))
+  (!!((Yystate) == (-24)))
 
 #define YYTABLE_NINF -1
 
@@ -551,9 +566,11 @@ static const yytype_uint16 yytoknum[] =
      STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
-      -3,    -4,     3,    -3,    -9,    -2,    -1,    -9,    -2,    -9,
-      -9,    -6,    -9,    -2,    -2,    -9,    -9,     0,     4,    -2,
-      -9,    -8,    -9,    -9,    -9,    -9,    -9
+      -3,    -4,     4,    -3,   -24,    -6,    -2,    -1,   -24,     0,
+      -6,   -24,   -24,    -7,   -24,     1,     2,     3,    -6,   -24,
+     -24,     6,     7,     8,    -6,     9,    -6,   -24,   -24,   -24,
+     -24,    10,    -6,   -24,    12,   -24,    11,    -6,   -24,    13,
+     -24,   -24,   -24,   -24,   -24,   -24
 };
 
   /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
@@ -561,23 +578,25 @@ static const yytype_int8 yypact[] =
      means the default is an error.  */
 static const yytype_uint8 yydefact[] =
 {
-       3,     0,     0,     2,     5,    10,     0,     7,     8,     1,
-       4,     0,    11,    15,     9,    13,    18,     0,     0,    14,
-      17,     0,    12,    20,     6,    16,    19
+       3,     0,     0,     2,     5,    11,     0,     0,     8,     0,
+       9,     1,     4,     0,    14,     0,    18,    26,    10,    16,
+      23,     0,    13,     0,    20,     0,    28,    15,    32,    12,
+      17,     0,    19,    22,     0,    25,     0,    27,    30,     0,
+       6,    21,    24,     7,    29,    31
 };
 
   /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-      -9,    -9,    -9,     7,    -9,    -9,    -9,    -9,    -9,    -9,
-       1,    -7,    -5
+     -24,   -24,   -24,    15,   -24,   -24,   -24,   -24,   -24,   -24,
+     -24,   -24,    -9,   -20,   -24,   -24,   -24,   -23,    -5
 };
 
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,     2,     3,     4,     6,     7,     8,    14,    18,    19,
-      15,    20,    16
+      -1,     2,     3,     4,     7,     8,     9,    10,    18,    24,
+      31,    32,    19,    33,    26,    36,    37,    38,    20
 };
 
   /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
@@ -585,39 +604,47 @@ static const yytype_int8 yydefgoto[] =
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_uint8 yytable[] =
 {
-      12,     1,     5,     9,    17,    26,    13,    11,    21,    24,
-      10,    23,    25,     0,    21,    22
+      14,     1,     5,     6,    11,    13,    21,    16,    17,    27,
+      15,    23,    41,    25,    44,    40,    43,    22,    12,    34,
+      28,    39,     0,    29,    30,    35,     0,    34,    42,    45,
+       0,     0,    39
 };
 
 static const yytype_int8 yycheck[] =
 {
-       5,     4,     6,     0,    10,    13,     7,     9,    13,     5,
-       3,    11,    19,    -1,    19,    14
+       5,     4,     6,     7,     0,    11,    13,     8,     8,    18,
+      12,     9,    32,    10,    37,     5,     5,    16,     3,    24,
+      14,    26,    -1,    16,    16,    16,    -1,    32,    16,    16,
+      -1,    -1,    37
 };
 
   /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
      symbol of state STATE-NUM.  */
 static const yytype_uint8 yystos[] =
 {
-       0,     4,    15,    16,    17,     6,    18,    19,    20,     0,
-      17,     9,    26,     7,    21,    24,    26,    10,    22,    23,
-      25,    26,    24,    11,     5,    25,    13
+       0,     4,    18,    19,    20,     6,     7,    21,    22,    23,
+      24,     0,    20,    11,    35,    12,     8,     8,    25,    29,
+      35,    13,    16,     9,    26,    10,    31,    29,    14,    16,
+      16,    27,    28,    30,    35,    16,    32,    33,    34,    35,
+       5,    30,    16,     5,    34,    16
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const yytype_uint8 yyr1[] =
 {
-       0,    14,    15,    15,    16,    16,    17,    18,    18,    18,
-      19,    20,    21,    21,    22,    22,    23,    23,    24,    25,
-      26
+       0,    17,    18,    18,    19,    19,    20,    20,    21,    21,
+      21,    22,    23,    23,    24,    25,    25,    26,    26,    27,
+      27,    28,    28,    29,    30,    31,    31,    32,    32,    33,
+      33,    34,    35
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
 static const yytype_uint8 yyr2[] =
 {
-       0,     2,     1,     0,     2,     1,     5,     1,     1,     2,
-       1,     2,     2,     1,     1,     0,     2,     1,     1,     2,
-       3
+       0,     2,     1,     0,     2,     1,     6,     6,     1,     1,
+       2,     1,     4,     3,     2,     2,     1,     2,     0,     1,
+       0,     2,     1,     1,     2,     2,     0,     1,     0,     2,
+       1,     2,     3
 };
 
 
@@ -645,7 +672,7 @@ do                                                              \
     }                                                           \
   else                                                          \
     {                                                           \
-      yyerror (yyscanner, coll, container, YY_("syntax error: cannot back up")); \
+      yyerror (yyscanner, coll, container, location, YY_("syntax error: cannot back up")); \
       YYERROR;                                                  \
     }                                                           \
 while (0)
@@ -682,7 +709,7 @@ do {                                                                      \
     {                                                                     \
       YYFPRINTF (stderr, "%s ", Title);                                   \
       yy_symbol_print (stderr,                                            \
-                  Type, Value, yyscanner, coll, container); \
+                  Type, Value, yyscanner, coll, container, location); \
       YYFPRINTF (stderr, "\n");                                           \
     }                                                                     \
 } while (0)
@@ -693,13 +720,14 @@ do {                                                                      \
 `----------------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, Container* container)
+yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, Container* container, Location* location)
 {
   FILE *yyo = yyoutput;
   YYUSE (yyo);
   YYUSE (yyscanner);
   YYUSE (coll);
   YYUSE (container);
+  YYUSE (location);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -715,12 +743,12 @@ yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvalue
 `--------------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, Container* container)
+yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, Container* container, Location* location)
 {
   YYFPRINTF (yyoutput, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yyscanner, coll, container);
+  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yyscanner, coll, container, location);
   YYFPRINTF (yyoutput, ")");
 }
 
@@ -753,7 +781,7 @@ do {                                                            \
 `------------------------------------------------*/
 
 static void
-yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yyscanner, Collection* coll, Container* container)
+yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yyscanner, Collection* coll, Container* container, Location* location)
 {
   unsigned long int yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
@@ -767,7 +795,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yysca
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
                        &(yyvsp[(yyi + 1) - (yynrhs)])
-                                              , yyscanner, coll, container);
+                                              , yyscanner, coll, container, location);
       YYFPRINTF (stderr, "\n");
     }
 }
@@ -775,7 +803,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yysca
 # define YY_REDUCE_PRINT(Rule)          \
 do {                                    \
   if (yydebug)                          \
-    yy_reduce_print (yyssp, yyvsp, Rule, yyscanner, coll, container); \
+    yy_reduce_print (yyssp, yyvsp, Rule, yyscanner, coll, container, location); \
 } while (0)
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
@@ -1033,12 +1061,13 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 `-----------------------------------------------*/
 
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner, Collection* coll, Container* container)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner, Collection* coll, Container* container, Location* location)
 {
   YYUSE (yyvaluep);
   YYUSE (yyscanner);
   YYUSE (coll);
   YYUSE (container);
+  YYUSE (location);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
@@ -1056,7 +1085,7 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner
 `----------*/
 
 int
-yyparse (yyscan_t yyscanner, Collection* coll, Container* container)
+yyparse (yyscan_t yyscanner, Collection* coll, Container* container, Location* location)
 {
 /* The lookahead symbol.  */
 int yychar;
@@ -1304,54 +1333,62 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 112 "parser/extractFile.y" /* yacc.c:1646  */
+#line 119 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_WARNING, "the %s' extract file was empty", 
 	    coll->label);
 }
-#line 1313 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1342 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 119 "parser/extractFile.y" /* yacc.c:1646  */
+#line 126 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stanzas: stanzas stanza", LINENO);
 }
-#line 1321 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1350 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 123 "parser/extractFile.y" /* yacc.c:1646  */
+#line 130 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stanzas: stanza", LINENO);
 }
-#line 1329 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1358 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 129 "parser/extractFile.y" /* yacc.c:1646  */
+#line 136 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "stanza: (container => childs)");
-
 }
-#line 1339 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1367 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 9:
-#line 139 "parser/extractFile.y" /* yacc.c:1646  */
+  case 7:
+#line 141 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_DEBUG, "line %i: stdContainer parents", LINENO);
+  logParser(LOG_DEBUG, "line %i: %s", LINENO, 
+	    "stanza: (location => locChilds)");
 }
-#line 1347 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1376 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 145 "parser/extractFile.y" /* yacc.c:1646  */
+#line 150 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: stdContainer parents", LINENO);
+}
+#line 1384 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 11:
+#line 156 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: orphaneContainer: %s", 
-	    LINENO, strEType((yyvsp[0].type)));
-  switch ((yyvsp[0].type)) {
+	    LINENO, strEType((yyvsp[0].eType)));
+  switch ((yyvsp[0].eType)) {
   case INC:
     container = coll->extractTree->inc;
     break;
@@ -1364,42 +1401,71 @@ yyreduce:
     YYERROR;
   }
 }
-#line 1368 "parser/extractFile.tab.c" /* yacc.c:1646  */
-    break;
-
-  case 11:
-#line 163 "parser/extractFile.y" /* yacc.c:1646  */
-    {
-  logParser(LOG_DEBUG, "line %i: stdContainer: %s archive",
-	    LINENO, strEType((yyvsp[-1].type)));
-  if ((yyvsp[-1].type) == INC || (yyvsp[-1].type) == IMG) {
-    logParser(LOG_ERR, "line %i: %s (%s)", LINENO, 
-	      "'INC' and 'IMG' containers cannot have parent");
-    YYERROR;
-  }
-  if (!(container = addContainer(coll, (yyvsp[-1].type), (yyvsp[0].archive)))) YYERROR;
-}
-#line 1383 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1405 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 176 "parser/extractFile.y" /* yacc.c:1646  */
+#line 174 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_DEBUG, "line %i: parents: parents parent", LINENO);
+  logParser(LOG_DEBUG, "line %i: location: %s %s %s %s", 
+	    LINENO, strLType((yyvsp[-3].lType)), (yyvsp[-2].fp), (yyvsp[-1].string), (yyvsp[0].string));
+  if (!(location = addLocation(coll, (yyvsp[-3].lType), (yyvsp[-2].fp), (yyvsp[-1].string), (yyvsp[0].string)))) YYERROR;
 }
-#line 1391 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1415 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
 #line 180 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_DEBUG, "line %i: parents: parent", LINENO);
+  logParser(LOG_DEBUG, "line %i: location: %s %s %s", 
+	    LINENO, strLType((yyvsp[-2].lType)), (yyvsp[-1].fp), (yyvsp[0].string));
+  if (!(location = addLocation(coll, (yyvsp[-2].lType), (yyvsp[-1].fp), (yyvsp[0].string), NULL))) YYERROR;
 }
-#line 1399 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1425 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 14:
+#line 187 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: stdContainer: %s archive",
+	    LINENO, strEType((yyvsp[-1].eType)));
+  if ((yyvsp[-1].eType) == INC || (yyvsp[-1].eType) == IMG) {
+    logParser(LOG_ERR, "line %i: %s (%s)", LINENO, 
+	      "'INC' and 'IMG' containers cannot have parent");
+    YYERROR;
+  }
+  if (!(container = addContainer(coll, (yyvsp[-1].eType), (yyvsp[0].archive)))) YYERROR;
+}
+#line 1440 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 187 "parser/extractFile.y" /* yacc.c:1646  */
+#line 200 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: parents: parents parent", LINENO);
+}
+#line 1448 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 16:
+#line 204 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: parents: parent", LINENO);
+}
+#line 1456 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 17:
+#line 210 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: contOptions: directory %s", LINENO, (yyvsp[0].string));
+  if (!(container->directory = createString((yyvsp[0].string)))) YYERROR;
+}
+#line 1465 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 20:
+#line 219 "parser/extractFile.y" /* yacc.c:1646  */
     {
   if (container->type != INC && container->type != IMG) {
     logParser(LOG_ERR, "line %i: %s", LINENO, 
@@ -1407,54 +1473,88 @@ yyreduce:
     YYERROR;
   }
 }
-#line 1411 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1477 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 16:
-#line 197 "parser/extractFile.y" /* yacc.c:1646  */
+  case 21:
+#line 229 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: childs: childs child", LINENO);
 }
-#line 1419 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1485 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 17:
-#line 201 "parser/extractFile.y" /* yacc.c:1646  */
+  case 22:
+#line 233 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: childs: child", LINENO);
 }
-#line 1427 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1493 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 18:
-#line 207 "parser/extractFile.y" /* yacc.c:1646  */
+  case 23:
+#line 239 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parent: archive", LINENO);
   if (!addFromArchive(coll, container, (yyvsp[0].archive))) YYERROR;
 }
-#line 1436 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1502 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 19:
-#line 214 "parser/extractFile.y" /* yacc.c:1646  */
+  case 24:
+#line 246 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: child: archive %s", LINENO, (yyvsp[0].string));
-  if (!(addFromAsso(coll, (yyvsp[-1].archive), container, (yyvsp[0].string)))) YYERROR;
+  if (!(addFromAsso(container, (yyvsp[-1].archive), (yyvsp[0].string)))) YYERROR;
 }
-#line 1445 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1511 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 20:
-#line 221 "parser/extractFile.y" /* yacc.c:1646  */
+  case 25:
+#line 253 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: locOptions: options %s", LINENO, (yyvsp[0].string));
+  if (!(location->directory = createString((yyvsp[0].string)))) YYERROR;
+}
+#line 1520 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 29:
+#line 265 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: locChilds: locChilds locChild", LINENO);
+}
+#line 1528 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 30:
+#line 269 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: locChilds: locChild", LINENO);
+}
+#line 1536 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 31:
+#line 275 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: locChild: archive %s", LINENO, (yyvsp[0].string));
+  if (!(addLocationAsso(location, (yyvsp[-1].archive), (yyvsp[0].string)))) YYERROR;
+}
+#line 1545 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 32:
+#line 282 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: archive: %s:%lli", LINENO, (yyvsp[-2].hash), (yyvsp[0].size));
   if (!((yyval.archive) = addArchive(coll, (yyvsp[-2].hash), (yyvsp[0].size)))) YYERROR;
 }
-#line 1454 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1554 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1458 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1558 "parser/extractFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1504,7 +1604,7 @@ yyerrlab:
     {
       ++yynerrs;
 #if ! YYERROR_VERBOSE
-      yyerror (yyscanner, coll, container, YY_("syntax error"));
+      yyerror (yyscanner, coll, container, location, YY_("syntax error"));
 #else
 # define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                         yyssp, yytoken)
@@ -1531,7 +1631,7 @@ yyerrlab:
                 yymsgp = yymsg;
               }
           }
-        yyerror (yyscanner, coll, container, yymsgp);
+        yyerror (yyscanner, coll, container, location, yymsgp);
         if (yysyntax_error_status == 2)
           goto yyexhaustedlab;
       }
@@ -1555,7 +1655,7 @@ yyerrlab:
       else
         {
           yydestruct ("Error: discarding",
-                      yytoken, &yylval, yyscanner, coll, container);
+                      yytoken, &yylval, yyscanner, coll, container, location);
           yychar = YYEMPTY;
         }
     }
@@ -1611,7 +1711,7 @@ yyerrlab1:
 
 
       yydestruct ("Error: popping",
-                  yystos[yystate], yyvsp, yyscanner, coll, container);
+                  yystos[yystate], yyvsp, yyscanner, coll, container, location);
       YYPOPSTACK (1);
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1648,7 +1748,7 @@ yyabortlab:
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
 yyexhaustedlab:
-  yyerror (yyscanner, coll, container, YY_("memory exhausted"));
+  yyerror (yyscanner, coll, container, location, YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
@@ -1660,7 +1760,7 @@ yyreturn:
          user semantic actions for why this is necessary.  */
       yytoken = YYTRANSLATE (yychar);
       yydestruct ("Cleanup: discarding lookahead",
-                  yytoken, &yylval, yyscanner, coll, container);
+                  yytoken, &yylval, yyscanner, coll, container, location);
     }
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYABORT or YYACCEPT.  */
@@ -1669,7 +1769,7 @@ yyreturn:
   while (yyssp != yyss)
     {
       yydestruct ("Cleanup: popping",
-                  yystos[*yyssp], yyvsp, yyscanner, coll, container);
+                  yystos[*yyssp], yyvsp, yyscanner, coll, container, location);
       YYPOPSTACK (1);
     }
 #ifndef yyoverflow
@@ -1682,7 +1782,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 227 "parser/extractFile.y" /* yacc.c:1906  */
+#line 288 "parser/extractFile.y" /* yacc.c:1906  */
 
 
 /* epilogue: =======================================================*/
@@ -1697,7 +1797,8 @@ yyreturn:
  * Output     : N/A
  =======================================================================*/
 void extr_error(yyscan_t yyscanner, Collection* coll,
-		Container* container, const char* message)
+		Container* container, Location* location,
+		const char* message)
 {
   logParser(LOG_ERR, "%s on token '%s' line %i",
 	  message, extr_get_text(yyscanner), LINENO);
@@ -1718,6 +1819,7 @@ int parseExtractFile(Collection* coll, const char* path)
   FILE* inputStream = stdin;
   yyscan_t scanner;
   Container* container = 0;
+  Location* location = 0;
 
   checkCollection(coll);
   logParser(LOG_INFO, "parse %s extraction data from %s",
@@ -1734,7 +1836,6 @@ int parseExtractFile(Collection* coll, const char* path)
       logParser(LOG_ERR, "cannot open input stream: %s", path); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
 
   extr_set_in(inputStream, scanner);
@@ -1744,18 +1845,14 @@ int parseExtractFile(Collection* coll, const char* path)
   logParser(LOG_DEBUG, "extr_set_debug = %i", extr_get_debug(scanner));
 
   // call the parser
-  if (extr_parse(scanner, coll, container)) {
+  if (extr_parse(scanner, coll, container, location)) {
     logParser(LOG_ERR, "extract parser fails on line %i",
 	    extr_get_lineno(scanner));
     logParser(LOG_ERR, "please edit %s", path?path:"stdin");
-    goto error3;
+    goto error2;
   }
 
   rc = TRUE;
- error3:
-  if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) rc = FALSE;
-  }
  error2:
   if (inputStream != stdin) {
     fclose(inputStream);
