@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -56,51 +56,61 @@ extern int extr_debug;
     extrERROR = 258,
     extrOPEN = 259,
     extrCLOSE = 260,
-    extrTYPE = 261,
-    extrIMPLIES = 262,
-    extrAS = 263,
-    extrHASH = 264,
-    extrCOLON = 265,
-    extrSIZE = 266,
-    extrCOMMA = 267,
-    extrSTRING = 268
+    extrETYPE = 261,
+    extrLTYPE = 262,
+    extrIMPLIES = 263,
+    extrDIRECTORY = 264,
+    extrOPTIONS = 265,
+    extrHASH = 266,
+    extrFINGERPRINT = 267,
+    extrCOLON = 268,
+    extrSIZE = 269,
+    extrCOMMA = 270,
+    extrSTRING = 271
   };
 #endif
 /* Tokens.  */
 #define extrERROR 258
 #define extrOPEN 259
 #define extrCLOSE 260
-#define extrTYPE 261
-#define extrIMPLIES 262
-#define extrAS 263
-#define extrHASH 264
-#define extrCOLON 265
-#define extrSIZE 266
-#define extrCOMMA 267
-#define extrSTRING 268
+#define extrETYPE 261
+#define extrLTYPE 262
+#define extrIMPLIES 263
+#define extrDIRECTORY 264
+#define extrOPTIONS 265
+#define extrHASH 266
+#define extrFINGERPRINT 267
+#define extrCOLON 268
+#define extrSIZE 269
+#define extrCOMMA 270
+#define extrSTRING 271
 
 /* Value type.  */
 #if ! defined EXTR_STYPE && ! defined EXTR_STYPE_IS_DECLARED
-typedef union EXTR_STYPE EXTR_STYPE;
+
 union EXTR_STYPE
 {
 #line 60 "parser/extractFile.y" /* yacc.c:1909  */
 
-  off_t  size;
-  char   string[MAX_SIZE_STRING+1];
+  EType  eType;
+  LType  lType;
   char   hash[MAX_SIZE_MD5+1];
-  EType  type; 
+  char   fp[MAX_SIZE_MD5+1];
+  char   string[MAX_SIZE_STRING+1];
+  off_t  size;
   Archive* archive;
 
-#line 96 "parser/extractFile.tab.h" /* yacc.c:1909  */
+#line 104 "parser/extractFile.tab.h" /* yacc.c:1909  */
 };
+
+typedef union EXTR_STYPE EXTR_STYPE;
 # define EXTR_STYPE_IS_TRIVIAL 1
 # define EXTR_STYPE_IS_DECLARED 1
 #endif
 
 
 
-int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
+int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container, Location* location);
 /* "%code provides" blocks.  */
 #line 26 "parser/extractFile.y" /* yacc.c:1909  */
 
@@ -130,6 +140,6 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 
 #define YYSTYPE EXTR_STYPE
 
-#line 134 "parser/extractFile.tab.h" /* yacc.c:1909  */
+#line 144 "parser/extractFile.tab.h" /* yacc.c:1909  */
 
 #endif /* !YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED  */
