@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -214,7 +214,7 @@ extern int serv_debug;
 
 /* Value type.  */
 #if ! defined SERV_STYPE && ! defined SERV_STYPE_IS_DECLARED
-typedef union SERV_STYPE SERV_STYPE;
+
 union SERV_STYPE
 {
 #line 60 "parser/serverFile.y" /* yacc.c:355  */
@@ -229,6 +229,8 @@ union SERV_STYPE
 
 #line 231 "parser/serverFile.tab.c" /* yacc.c:355  */
 };
+
+typedef union SERV_STYPE SERV_STYPE;
 # define SERV_STYPE_IS_TRIVIAL 1
 # define SERV_STYPE_IS_DECLARED 1
 #endif
@@ -265,7 +267,7 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
 
 #define YYSTYPE SERV_STYPE
 
-#line 269 "parser/serverFile.tab.c" /* yacc.c:355  */
+#line 271 "parser/serverFile.tab.c" /* yacc.c:355  */
 
 #endif /* !YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED  */
 
@@ -280,7 +282,7 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
 void serv_error(yyscan_t yyscanner, Collection* coll, Server* server,
 		const char* message);
 
-#line 284 "parser/serverFile.tab.c" /* yacc.c:358  */
+#line 286 "parser/serverFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1447,7 +1449,7 @@ yyreduce:
     {
   logParser(LOG_INFO, "the server file was empty");
 }
-#line 1451 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1453 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 3:
@@ -1455,7 +1457,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %3-i: file: headers", LINENO);
 }
-#line 1459 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1461 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
@@ -1463,7 +1465,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %3-i: file: headers stanzas", LINENO);
 }
-#line 1467 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1469 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
@@ -1471,7 +1473,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %3-i: headers: headers header", LINENO);
 }
-#line 1475 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1477 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
@@ -1479,7 +1481,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %3-i: headers: header", LINENO);
 }
-#line 1483 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1485 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 7:
@@ -1488,7 +1490,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i master server: %s", LINENO, (yyvsp[0].hash));
   if (!(coll->serverTree->master = addServer(coll, (yyvsp[0].hash)))) YYABORT;
 }
-#line 1492 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1494 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 8:
@@ -1496,7 +1498,7 @@ yyreduce:
     {
   strncpy(coll->serverTree->dnsHost, (yyvsp[0].string), MAX_SIZE_HOST);
 }
-#line 1500 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1502 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
@@ -1504,7 +1506,7 @@ yyreduce:
     {
   strncpy(coll->serverTree->aesKey, (yyvsp[0].string), MAX_SIZE_AES);
 }
-#line 1508 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1510 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
@@ -1513,7 +1515,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i https %s", LINENO, (yyvsp[0].boolean)?"yes":"no");
   coll->serverTree->doHttps = (yyvsp[0].boolean);
 }
-#line 1517 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1519 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
@@ -1527,7 +1529,7 @@ yyreduce:
     coll->serverTree->log &= ~APACHE;
   }
 }
-#line 1531 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1533 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
@@ -1541,7 +1543,7 @@ yyreduce:
     coll->serverTree->log &= ~GIT;
   }
 }
-#line 1545 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1547 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
@@ -1555,7 +1557,7 @@ yyreduce:
     coll->serverTree->log &= ~AUDIT;
   }
 }
-#line 1559 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1561 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
@@ -1563,7 +1565,7 @@ yyreduce:
     {
   coll->serverTree->serverTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1567 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1569 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
@@ -1571,7 +1573,7 @@ yyreduce:
     {
   coll->serverTree->scoreParam.suppTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1575 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1577 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
@@ -1579,7 +1581,7 @@ yyreduce:
     {
   coll->serverTree->uploadTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1583 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1585 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
@@ -1587,7 +1589,7 @@ yyreduce:
     {
    coll->serverTree->scoreParam.maxScore = (yyvsp[0].score);
 }
-#line 1591 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1593 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1595,7 +1597,7 @@ yyreduce:
     {
   coll->serverTree->scoreParam.badScore = (yyvsp[0].score);
 }
-#line 1599 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1601 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
@@ -1603,7 +1605,7 @@ yyreduce:
     {
   coll->serverTree->scoreParam.powSupp = (yyvsp[0].score);
 }
-#line 1607 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1609 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1611,7 +1613,7 @@ yyreduce:
     {
   coll->serverTree->scoreParam.factSupp = (yyvsp[0].score);
 }
-#line 1615 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1617 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1619,15 +1621,15 @@ yyreduce:
     {
    coll->serverTree->scoreParam.fileScore = (yyvsp[0].score);
 }
-#line 1623 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1625 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 22:
 #line 248 "parser/serverFile.y" /* yacc.c:1646  */
     {
-  coll->serverTree->scoreParam.factSupp = (yyvsp[0].number);
+  coll->serverTree->minGeoDup = (yyvsp[0].number);
 }
-#line 1631 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1633 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1635,7 +1637,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %3-i: stanzas: stanzas stanza", LINENO);
 }
-#line 1639 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1641 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 24:
@@ -1643,7 +1645,7 @@ yyreduce:
     {
   logParser(LOG_DEBUG, "line %3-i: stanzas: stanza", LINENO);
 }
-#line 1647 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1649 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 25:
@@ -1662,7 +1664,7 @@ yyreduce:
   if (!(server->user = 
 	catString(server->user, coll->label))) YYABORT;
 }
-#line 1666 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1668 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 26:
@@ -1671,7 +1673,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i new server: %s", LINENO, (yyvsp[0].hash));
   if (!(server = addServer(coll, (yyvsp[0].hash)))) YYABORT;
 }
-#line 1675 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1677 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 31:
@@ -1679,7 +1681,7 @@ yyreduce:
     {
   if (!(server->label = createString((yyvsp[0].string)))) YYERROR;
 }
-#line 1683 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1685 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 32:
@@ -1687,7 +1689,7 @@ yyreduce:
     {
   if (!(server->comment = createString((yyvsp[0].string)))) YYERROR;
 }
-#line 1691 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1693 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 33:
@@ -1695,7 +1697,7 @@ yyreduce:
     {
   strncpy(server->host, (yyvsp[0].string), MAX_SIZE_HOST);
 }
-#line 1699 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1701 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 34:
@@ -1703,7 +1705,7 @@ yyreduce:
     {
   server->lastCommit = (yyvsp[0].time);
 }
-#line 1707 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1709 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 37:
@@ -1711,7 +1713,7 @@ yyreduce:
     {
   if (server) server->mdtxPort = (int)(yyvsp[0].number);
 }
-#line 1715 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1717 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 38:
@@ -1719,7 +1721,7 @@ yyreduce:
     {
   if (server) server->sshPort = (int)(yyvsp[0].number);
 }
-#line 1723 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1725 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 39:
@@ -1727,7 +1729,7 @@ yyreduce:
     {
   if (server) server->wwwPort = (int)(yyvsp[0].number);
 }
-#line 1731 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1733 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 40:
@@ -1735,7 +1737,7 @@ yyreduce:
     {
   if (!(server->userKey = createString((yyvsp[0].string)))) YYERROR;
 }
-#line 1739 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1741 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 41:
@@ -1743,7 +1745,7 @@ yyreduce:
     {
   if (!(server->hostKey = createString((yyvsp[0].string)))) YYERROR;
 }
-#line 1747 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1749 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 42:
@@ -1751,7 +1753,7 @@ yyreduce:
     {
   if (server) server->cacheSize = (yyvsp[-1].number)*(yyvsp[0].size);
 }
-#line 1755 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1757 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 43:
@@ -1759,7 +1761,7 @@ yyreduce:
     {
   if (server) server->cacheTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1763 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1765 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 44:
@@ -1767,7 +1769,7 @@ yyreduce:
     {
   if (server) server->queryTTL = (yyvsp[-1].number)*(yyvsp[0].time);
 }
-#line 1771 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1773 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 48:
@@ -1791,7 +1793,7 @@ yyreduce:
     YYABORT;
   }
 }
-#line 1795 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1797 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 53:
@@ -1800,7 +1802,7 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i network: %s", LINENO, (yyvsp[0].string));
   if (!addNetworkToRing(server->networks, (yyvsp[0].string))) YYABORT;
 }
-#line 1804 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1806 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 54:
@@ -1809,11 +1811,11 @@ yyreduce:
   logParser(LOG_DEBUG, "line %-3i gateway: %s", LINENO, (yyvsp[0].string));
   if (!addNetworkToRing(server->gateways, (yyvsp[0].string))) YYABORT;
 }
-#line 1813 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1815 "parser/serverFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1817 "parser/serverFile.tab.c" /* yacc.c:1646  */
+#line 1819 "parser/serverFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2093,7 +2095,6 @@ int parseServerFile(Collection* coll, const char* path)
 		path, strerror(errno)); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
 
   serv_set_in(inputStream, scanner);
@@ -2107,14 +2108,10 @@ int parseServerFile(Collection* coll, const char* path)
     logParser(LOG_ERR, "servers file parser error on line %i",
 	    serv_get_lineno(scanner));
     logParser(LOG_ERR, "please edit %s", path?path:"stdin");
-    goto error3;
+    goto error2;
   }
 
   rc = TRUE;
- error3:
-  if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) rc = FALSE;
-  }
  error2:
   if (inputStream != stdin) {
     fclose(inputStream);
