@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -93,21 +93,20 @@ extern int shell_debug;
     shellCATALOG = 295,
     shellRULES = 296,
     shellUPLOADP = 297,
-    shellUPLOADPP = 298,
-    shellGET = 299,
-    shellSU = 300,
-    shellMOTD = 301,
-    shellAUDIT = 302,
-    shellSAVE = 303,
-    shellEXTRACT = 304,
-    shellNOTIFY = 305,
-    shellQUICK = 306,
-    shellSCAN = 307,
-    shellTRIM = 308,
-    shellSTATUS = 309,
-    shellAROBASE = 310,
-    shellCOLON = 311,
-    shellMINUS = 312
+    shellGET = 298,
+    shellSU = 299,
+    shellMOTD = 300,
+    shellAUDIT = 301,
+    shellSAVE = 302,
+    shellEXTRACT = 303,
+    shellNOTIFY = 304,
+    shellQUICK = 305,
+    shellSCAN = 306,
+    shellTRIM = 307,
+    shellSTATUS = 308,
+    shellAROBASE = 309,
+    shellCOLON = 310,
+    shellMINUS = 311
   };
 #endif
 /* Tokens.  */
@@ -151,25 +150,24 @@ extern int shell_debug;
 #define shellCATALOG 295
 #define shellRULES 296
 #define shellUPLOADP 297
-#define shellUPLOADPP 298
-#define shellGET 299
-#define shellSU 300
-#define shellMOTD 301
-#define shellAUDIT 302
-#define shellSAVE 303
-#define shellEXTRACT 304
-#define shellNOTIFY 305
-#define shellQUICK 306
-#define shellSCAN 307
-#define shellTRIM 308
-#define shellSTATUS 309
-#define shellAROBASE 310
-#define shellCOLON 311
-#define shellMINUS 312
+#define shellGET 298
+#define shellSU 299
+#define shellMOTD 300
+#define shellAUDIT 301
+#define shellSAVE 302
+#define shellEXTRACT 303
+#define shellNOTIFY 304
+#define shellQUICK 305
+#define shellSCAN 306
+#define shellTRIM 307
+#define shellSTATUS 308
+#define shellAROBASE 309
+#define shellCOLON 310
+#define shellMINUS 311
 
 /* Value type.  */
 #if ! defined SHELL_STYPE && ! defined SHELL_STYPE_IS_DECLARED
-typedef union SHELL_STYPE SHELL_STYPE;
+
 union SHELL_STYPE
 {
 #line 61 "parser/shellQuery.y" /* yacc.c:1909  */
@@ -178,8 +176,10 @@ union SHELL_STYPE
   char        string[MAX_SIZE_STRING+1];
   Collection* coll;
 
-#line 182 "parser/shellQuery.tab.h" /* yacc.c:1909  */
+#line 180 "parser/shellQuery.tab.h" /* yacc.c:1909  */
 };
+
+typedef union SHELL_STYPE SHELL_STYPE;
 # define SHELL_STYPE_IS_TRIVIAL 1
 # define SHELL_STYPE_IS_DECLARED 1
 #endif
