@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -138,7 +138,7 @@ extern int supp_debug;
 
 /* Value type.  */
 #if ! defined SUPP_STYPE && ! defined SUPP_STYPE_IS_DECLARED
-typedef union SUPP_STYPE SUPP_STYPE;
+
 union SUPP_STYPE
 {
 #line 60 "parser/supportFile.y" /* yacc.c:355  */
@@ -152,6 +152,8 @@ union SUPP_STYPE
 
 #line 154 "parser/supportFile.tab.c" /* yacc.c:355  */
 };
+
+typedef union SUPP_STYPE SUPP_STYPE;
 # define SUPP_STYPE_IS_TRIVIAL 1
 # define SUPP_STYPE_IS_DECLARED 1
 #endif
@@ -188,7 +190,7 @@ int supp_parse (yyscan_t yyscanner);
 
 #define YYSTYPE SUPP_STYPE
 
-#line 192 "parser/supportFile.tab.c" /* yacc.c:355  */
+#line 194 "parser/supportFile.tab.c" /* yacc.c:355  */
 
 #endif /* !YY_SUPP_PARSER_SUPPORTFILE_TAB_H_INCLUDED  */
 
@@ -202,7 +204,7 @@ int supp_parse (yyscan_t yyscanner);
 
 void supp_error(yyscan_t yyscanner, const char* message);
 
-#line 206 "parser/supportFile.tab.c" /* yacc.c:358  */
+#line 208 "parser/supportFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1282,7 +1284,7 @@ yyreduce:
     {
   logParser(LOG_WARNING, "the supports file was empty");
 }
-#line 1286 "parser/supportFile.tab.c" /* yacc.c:1646  */
+#line 1288 "parser/supportFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
@@ -1332,11 +1334,11 @@ yyreduce:
   strncpy(support->name, (yyvsp[0].name), MAX_SIZE_STRING);
   support = 0;
 }
-#line 1336 "parser/supportFile.tab.c" /* yacc.c:1646  */
+#line 1338 "parser/supportFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1340 "parser/supportFile.tab.c" /* yacc.c:1646  */
+#line 1342 "parser/supportFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1612,7 +1614,6 @@ parseSupports(const char* path)
       logParser(LOG_ERR, "cannot open input stream: %s", path); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
 
   supp_set_in(inputStream, scanner);
@@ -1626,14 +1627,10 @@ parseSupports(const char* path)
     logParser(LOG_ERR, "support parser fails on line %i", 
 	    supp_get_lineno(scanner));
     logParser(LOG_ERR, "please edit %s", path?path:"stdin");
-    goto error3;
+    goto error2;
   }
 
   rc = TRUE;
- error3:
-  if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) rc = FALSE;
-  }
  error2:
   if (inputStream != stdin) {
     fclose(inputStream);
