@@ -201,23 +201,27 @@ getAbsoluteRecordPath(Collection* coll, Record* record)
 /*=======================================================================
  * Function   : removeFile
  * Description: unlink file from cache
- * Synopsis   : int removeFile(char* absolutePath, char* relativePath, 
- *                             char* message)
+ * Synopsis   : int removeFile(Collection* coll, char* absolutePath, 
+ *                             char* relativePath, char* message)
  * Input      : char* absolutePath: path to unlink
  *              char* relativePath: part of the log message
  *              char* message: part of the log message
  * Output     : TRUE on success
  =======================================================================*/
 static int 
-removeFile(char* absolutePath, char* relativePath, char* message)
+removeFile(Collection* coll, char* absolutePath, char* relativePath,
+	   char* message)
 {
   int rc = FALSE;
 
-  // do not unlink final supplies
-  if (*relativePath == '/') goto end;
-
-  logMain(LOG_NOTICE, "remove %s from cache (%s)", 
-	  relativePath, message);
+  // asser we do not unlink outside of the cache
+  if (strncmp(coll->cacheDir, absolutePath, strlen(coll->cacheDir))) {
+    logMain(LOG_CRIT, "internal error");
+    goto error;
+  }
+  
+  logMain(LOG_NOTICE, "remove %s from %s's cache (%s)", 
+	  relativePath, coll->label, message);
 
   if (!env.dryRun) {
     if (unlink(absolutePath) == -1) {
@@ -226,7 +230,6 @@ removeFile(char* absolutePath, char* relativePath, char* message)
     }
   }
 
- end:
   rc = TRUE;
  error:
   if (!rc) {
@@ -238,15 +241,15 @@ removeFile(char* absolutePath, char* relativePath, char* message)
 /*=======================================================================
  * Function   : addFile
  * Description: index a new local-supply into the cache
- * Synopsis   : int addFile(Collection* coll, char* relativePath, 
+ * Synopsis   : int addFile(Collection* coll, char* path, 
  *                          Archive* archive)
  * Input      : Collection* coll
- *              char* relativePath: path of the local-supply
+ *              char* path: path of the local-supply
  *              Archive* archive: related archive
  * Output     : TRUE on success
  =======================================================================*/
 static int 
-addFile(Collection* coll, char* relativePath, Archive* archive)
+addFile(Collection* coll, char* path, Archive* archive)
 {
   int rc = FALSE;
   Record *record = 0;
@@ -256,14 +259,8 @@ addFile(Collection* coll, char* relativePath, Archive* archive)
   if (!getLocalHost(coll)) goto error;
     
   // add a new cache entry
-  if (!(extra = createString(relativePath))) goto error;
-
-  // notice dedicated cache directory where to extract final supplies
-  if (*relativePath == '/') {
-    if (!(extra = catString(extra, CONF_SUPPD))) goto error;
-  }
-
-  if (!(record = 
+  if (!(extra = createString(path))) goto error;
+  if (!(record =
 	addRecord(coll, coll->localhost, archive, SUPPLY, extra)))
     goto error;
 
@@ -300,26 +297,26 @@ scanFile(Collection* coll, char* absolutePath, char* relativePath,
   Record searchRecord;
 
   logMain(LOG_DEBUG, "scanFile");
-  checkLabel(absolutePath);
-  checkLabel(relativePath);
+  checkString(absolutePath, "absolute path");
+  checkString(relativePath, "relative path");
   logMain(LOG_INFO, "scan: %s", relativePath);
   memset(&md5, 0, sizeof(CheckData));
-
-  // get file attributes (size)
+  
+  // get file size
   if (stat(absolutePath, &statBuffer)) {
     logMain(LOG_ERR, "stat fails on %s: %s", 
 	    absolutePath, strerror(errno));
     goto error;
   }
-
+  
   // remove empty file from cache
-  if (!statBuffer.st_size && *relativePath != '/') {
-    if (!removeFile(absolutePath, relativePath, "empty file")) 
+  if (!statBuffer.st_size) {
+    if (!removeFile(coll, absolutePath, relativePath, "empty file")) 
       goto error;
     goto end;
   }
 
-  // match already loaded record from md5sums file
+  // skip already loaded record from md5sums file
   searchRecord.extra = relativePath;
   if ((node = avl_search(localSuppliesOk, &searchRecord)))
     goto end;
@@ -330,17 +327,18 @@ scanFile(Collection* coll, char* absolutePath, char* relativePath,
   md5.opp = CHECK_CACHE_ID;
   if (!doChecksum(&md5)) goto error;
 
-  // archive should adready exists on extraction metadata
+  // remove archive that is not already defined elsewhere
   if (!(archive = getArchive(coll, md5.fullMd5sum, statBuffer.st_size))) {
-    if (!removeFile(absolutePath, relativePath, "no extract rule")) 
+    if (!removeFile(coll, absolutePath, relativePath, "unknown archive"))
       goto error;
     goto end;
   } 
 
-  // remove doublons
+  // remove archive already there (doublon)
   if (archive->localSupply && 
       !(archive->localSupply->type & REMOVE)) {
-    if (!removeFile(absolutePath, relativePath, "doublon")) goto error;
+    if (!removeFile(coll, absolutePath, relativePath, "already there"))
+      goto error;
     goto end;
   }
 
@@ -478,7 +476,7 @@ scanRepository(Collection* coll, const char* path,
  *              int doQuick: trust on recorded checksums
  * Output     : TRUE on success
  * Note       : - on quick only check size, else check md5sum too  
- *              - add path into a btree
+ *              - unindex them or add them into a btree
  =======================================================================*/
 static int 
 scanMd5sumFiles(Collection* coll, AVLTree* localSuppliesOk, int doQuick)
@@ -502,8 +500,11 @@ scanMd5sumFiles(Collection* coll, AVLTree* localSuppliesOk, int doQuick)
 	!(supply = archive->localSupply) ||
 	supply->type & REMOVE) continue;
 
-    // do not work on support-file
-    if (*supply->extra == '/') continue;
+    // assert we do not work on final-supplies (support-files or locations)
+    if (*supply->extra == '/') {
+      logMain(LOG_CRIT, "internal error");
+      goto error;
+    }
 
     logMain(LOG_INFO, "check: %s", supply->extra);
     
@@ -537,6 +538,11 @@ scanMd5sumFiles(Collection* coll, AVLTree* localSuppliesOk, int doQuick)
       }
     }
 
+    // remove local-supply that no more exists on extraction metadata
+    if (!belongsToExtractTree(coll, archive)) {
+      goto unIndex;
+    } 
+
     // add file to localSuppliesOk tree for scanRepository
     if (!avl_insert(localSuppliesOk, supply)) {
       logMain(LOG_ERR, "avl_insert fails");
@@ -558,6 +564,42 @@ scanMd5sumFiles(Collection* coll, AVLTree* localSuppliesOk, int doQuick)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : removeFinalSupplies
+ * Description: removing all final-supplies from the cache
+ * Synopsis   : static int removeFinalSupplies(Collection* coll)
+ * Input      : Collection* coll : collections to scan
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+removeFinalSupplies(Collection* coll)
+{
+  int rc = FALSE;
+  Archive* archive = 0;
+  Record* supply = 0;
+  AVLNode* node = 0;
+  RGIT* curr = 0;
+
+  logMain(LOG_DEBUG, "removeFinalSupplies");
+  checkCollection(coll);
+
+  // remove all final-supplies from the cache
+  for (node = coll->cacheTree->archives->head; node; node = node->next) {
+    archive = node->item;
+    curr = 0;
+    while ((supply = rgNext_r(archive->finalSupplies, &curr))) {
+      if (!delCacheEntry(coll, supply)) goto error;
+    }
+  } 
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "removeFinalSupplies fails");
+  } 
+  return rc;
+}
+
 /*=======================================================================
  * Function   : scanSupportFiles
  * Description: scan files provided by support.txt
@@ -570,32 +612,29 @@ scanSupportFiles(Collection* coll)
 {
   int rc = FALSE;
   Archive* archive = 0;
-  Record* supply = 0;
   Support* supp = 0;
-  AVLNode* node = 0;
   RGIT* curr = 0;
+  char path[MAX_SIZE_STRING*2+1];
 
   logMain(LOG_DEBUG, "scanSupportFiles");
   checkCollection(coll);
 
   if (!loadConfiguration(CFG|SUPP)) goto error;
 
-  // start by removing all final-supplies from the cache
-  for (node = coll->cacheTree->archives->head; node; node = node->next) {
-    archive = node->item;
-    curr = 0;
-    while ((supply = rgNext_r(archive->finalSupplies, &curr))) {
-      if (!delCacheEntry(coll, supply)) goto error;
-    }
-  } 
-
   // loop on support files to (re-)add final supplies
   curr = 0;
   while ((supp = rgNext_r(coll->supports, &curr))) {
-    if (*supp->name != '/') continue;
+    if (*supp->name != '/') continue; // only supports's files
     if (!(archive = getArchive(coll, supp->fullMd5sum, supp->size)))
       goto error;
-    if (!addFile(coll, supp->name, archive)) goto error;
+
+    // notice dedicated cache directory where to extract final supplies    
+    if (sprintf(path, "%s%s", supp->name, CONF_SUPPD) <0) {
+      logMain(LOG_ERR, "sprintf fails");
+      goto error;
+    }
+    
+    if (!addFile(coll, path, archive)) goto error;
   }
 
   rc = TRUE;
@@ -606,6 +645,64 @@ scanSupportFiles(Collection* coll)
   return rc;
 }
 
+/* /\*======================================================================= */
+/*  * Function   : scanLocations */
+/*  * Description: scan locations provided by extract.txt */
+/*  * Synopsis   : static int scanLocations(Collection* coll) */
+/*  * Input      : Collection* coll : collections to scan */
+/*  * Output     : TRUE on success */
+/*  =======================================================================*\/ */
+/* static int  */
+/* scanLocations(Collection* coll) */
+/* { */
+/*   int rc = FALSE; */
+/*   ExtractTree* self = 0; */
+/*   Location* location = 0; */
+/*   LocationAsso* asso = 0; */
+/*   Archive* archive = 0; */
+/*   AVLNode* node = 0; */
+/*   RGIT* curr = 0; */
+/*   char* path = 0; */
+/*   char absPath[MAX_SIZE_STRING*2+1]; */
+
+/*   logMain(LOG_DEBUG, "scanLocations"); */
+/*   checkCollection(coll); */
+/*   if (!(self = coll->extractTree)) goto error; */
+
+/*   // loop on locations to (re-)add final supplies */
+/*   while ((location = rgNext_r(self->locations, &curr))) { */
+/*     if (*location->absPath != '/') { */
+/*       logMemory(LOG_WARNING, "location must use an absolute path: get %s", */
+/* 		path); */
+/*       continue; */
+/*     } */
+/*     strncpy(absPath, location->absPath, MAX_SIZE_STRING); */
+/*     path = absPath+strlen(absPath); */
+
+/*     // loop on assoLocations */
+/*     for (node = location->childs->head; node; node = node->next) { */
+/*       asso = node->item; */
+/*       if (!(archive = getArchive(coll, asso->archive->hash, */
+/* 				 asso->archive->size))) goto error; */
+
+/*       // notice dedicated cache directory where to extract final supplies     */
+/*       if (sprintf(path, "/%s%s", asso->path, CONF_LOCAD) <0) { */
+/* 	logMain(LOG_ERR, "sprintf fails"); */
+/* 	goto error; */
+/*       } */
+   
+/*       if (!addFile(coll, absPath, archive)) goto error; */
+/*     } */
+/*   } */
+  
+/*   rc = TRUE; */
+/*  error: */
+/*   if (!rc) { */
+/*     logMain(LOG_ERR, "scanLocations fails"); */
+/*   }  */
+/*   return rc; */
+/* } */
+
 /*=======================================================================
  * Function   : scanCollection
  * Description: scan caches
@@ -628,7 +725,6 @@ scanCollection(Collection* coll, int doQuick)
 	avl_alloc_tree(cmpRecordPathAvl, (avl_freeitem_t)0)))
     goto error;
 
-
   if (!loadCollection(coll, EXTR|CACH)) goto error;
   if (!lockCacheRead(coll)) goto error2;
 
@@ -647,7 +743,7 @@ scanCollection(Collection* coll, int doQuick)
   if (!rc) {
     logMain(LOG_ERR, "%sscanCollection fails", doQuick?"quick ":"");
   } 
-  // do not free archives (freeitem callback = NULL)
+  // do not free records (freeitem callback = NULL)
   avl_free_tree(localSuppliesOk);
   return rc;
 }
@@ -663,21 +759,28 @@ int
 loadCache(Collection* coll)
 {
   int rc = FALSE;
+  int wasAlreadyLoaded = 0;
 
   checkCollection(coll);
   logMain(LOG_DEBUG, "load %s cache", coll->label);
 
+  wasAlreadyLoaded = (coll->fileState[iCACH] != DISEASED);
+  
   // parse md5sum file (what this function really do)
   if (!loadCollection(coll, EXTR|CACH)) goto error;
 
-  // force quick scan if md5sum file was empty
+  // force scan if md5sum file was empty
   if (!avl_count(coll->cacheTree->recordTree->records)) {
     if(!scanCollection(coll, FALSE)) goto error2;
   }
 
-  // add file-supports as local supplies
-  if (!scanSupportFiles(coll)) goto error2;
-
+  // add file-supports and assoLocations as local supplies
+  if (!wasAlreadyLoaded) {
+    if (!removeFinalSupplies(coll)) goto error2;
+    if (!scanSupportFiles(coll)) goto error2;
+    //if (!scanLocations(coll)) goto error2;
+  }
+    
   rc = TRUE;
  error2:
   if (!releaseCollection(coll, EXTR|CACH)) rc = FALSE;
@@ -781,7 +884,7 @@ freeCache(Collection* coll, off_t need, int* success)
 
     // free file on disk
     if (!(path = getAbsoluteRecordPath(coll, record))) goto error;
-    if (!removeFile(path, record->extra, "free")) goto error;
+    if (!removeFile(coll, path, record->extra, "free")) goto error;
     path = destroyString(path);
     free = self->totalSize - self->useSize;
   }
@@ -1140,6 +1243,7 @@ isSafeArchive(Collection* coll, Archive* self,
  * Function   : trimCache
  * Description: trim cache: remove files safe and extractable from a
  *              containers available into the cache
+ *              remove locations too
  * Synopsis   : int trimCache(Collection* coll)
  * Input      : Collection* coll
  * Output     : TRUE on success
@@ -1181,21 +1285,23 @@ trimCache(Collection* coll)
     if (archive->state >= TOKEEP) continue;
 
     // looking for contents having its container into the cache
-    logMain(LOG_INFO, "try to trim: %s", record->extra);
-    isSafe = FALSE;
-    while (!isSafe &&
-	   (asso = rgNext_r(archive->fromContainers, &curr))) {
-      if (!isSafeContainer(coll, asso->container, isSafeTrim, &isSafe)) 
-	goto error;
+    if (belongsToContainers(coll, archive)) {
+      logMain(LOG_INFO, "try to trim: %s", record->extra);
+      isSafe = FALSE;
+      while (!isSafe &&
+	     (asso = rgNext_r(archive->fromContainers, &curr))) {
+	if (!isSafeContainer(coll, asso->container, isSafeTrim, &isSafe)) 
+	  goto error;
+      }
+      if (!isSafe) continue;
     }
-    if (!isSafe) continue;
 
     // un-index the record from cache (do not free the record)
     if (!delCacheEntry(coll, record)) goto error2;
 
     // remove file from disk
     if (!(path = getAbsoluteRecordPath(coll, record))) goto error2;
-    if (!removeFile(path, record->extra, "trim")) goto error2;
+    if (!removeFile(coll, path, record->extra, "trim")) goto error2;
     path = destroyString(path);
   }
 
@@ -1218,6 +1324,7 @@ trimCache(Collection* coll)
  * Function   : cleanCache
  * Description: clean cache: remove files safe and extractable from 
  *              supports locally available
+ *              remove locations too
  * Synopsis   : int cleanCache(Collection* coll)
  * Input      : Collection* coll
  * Output     : TRUE on success
@@ -1259,21 +1366,23 @@ int cleanCache(Collection* coll)
     if (archive->state >= TOKEEP) continue;
 
     // looking for contents extractable from local final-supplies
-    logMain(LOG_INFO, "try to clean: %s", record->extra);
-    isSafe = (getImage(coll, coll->localhost, archive) != 0);
-    while (!isSafe &&
-	   (asso = rgNext_r(archive->fromContainers, &curr))) {
-      if (!isSafeContainer(coll, asso->container, isSafeClean, &isSafe)) 
-	goto error;
+    if (belongsToContainers(coll, archive)) {
+      logMain(LOG_INFO, "try to clean: %s", record->extra);
+      isSafe = (getImage(coll, coll->localhost, archive) != 0);
+      while (!isSafe &&
+	     (asso = rgNext_r(archive->fromContainers, &curr))) {
+	if (!isSafeContainer(coll, asso->container, isSafeClean, &isSafe)) 
+	  goto error;
+      }
+      if (!isSafe) continue;
     }
-    if (!isSafe) continue;
 
     // un-index the record from cache (do not free the record)
     if (!delCacheEntry(coll, record)) goto error2;
 
     // remove file from disk
     if (!(path = getAbsoluteRecordPath(coll, record))) goto error2;
-    if (!removeFile(path, record->extra, "clean")) goto error2;
+    if (!removeFile(coll, path, record->extra, "clean")) goto error2;
     path = destroyString(path);
   }
 
@@ -1295,6 +1404,7 @@ int cleanCache(Collection* coll)
 /*=======================================================================
  * Function   : purgeCache
  * Description: purge cache: remove all safe
+ *              remove locations too
  * Synopsis   : int purgeCache(Collection* coll)
  * Input      : Collection* coll
  * Output     : TRUE on success
@@ -1336,7 +1446,7 @@ int purgeCache(Collection* coll)
 
     // remove file from disk
     if (!(path = getAbsoluteRecordPath(coll, record))) goto error2;
-    if (!removeFile(path, record->extra, "purge")) goto error2;
+    if (!removeFile(coll, path, record->extra, "purge")) goto error2;
     path = destroyString(path);
   }
 
