@@ -796,6 +796,34 @@ cacheSet(ExtractData* data, Record* record,
   return rc;
 }
 
+/*=======================================================================
+ * Function   : getRelativeCanonicalAssoPath
+ * Description: Append directory to path from a FromAsso
+ * Synopsis   : char* getRelativeCanonicalAssoPath(FrommAsso* asso)
+ * Input      : FrommAsso* asso
+ * Output     : Allocated relative path on success
+ * Note       : to be free by caller
+ =======================================================================*/
+static char* 
+getRelativeCanonicalAssoPath(FromAsso* asso)
+{
+  char* rc = 0;
+
+  // append directory if provided
+  if (asso->container->directory) {
+    if (!(rc = createString(asso->container->directory))) goto error;
+    if (rc[strlen(rc)-1] != '/') {
+       if (!(rc = catString(rc, "/"))) goto error;
+    }
+  }
+
+  // append path
+  if (!(rc = catString(rc, asso->path))) goto error;
+
+ error:
+  return rc;
+}
+
 /*=======================================================================
  * Function   : extractRecord
  * Description: extract a record 
@@ -840,22 +868,26 @@ extractRecord(ExtractData* data, Record* sourceRecord)
   }
 
   // allocate place on cache
-  if (!cacheAlloc(&targetRecord, coll, sourceRecord->archive)) goto error;
+  if (!cacheAlloc(&targetRecord, coll, sourceRecord->archive)) 
+    goto error;
 
   // Retrieve canonical path we will try to use for extraction:
   // - final supply
   if (finalSupplyTarget) {
     relativeCanonicalPath = finalSupplyTarget;
+    finalSupplyTarget = 0;
     goto next;
   }
   // - first canonical target name (may be severals)
   if (sourceRecord->archive &&
       (asso = rgHead(sourceRecord->archive->fromContainers))) {
-    relativeCanonicalPath = asso->path;
+    if (!(relativeCanonicalPath = getRelativeCanonicalAssoPath(asso)))
+      goto error;
     goto next;
   }
   // - source path for top containers
-  relativeCanonicalPath = sourceRecord->extra;
+  if (!(relativeCanonicalPath = createString(sourceRecord->extra)))
+    goto error;
   
  next:
   // build destination path into temporary extraction directory
@@ -901,18 +933,152 @@ extractRecord(ExtractData* data, Record* sourceRecord)
   if (targetRecord) delCacheEntry(coll, targetRecord);
   destroyString(device);
   destroyString(absoluteExtractPath);
+  destroyString(relativeCanonicalPath);
   destroyString(finalSupplySource);
   destroyString(finalSupplyTarget);
   return rc;
 }
 
+/*=======================================================================
+ * Function   : verifyArchive
+ * Description: check size and md5sum
+ * Synopsis   : verifyArchive(Archive* archive, char* path)
+ * Input      : Archive* archive: size and hash values to compare
+ *              char* path: file to check
+ * Output     : TRUE on success
+ =======================================================================*/
+static int
+verifyArchive(Archive* archive, char* path)
+{
+  int rc = FALSE;
+  struct stat statBuffer;
+  CheckData md5;
+  
+  logMain(LOG_DEBUG, "checkArchive %s", path);
+  
+  // get file attributes (size)
+  if (stat(path, &statBuffer)) {
+    logMain(LOG_ERR, "status error on %s: %s", path, strerror(errno));
+    goto error;
+  }
+
+  // compare size
+  if (statBuffer.st_size != archive->size) {
+    logMain(LOG_WARNING, "bad size %s: %lli vs %lli expected",
+	    path, (long long int)statBuffer.st_size,
+	    (long long int)archive->size);
+    goto error;
+  }
+  
+  // compute hash
+  memset(&md5, 0, sizeof(CheckData));
+  md5.path = path;
+  md5.size = archive->size;
+  md5.opp = CHECK_CACHE_ID;
+  if (!doChecksum(&md5)) goto error;
+
+  // compare hash
+  if (strncmp(md5.fullMd5sum, archive->hash, MAX_SIZE_MD5)) {
+    logMain(LOG_WARNING, "bad md5sum %s: %s vs %s expected",
+	    path, md5.fullMd5sum, archive->hash);
+    goto error;
+  }
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "verifyArchive fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : extractLocationAsso
+ * Description: extract a LocationAsso (local, url...)
+ *              (extract from location aavailable locally)
+ * Synopsis   : int extractLocationAsso(Collection* coll, 
+ *                                                   LocationAsso* asso)
+ * Input      : Collection* coll
+ *              LocationAsso* asso
+ * Output     : TRUE on success
+ * Note       : extract LOCAL supply
+ =======================================================================*/
+int 
+extractLocationAsso(ExtractData* data, LocationAsso* asso)
+{
+  int rc = FALSE;
+  Collection* coll = 0;
+  Record* targetRecord = 0;
+  char* absoluteExtractPath = 0;
+  char relativeCanonicalPath[MAX_SIZE_STRING+11+1];
+  char source[MAX_SIZE_STRING*2+1];
+ 
+  
+  coll = data->coll;
+  checkCollection(coll);
+  logMain(LOG_DEBUG, "extractLocationAsso %s:%lli", 
+	  asso->archive->hash, asso->archive->size);
+
+  // allocate place on cache
+  if (!cacheAlloc(&targetRecord, coll, asso->archive)) goto error;
+
+  // build destination directory into temporary extraction directory
+  if (sprintf(relativeCanonicalPath, "%s/%s",
+	      asso->location->directory?asso->location->directory:CONF_LOCAD,
+	      asso->path) <0) {
+    logMain(LOG_ERR, "sprintf fails");
+    goto error;
+  }
+  if (!buildTargetFile(data->coll, &absoluteExtractPath,
+		       coll->extractDir, relativeCanonicalPath)) 
+    goto error;
+
+  // extract record into temporary extraction directory
+  switch (asso->location->type) {
+  case COPY:
+    if (sprintf(source, "%s/%s", asso->location->uri, asso->path) <0) {
+      logMain(LOG_ERR, "sprintf fails");
+      goto error;
+    }
+    if (!extractCp(source, absoluteExtractPath)) goto error;
+    break;
+    
+  case WGET:
+    ;//if (!extractCurl(coll, asso, absoluteExtractPath)) goto error;
+    break;
+    
+  default:
+    logMain(LOG_ERR, "location %s not manage", 
+	    strLType(asso->location->type));
+    goto error;
+  }
+
+  // check the file (locations are not trusted)
+  if (!verifyArchive(asso->archive, absoluteExtractPath)) goto error;
+    
+  // toggle !malloc record to local supply
+  if (!cacheSet(data, targetRecord, 
+		absoluteExtractPath, relativeCanonicalPath)) goto error;
+  if (!removeDir(coll->extractDir, absoluteExtractPath)) goto error;
+
+  targetRecord = 0;
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "extractLocationAsso fails");
+  }
+  if (targetRecord) delCacheEntry(coll, targetRecord);
+  destroyString(absoluteExtractPath);
+  return rc;
+}
+
 /*=======================================================================
  * Function   : extractFromAsso
  * Description: extract a FromAss (iso, cat, tgz...)
  *              (extract from container available into the local cache)
- * Synopsis   : int extractFromAsso(Collection* coll, Record* record)
+ * Synopsis   : int extractFromAsso(Collection* coll, FromAsso* asso)
  * Input      : Collection* coll
- *              Record* record
+ *              FromAsso* asso
  * Output     : TRUE on success
  * Note       : extract LOCAL supply
  =======================================================================*/
@@ -922,6 +1088,7 @@ extractFromAsso(ExtractData* data, FromAsso* asso)
   int rc = FALSE;
   Collection* coll = 0;
   Record* targetRecord = 0;
+  char* relativeCanonicalPath = 0;
   char* absoluteExtractPath = 0;
  
   coll = data->coll;
@@ -933,8 +1100,10 @@ extractFromAsso(ExtractData* data, FromAsso* asso)
   if (!cacheAlloc(&targetRecord, coll, asso->archive)) goto error;
 
   // build destination directory into temporary extraction directory
+  if (!(relativeCanonicalPath = getRelativeCanonicalAssoPath(asso))) 
+    goto error;
   if (!buildTargetFile(data->coll, &absoluteExtractPath,
-		       coll->extractDir, asso->path)) 
+		       coll->extractDir, relativeCanonicalPath)) 
     goto error;
 
   // extract record into temporary extraction directory
@@ -992,8 +1161,8 @@ extractFromAsso(ExtractData* data, FromAsso* asso)
   }
   
   // toggle !malloc record to local supply
-  if (!cacheSet(data, targetRecord, absoluteExtractPath, asso->path)) 
-    goto error;
+  if (!cacheSet(data, targetRecord, 
+		absoluteExtractPath, relativeCanonicalPath)) goto error;
   if (!removeDir(coll->extractDir, absoluteExtractPath)) goto error;
 
   targetRecord = 0;
@@ -1003,6 +1172,7 @@ extractFromAsso(ExtractData* data, FromAsso* asso)
     logMain(LOG_ERR, "extractFromAsso fails");
   }
   if (targetRecord) delCacheEntry(coll, targetRecord);
+  destroyString(relativeCanonicalPath);
   destroyString(absoluteExtractPath);
   return rc;
 }
@@ -1089,6 +1259,7 @@ extractArchive(ExtractData* data, Archive* archive, int doCp)
   Collection* coll = 0;
   int isThere = FALSE;
   FromAsso* asso = 0;
+  LocationAsso* locAsso = 0;
   Record* record = 0;
   char* path = 0;
   RGIT* curr = 0;
@@ -1131,7 +1302,6 @@ extractArchive(ExtractData* data, Archive* archive, int doCp)
 
   // final supply
   if (archive->finalSupplies->nbItems > 0) {
-
     // copy archive into the cache if it helps
     if (archive->state == WANTED // localy (toDeliver) or remotely 
 	|| doCp // to help next remote extractions (see extractContainer)
@@ -1145,7 +1315,10 @@ extractArchive(ExtractData* data, Archive* archive, int doCp)
 	  data->found = extractRecord(data, record);
 	}
       }
-    data->found = TRUE; // from cache or final-supply
+    else {
+      // from cache or directly final-supply (without copy)
+      data->found = TRUE;
+    }
     goto end;
   }
 
@@ -1181,8 +1354,22 @@ extractArchive(ExtractData* data, Archive* archive, int doCp)
     }
   }
 
-  // Recursive call: we stop on the first extraction
+  // search into locations
+  curr = 0;
+  while (!data->found &&
+  	 (locAsso = rgNext_r(archive->fromLocations, &curr))) {
 
+    // check location match local server
+    if (strcmp(locAsso->location->fingerPrint, coll->userFingerPrint))
+      continue;
+
+    if (!extractLocationAsso(data, locAsso)) goto locationError;
+    data->found = TRUE;
+    goto end;
+  }
+ locationError:
+  
+  // recursive search on containers: we stop on the first extraction
   // backup toKeeps
   toKeepsBck = data->toKeeps;
   if (!(data->toKeeps = createRing())) goto error;
