@@ -410,7 +410,7 @@ mainLoop()
   rc = TRUE;
  error:
   env.running = FALSE;
-  if (!kill(getpid(), SIGTERM) == -1) {
+  if (kill(getpid(), SIGTERM) == -1) {
     logMain(LOG_ERR, "killing signal handler failed: %s", errno);
     rc = FALSE;
   }
