@@ -100,13 +100,13 @@ cacheUpload(Collection* coll, Record* record)
 
 /*=======================================================================
  * Function   : uploadFinaleArchive
- * Description: Upload a new final supply into the cache
+ * Description: Upload new final supplies into the cache
  * Synopsis   : int uploadFinaleArchive(ArchiveTree* finalSupplies)
  * Input      : Connexion* connexion
  * Output     : TRUE on success
  =======================================================================*/
 int 
-uploadFinaleArchive(Connexion* connexion)
+uploadFinaleArchives(Connexion* connexion)
 {
   int rc = FALSE;
   Collection* coll = 0;
@@ -116,7 +116,7 @@ uploadFinaleArchive(Connexion* connexion)
   static char status[][64] = {
     "210 ok",
     "310 empty message",
-    "332 message do not provide a final supply %s",
+    "332 message provides none final supply: %s",
     "313 already exists %s:%lli"
   };
 
@@ -124,7 +124,7 @@ uploadFinaleArchive(Connexion* connexion)
   coll = connexion->message->collection;
   checkCollection(coll);
   
-  // check we get a final supplies
+  // check we get some records
   if (!connexion->message->records ||
       !avl_count(connexion->message->records)) {
     sprintf(connexion->status, "%s", status[1]);
@@ -134,47 +134,59 @@ uploadFinaleArchive(Connexion* connexion)
   if (!loadCollection(coll, EXTR | CACH)) goto error;
   if (!lockCacheRead(coll)) goto error2;
 
+  // check records
   for (node = connexion->message->records->head;
        node; node = node->next) {
     record = node->item;
 
+    // check record is a final suply
     if (getRecordType(record) != FINAL_SUPPLY) {
       sprintf(connexion->status, status[2], record->extra);
       goto error3;
     }
  
     // check archive is not already there
-    if ((record->archive->localSupply)) {
+    // (but accept archive already defined in extract catalog
+    //  as it may be usefull if archive was lost for instance)
+    if (record->archive->localSupply &&
+      // exception for archives coming only from locations
+	belongsToContainers(coll, record->archive)) {
       sprintf(connexion->status, status[3],
 	      record->archive->hash, record->archive->size);
       goto error3;
     }
   }
 
+  // upload records
   for (node = connexion->message->records->head;
        node; node = node->next) {
     record = node->item;
+
+    // nothing to do for local-supply coming from location
+    // (as client already provides incoming rules it)
+    if (record->archive->localSupply) {
+      destroyRecord(record);
+      continue;
+    }
     
-    // push provided final supplies into the cache
+    // push provided final-supply into the cache
     if (!addCacheEntry(coll, record)) goto error3;
   
-    // extract the final supply into the cache
+    // extract as local-supply into the cache
     if (!(cacheUpload(coll, record))) goto error4;
+
+    // pop the final-supply from the cache
+    if (!delCacheEntry(coll, record)) goto error3;
   }
-  
-  // record remains into the cache ; tree free by caller
+
+  // record remains into the cache (free free by caller)
   connexion->message->records->freeitem = 0;
   avl_free_nodes(connexion->message->records);
   connexion->message->records->freeitem = (void(*)(void*)) destroyRecord;
-  /*
-  avl_unlink_node(connexion->message->records, node); // consume record
-    remind(node);
-    free(node);
-  */
   sprintf(connexion->status, "%s", status[0]);
   rc = TRUE;
  error4:
-  if (!delCacheEntry(coll, record)) rc = FALSE;
+  if (!rc && !delCacheEntry(coll, record)) rc = FALSE;
  error3:
   if (!unLockCache(coll)) rc = FALSE;
  error2:
