@@ -29,7 +29,7 @@
 
 /* API */
 
-int uploadFinaleArchive(Connexion* connexion);
+int uploadFinaleArchives(Connexion* connexion);
 
 #endif /* MDTX_SERVER_UPLOAD_H */
 
